(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    424802,       7191]
NotebookOptionsPosition[    422050,       7093]
NotebookOutlinePosition[    422463,       7109]
CellTagsIndexPosition[    422420,       7106]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Lotka Oscillations", "Title",
 CellChangeTimes->{{3.46548160102174*^9, 3.46548160365125*^9}}],

Cell["\<\
Undamped oscillations from a basic set of mass action equations\
\>", "Subtitle",
 CellChangeTimes->{{3.465481608394134*^9, 3.465481623646714*^9}}],

Cell["\<\
Alfred Lotka
\"Undamped Oscillations from the Law of Mass Action\"
Journal of the American Chemical Society 49:1595-1599 (1920)\
\>", "Text",
 CellChangeTimes->{{3.46548149400881*^9, 3.4654815572092657`*^9}, {
  3.465481626383789*^9, 3.465481629137726*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "xlr8r.m"}]], "Input",
 CellChangeTimes->{{3.4653997624965*^9, 3.465399768173336*^9}}],

Cell[BoxData[
 StyleBox["\<\"xlr8r 0.74 (13 May 2009) loaded 25 October 2009 at 10:47 \
GMT-06:60 using Mathematica 7.0 for Linux x86 (64-bit) (February 18, 2009) \
(Version 7., Release 1) (MathSBML 2.9.0 [8-Oct-2008])\\nGNU Lesser General \
Public License (LGPL) Terms Apply. \"\>",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.465399768658587*^9, 3.46548163208661*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Here is the simple Lotka Reaction Set", "Subsection",
 CellChangeTimes->{{3.46548166591357*^9, 3.465481673934202*^9}}],

Cell["\<\
Basic Scheme:
\tX        -> X + X
\tX + Y -> Y + Y
\tY        -> \[EmptySet]
\
\>", "Text",
 CellChangeTimes->{{3.465481735201686*^9, 3.4654817645653353`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"net", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"X", "\[Rule]", " ", 
       RowBox[{"2", "X"}]}], ",", " ", "k1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"X", "+", "Y"}], "\[Rule]", " ", 
       RowBox[{"2", "Y"}]}], ",", " ", "k2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Y", "\[Rule]", " ", "\[EmptySet]"}], ",", " ", "k3"}], "}"}]}],
    "}"}]}]], "Input",
 CellChangeTimes->{{3.4653997742769203`*^9, 3.465399801052157*^9}, {
  3.465399917469922*^9, 3.4653999176522007`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"X", "\[Rule]", 
      RowBox[{"2", " ", "X"}]}], ",", "k1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"X", "+", "Y"}], "\[Rule]", 
      RowBox[{"2", " ", "Y"}]}], ",", "k2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Y", "\[Rule]", "\[EmptySet]"}], ",", "k3"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.465399807868227*^9, 3.465399918215087*^9, 
  3.465481634223961*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["look at the steady states", "Subsubsection",
 CellChangeTimes->{{3.4654823997176733`*^9, 3.46548240394501*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"interpret", "[", "net", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.465399808421032*^9, 3.465399819090722*^9}, {
  3.465399921909342*^9, 3.465399924138132*^9}, {3.465481637271768*^9, 
  3.465481649919032*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["X", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{"k1", " ", 
         RowBox[{"X", "[", "t", "]"}]}], "-", 
        RowBox[{"k2", " ", 
         RowBox[{"X", "[", "t", "]"}], " ", 
         RowBox[{"Y", "[", "t", "]"}]}]}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["Y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "k3"}], " ", 
         RowBox[{"Y", "[", "t", "]"}]}], "+", 
        RowBox[{"k2", " ", 
         RowBox[{"X", "[", "t", "]"}], " ", 
         RowBox[{"Y", "[", "t", "]"}]}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.4653998196178217`*^9, 3.465399924499035*^9, {3.4654816436033697`*^9, 
   3.465481650339724*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ss", "=", 
  RowBox[{"steadyState", "[", "net", "]"}]}]], "Input",
 CellChangeTimes->{{3.465482175925317*^9, 3.465482211060013*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Y", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"X", "[", "t", "]"}], "\[Rule]", 
      FractionBox["k3", "k2"]}], ",", 
     RowBox[{
      RowBox[{"Y", "[", "t", "]"}], "\[Rule]", 
      FractionBox["k1", "k2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.465482182229013*^9, 3.465482211382057*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J", "=", 
  RowBox[{"jacobianMatrix", "[", "net", "]"}]}]], "Input",
 CellChangeTimes->{{3.465482195068614*^9, 3.4654822145000477`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k1", "-", 
      RowBox[{"k2", " ", 
       RowBox[{"Y", "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "k2"}], " ", 
      RowBox[{"X", "[", "t", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k2", " ", 
      RowBox[{"Y", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "k3"}], "+", 
      RowBox[{"k2", " ", 
       RowBox[{"X", "[", "t", "]"}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.465482205473549*^9, 3.4654822149450417`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Eigenvalues", "[", "J", "]"}], "/.", "ss"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"k1", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"k2", "\[Rule]", " ", "2"}], ",", " ", 
    RowBox[{"k3", "\[Rule]", " ", "1"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.465482217235588*^9, 3.465482240700582*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], ",", "\[ImaginaryI]"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.4654822194547*^9, 3.465482241708764*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["run the simulation", "Subsubsection",
 CellChangeTimes->{{3.465482391766354*^9, 3.465482393490562*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", 
   RowBox[{"run", "[", 
    RowBox[{"net", ",", "  ", 
     RowBox[{"rates", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"k1", "\[Rule]", " ", "1"}], ",", " ", 
        RowBox[{"k2", "\[Rule]", " ", "2"}], ",", " ", 
        RowBox[{"k3", "\[Rule]", " ", "1"}]}], "}"}]}], ",", " ", 
     RowBox[{"initialConditions", "\[Rule]", " ", 
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"X", "\[Rule]", " ", "1.1"}], ",", " ", 
        RowBox[{"Y", "\[Rule]", " ", ".9"}]}], "}"}]}], ",", " ", 
     RowBox[{"timeSpan", "\[Rule]", " ", "50"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PhasePlot", "[", 
  RowBox[{"n", ",", " ", 
   RowBox[{"{", 
    RowBox[{"X", ",", "Y"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "50"}], "}"}], ",", " ", 
   RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.465399827238549*^9, 3.465399936409593*^9}, {
  3.465482169773664*^9, 3.465482172350759*^9}, {3.465482258923101*^9, 
  3.4654822969613323`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUW3c8ld8fl9VUtiKphAaJRFHeKjuykxGJyEgysyJKKPJVKZkhFU0lDeku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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesLabel->{
    FormBox["X", TraditionalForm], 
    FormBox["Y", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0., 1.283084565327463}, {0., 1.2830847292080192`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.465482297437533*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnQe4VcW1x0eaKA/hqXlqQgQBu7EmagQ1xEoUE7u+qIiKATWoiIA1aFAB
AQELqKioYCUUUQERpEiv0kGKIL1KF6Rk/9ZZa98595xd7r1Jvrw8/eTcO2uf
+c/MmtVmzey59Ro0a9Twzw2aNb69QbVLmja4r1Hj2x+odvG9TQNS6f2c269R
8K9xNcfv+5yzj33B//sa8wGlaL+fKz8OdO3bt3f333+/u+WWW1zv3r2FOm/e
PFe5cmW3evVqd88997hKlSqVcocddpgr7SpUqCBkvlZdPssnQZQSQhnXp08f
V716dXf77be7rVu31hDyQYkdoNy2bVvXvHlz9/jjj7umTZu6PXv21ExZfefO
ne7WW291rVq1cvfdd5979NFH3d69ezOtV3T9+vVztWvXln90MF/rhZuoqaxL
qhvDumMyk1BbflRws2fPdkcddRQdc+vXr3cHH3yw27ZtG2ySse/atcstWrTI
3XvvvS7DztICRT1KR8nnAalwSmv9yy67zA0YMMCbyUqp6s+cOdOdeeaZ8h1q
XXDBBa5///6uRhEwunfv7q644gqpwfcQizFjxihnK7qHH37YPfLII1Lin183
Cr+m8iCubhwPs6aknOvcubO79tprQ5hjjz3WDRs2rIzWHDx4sHvhhRekVDO+
Sml93KJFC3f33XdLB6pVq+bq1avnRo4cWT1d7S5durjbbrstfHzTTTe5Nm3a
1EhXG4bcdddd4eNzzz3X9erVS3peiqdl43EKvlguDwOOz2YdA23UqFGIUatW
Lff222+X1ZoDBw6UvqCZNeKrZLpf1o0ePdr16NFDSia3qaqWc4899pg75ZRT
RES+++47V6VKFTdo0KCUtYcMGeJOPfVUt3v3bqmNJi9evDiXbxE4BV/cP8/o
j8vmGxauMEbPnj2N40888YRYsgKFjaxSRk1uy5YtZeDKsxrxtWzQrVu3djff
fLN75plnpGa7du0KTGZimxjZG2+80dWpU8e9+uqrR+ewKqJ+AavK5xnwsdms
6tSpU46YDh8+3EYAc9etWycl9Lt06dJMYfX42jaC5cuXu44dOxbmWmybpd0H
H3zg6tat69mSxG7OnTvXHXnkkdLdlStXukMOOcRt3749V7oicHK/GDFw5d7B
2tVM8LDPY2w5N2vWLDGrgWsVs0pfAtGxrgYT5OrXry+l6dOni48LZKJ6fG1T
+a5du7qTTz45S28TGkTbqlat6rZs2SKUG264wa1ZsyZl7REjRkiDlOBJuXLl
4EtN7Y/vI8rEI8ZViWBKDLeP0/qoVJMmTVyDBg1c3759y6idCyZfSGggAw4s
iHqXnCpmFXBr2DdYG/HVsoqOMWvYsKGEQMQyjDSiinWIrzRu3Fiq8BNHahx5
99133fHHHy9cKZcfJt9Xy8aM9bhozm1QGj3avHmzlE7OQzstGkI+r0l4nlHg
AyS86Natmzv88MPDuHLcuHHiP6677jq3cOFCDSOisS5TOZkwYUIoO8uWLXMV
K1ZExDLCGoR/++Snc5fzcaCyMnDPOCqxgnfccUeZ6LYOKAHtwB/r/sfU/S+l
PfXUU+6II45wU6dOdT+KzY91U4oNS9hDDz1UAsYfxebHuqnEpozEvMR3hAiB
Iy4dLTknl4B2Sgnq2vp8yZIlki0g8iCLoamgdF68vFuwYIEkLYgrqQ7MRRdd
hHN2c+bM2S8BJinw+L/0XB7/2/XqP/35/wuuN5DPg4J13063fNkmN3vWajd+
3FI39PMFrn+/Wa5Xz6nulZfHu25dx8nPri+Nc2+8PknKb705uZR7uev4wCq9
/tpE+Y1/r3WfuD/1Ms9+Il+lij2337u/mqlD3ZdeHCvfA54m+/xtphvw0Rz3
xbCFQTj/bWAAVrnFizYES9KtbuvWnW549Iiul8+ywUptTxD9b3KTJi1zn34y
V5otJWM40L36ygT3crfx8vOdXtPcwE/nuS+//MZN/2qlNLNq1RY4klluHyjM
2bB+u1u+fJNb8PU6+dqYMUvc50O+dv37z5YeB1ClgiFNyDRRnl8F/s0ek13f
PrOCJfIi91VQb+mSjYxgQPQArpTPCm7Dhu3S+T59ZmZ4F3QYbPj18cdz3OTJ
y2WAO3fududJnf3djh0/SOfnzV3rxo5d4gYOnOfee/crqVdGOFxWGPFR0Osx
o5cERnZ9sPTf4d6P7s7l8lnerQ1YP3LE4nD6APvg/eluYjA9wbRc6fVgxYrN
wqOhQxfIV+ADPchIRKYHn3w8102auExGwFT1iO7BpQq9dOl3IpMvvjBWBOZv
vWeIvMKA+jrr33//g/vmm40iw0wN01BKWFdWusBU0a25c9aIIL1cWOEvFEI5
GQciYZIJx4K5u0fboe68eWtFQN9+a4oMLNNOGZGoUSMXy1T/8MOeLtEjq6ON
bd++SzTuhefHoD5u6pTlbvfuPc3lcRmRv9mzV7tBwWwGs29KBxuHBe0vXryB
b7ePbuc87fXevfvctKkrZEC0A2greXaADBixQWR4Budo5913pskcowDPRDdR
W5sABnnv3Gm0iEvAANdGRWjTpu9Faj/8YLpMBnLBIPjeqpVbnoxGP0c5sWnT
jsDsTBFGB9PcSb/KrGMien84I5gF5KO0AKOkNPpYNPLZiswU9Hx7qgx73bpt
XbXLzDNKyBwzOy8F2AwPMxDwvGU08JkKvGfPXhF2ehWo5uueMMNqAPlH29iH
Xbt2u2bRqL9S2sKF691zHUfJqHsq5ObN34vIwlYgA/vspgSSBHfui4Y8w+so
k/3+e18xtPcVddu2XW78+G9Dq48GoT18/Z5o1NOVhsVGnGBYXxX3jRt3uM8+
+zpg6Fjh95Dg9/Xrt+lWaSZDk3an1OXb7yuVp0OnKQ0mP99ljAjqAB0jejF/
/loZ2/OdR4trgrOMsWHYq5JuG+br1alKQ7VhPKVByiZxdF8sFBOEJo4O5jaw
dbdph4q0aVY2T9sW5H8YaA2ujNLn2jYjnzZthXACWcJmBpJQP2y7CLtO0p+y
tHySPkXYcT+UhmuLzMGcQK4QFuYAyxbM0U1hi0XYrymdZ7S/sNEGxgctofSl
P9rALqLhGK5xY5dCuzFsu3gbIPm6YSxA5mEqpXE6Reg+cULHDqNE1dCZ68M+
FG/LIF8fTlTajOkrQ6GbpH3AwhJ9PdtuhPxECDV+VCEqlHR2cdn0MnlaP8Gz
DF2CiRanpDYIl4pydnruSzdjxqqrou3L8UoLLJVr/+xIUecZYU92SfTYrs0I
iZR49vtkKLSfgEhmUTtEGAM8NnX16i31olGOU9rX89eJjIm9UpSVKzeLw2NY
geW+LBrlWKUhkR2Cdvm5wHNRBIOgBLpZNxmFCAhbTWmRZ+Yxvowq8GyXRKMc
ozREAHGktMRDwWZ0aD8Ki3pRMgreKHCsUvrWQyHuYUSBsF/goQjI0VqXEBW7
QGmF1iWwIBpkyRD41TrRPTCUHm9MliiG0ipFIbTCsxFUBGJyfjSKba7gD60v
a5UWBC9is1Do85IhiImJeymtVxomB2ZCrx0NUUNpKA3KQ2mjjgU/D5cJ+AO1
OCcZhejA7PAmpRFZtG0zXOT418kQOCd0kNJm7QhllImOBFN8VjRKdY+pTAOl
bUrDISOkrGfOTIYYPGi+GExK25WG4tNBjOqvkiGwPEb7XmmoCk6QMZ0RDXGU
NxAWaJR2KW3RovWuXdsRInunJ0OwpCAwp/SDp4JAYB/9LTdBsIpYGOSC0m7P
jhAsEzucmtw2YYbR9iqtX99ZYkgonRwNUU1prJ8JbIXO5376gElgaUTpF8k4
RNlMfYhj4RP5ABSQoZ6UjIN9MNq+DM8yDzDtmHVwTkzGQY6ycMy3zZq5WnAo
nRCNU1VpLI6NnfLEAhiWGZgoSscn42A30dEQx468ID8YRkoxO7yGY8Id4th5
EFa8FijF7LEbji868mlZbHiDLlM6JhnHPE0ODqLMkofVQwzOkUoLvLWIbohT
wdMlc61HJ+OQSSASDnFsAwdDibmlVLOwTlptTCDeK6xdUR+QvCDkpFQjuRc5
3DUcpBe/wahS4JighjgH6YNg/RWyvnoxcCrpA1Sf9MW+0Krkxfm50rDQ+N4Q
p7I3LmYbN58CB6uDqQ5x/lsfYHxJCxSociwOGQPC4hDnYG/ANpFVk3FQQCQw
B4esnnm6FDgYOgQ1xDlEH8C0tWu3eZMSi4NvyJovwyFpgAnwcHT/KWkBHnHQ
ON+Cw3qRIzWH6gM4QqKm4MuuBOdr47pAviFvF/A1BC1+F4p7yFQey4r3Z1H8
/4k+IOYw81slbLYYBzTzLbWqKA0lsphVnvyPPsDnkKrMbr1oxxzjGsaqfKja
l9Uw6s1qO7vhop0UjGuYnGiWPTjM0xuTtJ+FDRfhQF1cq+SWyJXltEoqmBWp
32r+1XS+g2ZxTY4atVjSJmGTh+sDsjb25Z9GGwjDYYvk22+/y8WBYUS1KXFY
+pJDyMHBqpLoTYnDvglim4ODshDRpsQx2xbiHGH88eK5I9LgTMiPQy7LBCoF
To4hMBxUkTx7YRyBsdo5BtRq4/7JUaceTSGu/DRP9w5PxrGJyMHx45UUOJH9
YcDm/0rSH1JZ5i5T4JiHzsFB3Qj4S9ofsjLDhy8qMQ5JNItyS4JDHGaLjxQ4
Jmohjvk5X0APS8Yxh5uD43e0JDih1/sn9SdLO//po/lH4fha/i/sjwlYSXEi
pZgMqXW2JNpAvtbcdUlwcMwWXqXAsdVkDg7LcHa6S9ofP6eSAsdXniwcP2dQ
kv74TtXHydKqHKn5R/kq853EotaTFL7T0ns5OGR2PtLMTkkiAX+2U+BExgSa
006LExnh+L48BY7l5kqKgyIT1oQ4FgHi80ifUEoRAeIeObySg8PeqoXOKXA+
Gzxfdu1zcGCcaYPiuEw6pJgv27p8C9gw4B8ZEfD7ic6CbpTkHdO4brB1QMga
dsOWOqTnOEZAqWCBVbzXLQvW0abzJMBtFZHVLOlQ2+oqaLZ4byvGjZv9GY5z
5HSA5JlFqgUdKN67f3EdIIHEBlLYAX9JbTYucUmd7zW6cjGtIt+h4fNbZUKG
6EK7oNXivW0Wl7fJsd6WQGGhSBLL70D+pXXci1lFShlZ077GVYk2IJE5OEs9
IVO2JfDzZJwcVhgOamdbrClwIvvzopc6SIGT44Ast0gSxhxiihwlUUXeXCcR
gC2xU+CgHVihEMe+jIY8r5umVZNxMPhLlmzMxeEMm+2M+DgCY7VZy1uCP6u2
v2Oaohfs8bClE+JYZhuhR/gppchsk4ozr5mFw5ECQpeUOHQ9XB7z6Wfsjbsx
GXvbQciRPttBwLNY0JwCJ0c7DYeDPMbn4vTHdkb8xHBxdkYO8jpqOwgpcHIy
/7bjw5EFC6VS7Pgw53bqIQuHNbydQkiBQ7YCYx/i2D4Yxw44LUSpZjIOka0p
TxYOKRoLbCL305gMVjFhbdvVs3NAlFLs6pFaDJNOPg6+nTRuAk7VqNk+wOvP
0099IaUUu545Nt1wyMtO0f204uCU9/rDsQ5KKXZzc6SvvNef6cqfFDgE32v8
4Nt2qTnrxr4lpRS71OzLWbNZOEiN7S6nwJF9wsCuhzgW9JDitvMfKXbfM/uW
k3NxsMikDxJw7FRBjtWxXD+bh2baYk4VJOJwSMisjo8jMJG1LRwiorb9mxRn
JPALWUl7w0HyOOWfEgchW+p7Xjv7gSO0A0spzn6gyPZ1eWJnUZg+ztNQSnEW
Bd+ZFXMbDrNta8IYnLjjNWy6mD+NOV5jEP7xCINgJLbQTwHh92KP0ji5Zuuq
U5Ih6LC1aEeNWKubBU5x1IjTg3Z+ZbfXM9s1V4iUK+mIe6fyxvXWA8wGy0ZK
dtCK3L5FSaeFPSjJJUtxPfCtiJ0WQ01QF6yvnhYr9oVD+dq2w26+zu9Umn8C
tqDt4l3aU7B2Ny3yfZMdr+NdHZP+M8IWi3bnTb7tURuln6ncoTQ42+aZ4eKC
fhm2WbzLY+I4zFtlLIH8tjkPZIf7Ctou3vUqcW0TSNnxcjsNyYElS6bqaciE
I9357iOJ4zbyXPgYJ/7g6dZfCLdjjnHaeVLfvm1VGpGqHe1MAeHL2Ral4cjs
8GHMeVSDQCnNvm327NtTrYeJ+JydDOFncQ2CY2cWHKSA4Fix5QXseC7raTvY
EHM8144a+1q+UWloOK8YUIo5JGwQ/ozYtTDwpmWLgbLhUsuDEASrSGxsTt8q
YtmMK7WS28ZJ2KLDTkpzwsymMuaktEHgnm0vZ51ndVr95XNZsp6bDMGM23GK
tR4HmjX9RBINMUe+7ey5fxpjjdI43mYxbQoITJmxc7XHH0wKpfOTITiCa9Zn
lcef1n8dJrz4TTIEwbxFhCuVhmrDTjQk5hz+MXl4sUJppNI4qkepiBDLlYZW
DNNEyW+TIRAh4jpKy5RGPGKrwguSIXhFzIKmb5WGPBCPITMXFtYMq8g0WjtL
lYaXYhlNsB7zOoW92uEfX1miNMInjDylFBAsL8zIfaM0zi1yxoHSxckQvGPM
W7yUFisNw2cbADFvlxgEQmM+Y5HSsBDwApm8NBrCXrmxg2T8W6A0MhsPPzRY
WB3zpoxBYCeNF197PXuo5SCZ0t8lQ8ALO/w135voRx8ZLEF+zFs/BsEi1DIK
85QGD4hWSDpeHg1hLzFZBo5/c73BDdIj+SkgyPOTZKI0R2msyCwJFvMSlEGw
8DIxmu3xh5wcpSuSIYgbzPXM8uTiiVafi3L5L3QJwgl5ODBDaaRx8VdM8R+i
2zYIMky2rJuuNAzfvU0GiDRcmQzBZQp27vgrzzY82OxTWeJcFQ1hr+d18QYy
1ZPJFs0HippfnQyBMOGjKU0JZXK38AJmxtwMYRCot6VjJysN/j/+2BDZALw2
GYKpNB2dVEiscUnXRUOc5PHC8lETvYm2N01SQLDUw2JTmqA0u52B0vXJEHDf
7PZ4pZGAMhd8QwbCZVK+xbjsOF9wbS+u+m8njVUaPs/UUt9WzaRKinepb9x7
syRGzbmMURqm3k7v/6/XfJo7bgvWhyYmHBu1IyejlcbbF3bY7I9RLcQuULNH
YxcWEXvZIYVRSmPHxjZUbopqK3ZDN39brANN8EYqjZeYjHM3R7WVsHebry3s
tm1LjlAarxZaluEWX0iKdDNnvlbtDXJWE6adXyiNVJ2FAfVVLzJNeNdTRlxk
mU8NrC1CPDsnO0xpxPemg7dmj9C/rLJiDCxW0WKqoUojRDTYBtHWwd7hh+8W
Q3ymNGQML4aRuT0ZYsaMVeJqKQ0OR7BXgiHS1ndEQ9j9Bpbk599Ab3D4TYxt
w2QILIoF458qDS9CPIU7uDMZwn+d6BNPv5s98Ink2P7kQQjC6folRsqFLpTs
bQ5c7/33DpCFa6Potg2CLtqRhI+UhjenbVbfjZMhmDaSFpT6K411aIsHB4oX
vysa4gyl4fxtY6Kv0tgPbvX4EGHm3ckQuBtejabUR2m8yNmp45eyXIi5fuOX
SmMOLP3fW2m8KWv24M/JEETSpgUfKo1bA8z1NomGsNtK8N6WhXtPaZTRGHQ5
5nYSg0BobOPmXaUxMNZaJNnuj4Y4U2m+ze+lNGboySeGyqmapskQxLCjdfOy
p9IQNZQOqX0gGYIeWPblLfnMvAdvV18Fz2PufzlLaXhefCOlHp5+oaIE3s0L
69dZXvPsu/HzDaWRW7v/vo/FvbeIbvtspbEXZzu4rymN4Iq1Esc0Yi7F+bXS
kGBzGK94TEBc9SDVQ8koyISta14uxAQ69Eg0xDmeZJrN7qo0sgDNH/xUTOCj
yRCsLSwf9ZKnYuQK0eCYy4dqKY2Y0nIRzys7LGgGOpisx5NR4L25sC5K450H
5BvH0ioaorbSuC3DUlJ2uRJlbtKAs08kQxRk1/e4jjoWhI2kES8HBb/HXPR0
rolkYOotemivNHQU0SWWah0NcZ7SCOXs+E47T3SZcsnlFlYRq4i3tBROG6XZ
TQIYvZhbsM5XGkk220Z62mjBeuuZp7+QW+TaREP8Jk/3/6p8xGYSNcKZoHdt
k1GYBSaPn096Ams3PDwbDVFHaWzEWhr5L56usiGKGwmgY64e+62nEbYV+5jS
7KoJjHDHaIgLlAb/7RW1h7UjjIv1AdwKfn8uGYWZZBr4+ZDS2C3hsAZS1zka
4kKlEY9gwhFru6ONUzAsXhDzYJq6RKNc5MmDLW2aKY1QnRwJ2YPMxU12HVbK
v36T+josSe6Vwnk11accrWGNyUGfjB3TisX/Iy/5Gr5EaYQQ5LQoNfGYiA8k
MxnESF29XkT+NRRZLMk68mJ9Sv7KDhLdozTStOy+ECq8XBg23x8LybcEuVRp
zDsZaBToLqUhwxgNnO+rhRvI9yc28q2n6no2lOwG9/H9SXnDwU4OZhKKBZLe
vXAbCX+TIl9zvyvUHIb1Dm3ObmTRAPJ1XyCK9OcZ8jV8mcdIktakTRt4Go3p
5ChBEHr2UC3IWTrG/WGDfJNXT2n4U7vt7GbPnBFcMoGB5LyVPdikJeQVSiMZ
o95asyEZz2ch+9Qpy3tGm4XfKw13S6SKfbreQyEHh+uaNGnZO9Eofwi1cIvY
fWz9NR5ncfD0JUB5LxrlSqXhCdFFvN6VioLrxP+wMAkCsA+iUa5WGkEz4kV8
Uk9R2Nq0S2ODWe4djXKN0lh2mXmqq3MPX1g/YIxxRXynTzTUdUojeKX7rGwu
UiiGxZINESDFQPjVz4MSJJsP7BTv/dLmli076ygZ/SGMxw8EjI+54/VGT6nx
rYhNYPDsEk28nN04SR6FefgkGu2PisZ42PzGhAY6e5aiYdiJvOAeh32JowZF
o93s9Q23itsNfNXpisZigb5hAEEFfUg0Wn2txhBQO4aECUNAT1TLgWAwrfQd
/hErBFM5LBr1Nq1JeIvHpRY8ZI0eKHNmA31/ianRG2TYbsS0ex1HRKM31OpE
vKzubFXCcKnO9GdeSCkvPSCZR+t8hzEQGRFwBwo3OrqVTBqigrybRCextsgC
CCwISLgi3LgspgxhP0DHDTeZHyYD9UKtgzqlpAtlBAJhJj+/efP3E6I70USH
Ybclc3ULlpApgqly92S38Zm9xQPDEcrlsN0ydxGTAEdjSG4Q2wZ9mxbdoHz+
W1/TLb83/tf/Xkk1hdNFbAvwX4cOHTKuh2e602Ln9mvWrCkHzML+F3rOO1Tc
lhH1/M4775QTVJzb8p9XVv1nc4A7TYYOHcqf5sn9Slnu4Xc1amS07c0333TT
pk3LYmVlFVeGwzUplPCmNB0MS756tT/68m7ixImS5yZMIoyhF5z3Ov/88/nD
PlLlqnhGuv3+DijRkAE=\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"runPlot", "[", "n", "]"}]], "Input",
 CellChangeTimes->{{3.46548229950303*^9, 3.4654823006584044`*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {Hue[0.5], InsetBox["\<\"X\"\>", Scaled[{1.1, 0.6666666666666667}]]}, 
    {Hue[1.], 
     InsetBox["\<\"Y\"\>", Scaled[{1.1, 0.33333333333333337`}]]}}, {{}, {}, 
    {Hue[0.5], LineBox[CompressedData["
1:eJwU23c81e8XAHBkJSR7773Htcc5SoWQColIshJlfbNTRktDkmigUiIaKhXF
vTbZW7aQZLskid/n99d9ndd9xnme5zPO+/W6V8L9zEFPOhoaGmdGGpr/f0re
/PckQ/SNSQrXjedp6QvwgVlBzN/nJiSKGM5dOr4AlLCX2fI+mTB62e2/BbkF
qFYP9Gb0eQWxpaIsya/nofZam/mydxkwmpHePfGegzqDuE/T3s1Q8mfLMB/p
F7ww4jqn/aoFkmrr/iO/mIKFPo/MkLxWuLHSsZwrNQXnBJlHF7Pa4cQCam1w
/4S7d2285653A/don8lpuh9Qf6svcNJ7CLi2b9rQyH2Hy2mpdbc1hkHDdJ9T
yLtRUPYBJ61Xw3Bziu2qsNkoBDHdigzKGwGxyTUtku8IbOwmlc5nfYfFb4/T
krKH4BHPgE2S6Bho5TO/PzE2CGbjCUNqD8aAeUJmY1Z+EBLju2nO3B2Hri4r
MWFyP/BXROyauf4D+A+sMbfKfIOSZKmOa9smYUo2Nznyai+4ujd4KF+ZhIbH
B2rjl3ogm1b04qn4n9DBLuvk29YNe1urebfRTUHG15n9YubdMJV1JicvZgq0
nYKlxyldoIGU2p8Rv8BWv47DmtIJHdt9j1xZ/QW3c9tNKvZ0QtgQ55T82Wmg
rUnZvdjcAaXnPLb5BM7Ah8pwJ/GZdrD8wmQzQex7yUgKG9q2gcam+zLv/ByI
FHwwkfrZCtfEjzVJGc2DHi3sTkpohRD34v/sKudh8FFJwr3aFvDZ4lPnx7wA
mi8HP9OeaYGj2TwiCVYLMAi8KZf4W8BsIqDyfccCRFh+TeT82QR6l0T5m/gX
weWq71iOdRMoyzecmji6CG65refef2gELl85Lr7xRWhrEY6/cL8BRmcGjoct
LwFz6/iIzMN66LqR+D5Jnwp6bqxPP8nXQ72a/tbcaCq0KL1SDP9YB4WBKa97
GZYh/UMY0/T3WnjGuZN+0WIZhoyZrzrH1MK9t3OHWW4sA111ks5p0Vq4sGy5
acC7Ahf07Y7TetdASOrqwUNOK0Ad4RTfy1EDPrrPnp3KWIEitW1tnz5Xg204
rc0D2d/wWMa08bNoNYj/+/Dgn84qXNo1xxFPXwXcGZ7zPJGrIN8RiOGVlcAM
XGaqZasgfejk4aGLlTB3/vQv171/wG23aP9LzkoYlRCG0MQ/4BzGsbrUVwFd
5XXJN5v/QEqZ7/VjORVQSi9jQD68Bvf7nAK9zSqg8Gnb9Z77a6BSS60b46mA
Z3vOj8wPrcFaEdXK4mc53Ljcd1nC5y+Y0V/QTbpTDrEKV/r18/+CSbYDu+Pp
cjhbr6N+cP4vnFl/8V+reTm4sCZ3x4atg6cZf2AeXTnYFoDS/c/rkMtvoLE0
QgEzm5lzb2n+gdO2hT3kcgooJ5nLjl3+B/enuljJlykgrrESvt7wD6a7KMZD
/hTgbnvSyL1jAzIyNDOO2lFgnWszZHf6BnzuNjK3laHA/Lv8WpeBDejb1/X3
/XYKjNk7CZ+V2ARMz8k78pcMPStMATc8N4FWcocdaZIMX+++r3iWuwkk8+Df
Jl1kKNU7wVc2swkCZ3alBVWRodfv8vtf/DSYu+NNU+17MjSy6Wyld6HBk+lX
zavTydC2jzOtKYoGvbQrhJVvEONfmZVNf0CDUfsvTEXGkWGwpv79ic80OJjS
lvQmnAxjDDlmqv00GF42dawugAxTu+LaV//SoNj1R/llPmSYv3DMvUKIFh+W
NH1NOk6GlTLDheuGtFjmcYdL35kM6//4zjs602IPJV7mvT0Z6Iyo7FKRtKiW
dYGb7gAZmCNaHs7co0U+o+vrwtZkYP+Yr/yxmBa/tz7/Q2dJBq6VyyWx32jx
WsU/uTd7ycBP8rS0XqPFrcfWWqX3kEE0yLSXT5AO1SoOFTjvJoP0axGfUX06
ZK/JOHeIiBVn/6zkH6HDQtMAFhaivbpyV0JoOB0qs7jwRBPj6fgWcu9Mp8MW
SeZzeRZkMHp+4wnrJzrMeCsWl2RFhp0TvprdPXRIJ80WrmJLBnPpvZRHq3QY
Wqj/LsaODDbuUrZ+/Fvw7EP2KwlHyGCXtTmoo7cFSySuHzE+RoYjg33+tI5b
8O3k9Z6nnmRwFf64/jV0C3rkHuj64kcGD6eUxNS7W1B+WkwqPoQMvmkBgsc/
bEFHfbz5O4oMAV1WuUrdW/BTlOwc70UynOVW0FtZIfqXPbYfuUmGqIMMNWRe
erTp3ErvcI8Ml5u+jNk70OORdu6dhm/IcIP1XrD4WXos/nHWIe8LGVIsz9L9
ukOPMgXpdeR6MmRWq4qf76THR/RU3dEJMmTTb3tluUyPqwKHr04vkyFv5w9j
Hh4G/G6f3f6AgQJFpZnOeXYMGKm1yTYrS4HP65FTISEMWPeg+fMNPQqUGziG
QwoDDvX6dnRYUqCpiONuRzsDvvwh6nYgkALjLy+0bRxkxOTH1uXs1RSYmnY5
XhfEiBlnpf8N9BP3g6LB/O1kRozu/WhhRyXul2eLbAptjGibcPWlrkw5cGee
sDh0gAmfHU5+PnWjHAQHoEckkAk/3l2ton1RDuJCwt6TSUxYELH7V2VNOSjd
7YiPbmHCoZcO9Ie2VMDOm7vJOfuZ8X7pf1+ex1bAect3uW2nmTHy9d+EpCfE
84VB6va/68z4xzMmUqaqAgyiaLwONTDjgkarjzNLJWidLNm2ab4VrcpFaAUe
VkKQtOKygs9WNJw52ptYUQmvh9IG7S5txY2g+rX3U5Wg7HD2TV7VVmy7VpCj
bVgF0rs0DjvsZMHdYhEHt49XgftGJl44zoIf98m6eu+ohqxP7Ir551mQlu+p
bZxJNQirT6/TlrGguU/xE7b71cAjkvO4wHAbst8KUH7kUgOMv4Vn6bVZ0XGP
FzmKpQ7MChO71exYMWzj0+G1XXUQ679GdgpmxaWPvlZHz9XBxvfu26/fsKLm
1tz9Xct18LslWf+oKhuy3aK1+jFXD5N5zAlv5djxkrfGnxLORpD1Cj09uIcd
Xe/Edb9wbgQPiYnDW73YsQMmR3OfNsLw3QrFY9nsqLnl6GSfURP0xp9rYZHY
jrsKtpufCmsGT7U1Ng02DuTKpXyL4moFq75LT/lFOfBCxV5L+t2tQLrEY0yj
xoF+jml95qGtQD+k7tdsy4EnZ24pcQ62wuMb3vX+KRzo3qD4euxdGwzNdFzM
E9qB6Z/bt92/0gHV6e6iyco7UCz90DBLbQe83D3/Ptx4Bz742r/mwtQJ5x5u
Gzc/tgNHhCpFPl7uBGHrnbt+PN6Bqts+hcaldsGR/FebUoqcSCde7F4x3APo
aHx3myEnHhYq+pWh2gvy9F9Vl/Zx4puj5S8uRffCqvOES7k/Jz7tfOqbKPoN
UreJfHZ7w4kP3Np5n/n3Qbvv1bCHelz46OlphjM7B6GYl58jwYILdXxlJA8/
HoTH5U9z/Jy4UK14wPK/LUMQJEjpMoziQpno1MCjdUPAUf+b9K2MCw/FnQ3d
WjgM1gqeC7x7uVFgfbbH+9QorCX+VzLgwI3Myy//PHg0Cs9nExKyvbhRy09M
1bNnFOjfPRPQvMiN0n/mP77a+x2KTSZNrau4MTcmL0dLZQxk7U4lx+3iwSIz
tjNzXBNAExOoNQ+86BOb33Tbcgpejlz4V7SfF1d6klPkk6fA2Sy5JvoYL5Is
Urvkv01B0da3zttieHE6Plb36Klf4JdCjZMt5cWXZ9gteJOnoTc3tOOoER/6
yTDfpfyahYuslzOkrPjw2qdHzrd154B0Js1nypkPjRa6Svzi5iCJ9Gk9NJIP
C5MUfl5km4c9ZWvSt4v50HW1JsEvex4KO6L/q9PjxxLObwdr6hbgeYKH+6gF
P5bFGq0wzS9Ahs6+/X+d+LGXYWDjK88iXE3jV1CJ5se//C/J+ccW4cTRt/1J
FH68XbEZ6vNrEZzY7tXltvGjpVPjnyOsS2Bber6o/Ds/phdQz7orL4GRuE0S
lUEA+2jec4WdXALNVlI0G58A8ke/6fG4uATysUK+svICaNbhXSn3eAm4xyZ3
OVoKoNbtD5JTnUvAcqdZPdBZAHXSbcyrZ5aAZk+RyFU/AdzMsBXVpKfCysoD
lifRAsjBfviwkAAVpnPifpfcIPofiIw7o0yFUUffsY5MAaRUe2oLm1ChZ+uB
1pnXAphYIr7GbkOFpmLdUsZyAfz5esVY+ygVqk6JvhBrF8BibceWKB8qfBZm
SNMbE8D8xq609iAqFDb+ij+wLIAzRWvn5CKp8PxcW6AvoyB2lC4XeF2gQoba
J9c4PkHkZFZxOp9AhZThzH0P5AWRwU7494lLVLh666Lee31BLH5xlZeWiM/v
9JdpshRESv7HOvN4KpxdOsT5w1kQreqmOFViqOCXbbC56SeIJeP3t2aFUsHd
XmKa/5wgphYF+N/xp4IjI3Ovxk1BjHgykEN3nAo2H2arLLME8YllwomBA1Qw
8+ksPPFGEH/KZD8SQSoYCHzOjCoXxKDBO+uflaigXv/42p12QTTuNyl+z00F
ucgr4S/HBFHjB6Mow98lEFUO8KpZFsStowqncweJ8xlwODTMKISuK/dOPCkj
zueGMf7hE8LgZ2lPlx8S5wPSKpwKQnhsciQ3O3wJVuZYBJUMhLA36wr5w8El
mM5aYDTbJ4R49OgZXYUl6KErG/7PXwiNBsxtC5oWoent08Yb54RQo+lyAfnh
IlR6XCvOuSmEnrs4YiJ9F+FN9ZGU3jdCWNk7L2TwbwGuXqXuNV4RwrwOR/dE
lgU4b9hHcmASRj/nqZ6Iunk4O02ROMMvjHrsB89OXJwHd5ubf7MMhFHMY9Y7
6O8cGHIqvqKPEcb52c2DxqUz0ETrVNd4UxhdLD+pyKjOgNvCle+pWcLIGz80
YvxwGuJbfvIplAsjzUwwCwvhoqYbueetGUQw6zzbyjTpJ7id673HyyuCikHk
PaZPJ2HRf+v7IVkRfJHxm/0Z7yTwWZ/8GWgugu/zDQWP/5sAt20KB1MTRXAb
3Y4d2kNjsLjm6HfsgQh+6DVd/nB0DOKnLl+ULxDBYXH7zYj+75BbN1lc3CSC
zqpK34W/j8LipedSQztEMXDGxOwN+wjEh/YYP5cUxXYZRhWlrGHg9WZ2DNQS
xRetmiN2pGEw3ONzbYu9KBZIRRnG1A1CPL38slyaKAr8Pjl972sf8FIPb194
Lopce3alHxHog+ffLykUfxLF9YCN82Z+36Cx/IeLVZ8opjRY37KT6AW3Qr4w
nmlR4v388eH+uB5YfLQ3eXBdFKNGji1LTXUD74Wc6gBRMTylwvFyuaoLngd0
D+uriWGSXQW1zKALDN2Y/tKhGJYL1nP/e9sJbuCtdue4GI6wPTY78bYDcv/J
pn3KFsMdjLp/u0fbwGjGoTD2vRhyjoX664S1QVP/xYZ91WIomhzjoLSjDRZL
JmgGf4ihimtfk591KyS84BXKWRVDsYrr1+PnW+Ca9RPBj/Ti6NS6c09daguI
GreTLvCI4+2f0aSfPc3wg/SLMi4ijodsOvbY6zbDa+Ut+y1lxXF/Rszew/eb
YKew1kkuXXG8e7Or3zu4Ebz/Jj986iiOrsnxqeuuXyHFZroi3E0cB1jPhLvN
1AP50e4pax9xNJFUe3g+ph74zVd1VkLFMdv9E/ncS6K+uH/ApT5GHH/s+9gu
va8OAmbz4jIuiWN4pNQIz69aqE1xadlzVxy5mmJMA0m1QP1RtCKYKY4p9zlP
5A3UgLghh8jcM3H84Nz5s/5KDYSNlJ+8WySOpfS3ZU5OVYOCqvyWyU5xfPx4
I722vgocLlxQ+DwgjtEbsjxTl6sgtuPb/qRxceS7ln/8gEUVfIu4/kBvWRyl
ykMU81sqgbFpopz1nzjGdV6Xi7lbCZoS+HOYXgKPJgV8cXCrhKs1i9pXuCXQ
hqlNr/t3BRQJWh11EZZA35lMGY/qChj1fxqrIS2B5KADel9SifqP27G5V0sC
9yXoZWcaVcAvty8+iock0ECdv7P/fjnwv+O9ueEkgQcZWC5GhJaDGVPA+zZ3
CUx9ZzVxxa4cHhRI0kUGSeDvDFuJbs5yqKWJkt8fIYHH3GkMtxD1LfVQp41U
rAT6L0qKRXdRwGrt0v2vtyRwpuE/Lf1MCoRZj1Ay0yXwcImxhl8CBbKzDCaD
H0ng5xx9wyY/oj7eM0MSfiOBwZVmcluAAvL39jjPf5TA3e832OsUKGA3k3mh
kiyBYzLBX57wUKDg9sEmvxYJvEx/XSFmngzfJl5QsUcCnwVWtocMkYHRgEGI
Z1gCrS9S//g0k0Hzuqvpzx8SaMSdl+BAJvwy/MH7y5wE5jlccNMrJMNVrR03
bv0mNjlo/fXWp2Qouuj7znNTAp08e3dVpxGeUxGhZd8uiaQR2db5WDIYnD8r
N8oriV9Dmu47EL70am+2LhKVxFvLZzzuEr5MllUIuSoriV+e5Ja8InxZGh57
z1VVEqdO/nN9QPhyqqGPrKkjiazGP7c5Eb7kFdf+wWgiifycv2LGCV/uDL7B
1rdbEvfIF8UaEr48U/1D65W1JC5Zxe05QviSjPmnlB0k8Xyq8Rwt4UuOkoAn
ua6S6Fp9QOsm4UE3be0+WW9JDCxga/lH+PH1qz+c2WckcUdPT5IlEdMollpK
hEmiaYPxpyAiPpAdG5txXhIDTDtrgwlfPhbdWyx0RRLfK2XAPnMyLKZtW0y7
JYnExfhwhZhvJ1eLAu89SUzeHhwRbEOG29dTjt9+LIlqQV39ZQcJbzMdSed4
IYmT/X6/eg+TgRQr0nr9rSTW5Q41lLmQIX59hHnbZ0n8ITmRc8aDDJ1nn+Hl
Sknc6Iis/nGKDLILvmEMjZJocV+1RZbw5NlTaq9jOyVR0KIoUimaDNXjSz82
BySx6k19DJXwJJ/bR7HoCUm8obr/9vlbZPhoZ3oz9DdxHtKdHwaeEz5vZqih
bkri6fMtugXvyeBoUb8RyCyFTqa5B4wqyPDH+NBpPwEpLPv4/WDqMBksP/I9
+ykhhbPMu8TdiOvrnmb/gJeiFF7T+en+g4YCBnKe1scNpbB35ZGSijQFojhC
lR1cpPDyPo9vScEUaLhq6NHuKYXnvI/1ml6hgAgDzQPb01IYGzuy9oq4H0r/
XN62L0YKFV2efqxsogDN93tT8EgKqfO/ngxql4OtyzHJL7lS+O/wBVLCgXJ4
1C3lZFAohakiGXYz/uWwsyG/jlQhhe3X63oYcssh7n3pc4VxKXzz6l1okHwF
dKjFDT+bkcL1j+/uoWUFSOft5ZdekcLNL89revwqoDKj5ZIokzSetYw55Peu
Ahgvj3pxKUjjNRpTqoU18XxxYpT55yeNf1QXLQ7mVIGJOuvKzxBpjFHw8LBv
r4IFBs6arihpXCxjaxenqQbHNyInX1+TRt89ao18R6tBhlm74ES+NPLy9H//
KFIDPQMG52zfSSPfXvVFDdsauPYW9xt/lsY7OW+LYuNqYNHVaoG3QRo/TQq0
vZ2uAfL7E9r1v6TxdUbw7M26WghJPMn4YUkau2bCJ+m21IHc8TPdT/5K40ZT
ccwx4zq4wRoZHr1NBm2NYOfQuzpwPpH8RV1JBkdDqu4Zv6qHFQ7K7ru+MkiN
7Xtc294AeRPVvPFBMuj67d+HbSKN4PK54UdAhAy25dN9OuHdCJXePVcsr8qg
gmh+s+tmI9wqnWv8lyuDF4X353QbNYOyn6iDx08Z3EfDPX94tQWGTaXlDizI
4BOF5pDjsq1wm09x1fiPDOoo3qbnsG+FtXLte3xbZVHymVDeiXetUCtgPVgv
L4sbc3/a+CPb4ERNpJeGjyzKBDpH+ih2gIeRrM3KGVnMrTrrH+/eAV5vWrRL
QmWxlDmk++j9DvC5L8Ow+5IsaixHMe7b3gmnzzQ/cXwmi9mPs8PsaLoggk9q
JGZMFn1f8UoPMPdA1LXGWrNpWZTaK6f1xroHomnDXm+lyuLLEFdx99s9cP5X
Q8ztLXKod4i9y52oLy6WnRXNkZTDyVXRTgHzb5DsXe/c5CaHIW9v/JAv74eU
/pBdt33k8AwTgyuFZwDuHBBTcgyQQ5/AZKHDvgOQZhiyNhIjh1y9NkyxvIOQ
sV00fTlDDoVv3nnPEjkEeR8Cu4QH5LDPhK9Iy3AEKEwCB04dkcfiHEP6T5lj
MPFE1bL3uDzmL9TsbCLqM1Y027XXVx4LM4t+J4qPg2PYGW2pSHk8xKJAv/Fk
HOYmqwT6HsjjsX1khdzCCRCpDxq1HJbHXw0Pdy3NTEL4tYZgRW8FZLzoGhtT
MwMZ8qN+aWcU8PA2Bkku/lmorPztyRimgOVN6e4dPrPA8U/ScfSyAv6ds9R4
zzIHOf7hRvfyFPDrzd6GY3Lz0Gkjy8Ayq4COmffvK3gtwNqU4UboigLa3N8h
MnVtAcQvHfg9vqGAiS7xbNZvF8CvLOonZbsiJlPaH7dsLMAW9fbGcA1F/Ky4
ynH75iLIN0xW/9BXRJPaKkvVwkWw8dkos9+piAXDPvxsHYtwL0uhUOOQIl7x
PG3gwrMEGjvOp/4MUUSxXdNzBdeWoJi5W74mShErH3zkZHi2BDtpVEuy4xVx
IGDRcX/pEnz9HW8de00R87lmf5wjfGc31zd0LEUR910p/57wawn6JzSDjB8o
YmfnxQAHGip4Dl6hF8pWRPmyhPhRLirMdg6nrr5QRC36DyVCsoSXGnUVut4q
YntWWtGSDhU2K2+UvC1RxMbFfJ6je6hw+fO49a0Kor9jRvAeOypwvDMaPv1V
EWWfxTpnu1Eh/cXtIKt2RbRvYynyPkUFySdT9Ip9imjzdjYqNoQKefdM7zJ9
V8SnYhO5E4T3tJLTFManFPHV9YYDFwnvfb4yV1K+SOyf3bXDdoT3dl/YY5O1
pohxT/LXdhG+awp7OBxNp4QqZksR5kTsEEANcmZRQuPlmAJ7ov2Q9z4GfU4l
DCpkLXIjxvM59vgur6ASvhDcM+pKzDfv8EeBKqGE355y5e4OpkK4je3nVgUl
HGKWNWc9SQW6PTk2rzSUUO3f9NYXhF8TjTeGr+krYSkl0EiQ8C23tn2wr6kS
RjpS4JAxFR4o5zOYWyjh1ZIrawcUqSAjvSVN5oASHkw79ZKThwovhZwUtxxR
wvBPXj23/i2BDtebz8NuSugeaV3U9H0JzOmOjdwPUEJTje2vE3KXoPXP++Dw
MCUM1Mkw3XJlCZwWWBkPn1fCkd3USXOvJTg1XKzImaSE0Rq2l/YILgG1e8eX
ubtKWNeWTbt9YRGimn32N2YqIdXyZUp51SLcKOUNufxKCTsuc2QLn1wEviJ/
Rq8PSnhn6O2REd1FyCqoTNtVpoQyJLHfDfSEBx8EfdloUsLrl0dOuKcvQEdE
E+N/s0r4ftkga+LVPLgEyaQfXFFC2Ycn7qgFzcPEySgl9Q0lvHn2yxl7rXn4
7aho+4tNGbtvn9q613MOBHUvph9XUcZnKixMGbaE/5aMlW38lHHcu+v78+0/
gY2TpqUjRBlzDPTV1qInoVi9PNg5WhlJo/ttg2d+APfpPSU+N5TRzl8oN6tl
AmonbSzjXitjlIBfT0b+GPzHtGN26ydlLBOI+LQoPwaSsu23kijKeD3/8vqT
nO8QdeJw78M2ZQxmanh7Nn8U1AeP+XykKmPT8ejFt53DMLAuwQr/lPGUksZ0
t9cwXBUae1XFoIJOn1TPX1oegjFHn99tvCrY6b/QMWU/CLdCFe8fEVPB+oGh
0uAbA2CSOm0yLKeCeeln2i809ENae8DFGT0VtDW5do/2SB/sXtRUDDFVQV5n
GgX7nG+wyLHcuGahghunDBWX1nrByiach9lZBQXLOLpL3vQATd2FbMloFbTf
uWO+z6kLCn7sMs9NUMG0M5fll1o6wYmRcVrthgouHTEpTdzXCe92XdUyzlTB
vsA11ibrDjjubtVdkaOCPZdrHxt3tgP7BfZIy9cq2HDZKaPYrR18SpPLD1NU
sMX3TrZPXBvwDNh5DdapYL9si4KbYBuU/+Vl8WxTwT2/XFgWifeZsP79A0Hf
VVA3tpvtLLUFWt4+Gb7GoIoOEebTQqRmiG7zjOdiV8Vg2T3zDXeaQHFBTv4e
ryo29sm84vjXCPGq+Wdy5FRxxjOt5E5fA2hYn+ZSVVdF4T+nrc4dbIDBU+of
3umpIt3AY/vdTV9BL/fdBsVCFQu2lrTXtdfDeM3Zx+YHVdEk+RStvks9JE/o
7Wl2UsUtgRnhP6bqYFrqy/X+U6rovTreGchZB48yqoR/X1fF3dx1RYk3auDB
UeVu+1RVXH130LlVtwbSBG/fepehisUht+W0x6rhRqobY9ArVdw8lLA4v7sa
rtjVkFs+qOJkg/RH/r9VEM+pGqlGVsXnnMUu64VVEHHj79x0iyp+PpUlmKlY
Bf9Zueft61VF9+7930hTlRDAUueRN6KK7MeQXTO/ErwupvZ6L6qi8qYnF59u
JRw8p1ExyqWGfiF1Hk+8KsDaKC3aVFgNK/USPiXoVoD52oZulrQapt7fmWbB
UgEmZxvyXbTVMC1g+0WT9+WgT9Ly/myshp21rzbtr5cDaTFdQmiPGrZeHYoT
9C4HpdPeqT0Oahi8efNUpFg5yCo32eoeU8ONp9WCdBsUkJwibUv1VkPukUzD
rYMU4PeiO38oTA0TqRaPAh5TgEv6pEHheTU8tC3qYulFCrCPNlM5rqhhuhkj
hzfhOXrXhyeb0tVwSsH76VNDCmwK0UurPFbD1Y+uXsoyFFjr9R1MzFPD9crr
IrPbKbB8tzVtqlANI10izL//JcO8vd4hixI1fPxIK5f+Jxl+cWWyPa9Qw6Wj
q3RW3WSYaGWoZWxQQ91hOPS2mgz91u1Glf1qqEqVbawj6v3ubQa/JcfV8NqO
ozz+98nQVpf15sKMGn4R/3Rc4CYZGi8x+Q0vq+ETScuZujgy1O4+LQsbath0
gG8pnPDc6AXfeZst6tg8Kf9SmvDc0PBD63NM6vgz645vlTcxH7TmFWxTx4N7
67kd3Qh/ZtAzD2xXR/tt7HM9R8jQ80/Xk5VbHYupB43M7AjfHD1Vbsivjlbb
EiF1P5FPSYbYKWF1jIof3Pl1HxlaBNui7omr4+sResZhwltN4Qzf6qTV8dS4
y7NWwmNfe/R0/8irY6/f210PCa/V6vqlyKuoo6x98z8g4urUzIXDGuo4ELa6
UkTElcttNpe01XH+eOCTTaI/xY4xv0hfHS0u0fTwWRAefau/dcJYHT2+fDn9
j5j/M6e/F89OdSzpIZu+JPIrDsyqMNujjoIcRUryRP4fW9rFQyzV8X6Qo/FJ
Yn1Fakznntio48JLmYkzx8jw9oZBX9tBdQzWnMsw8CKD+312hmIHdeyzTYoF
fzJwPh9VfeSkjqsuKc7ThOco74ocL7uqY4Pj3k0gPBdAuRp7xl0dH6nqXNcn
PCfW5Jrv4KWO9DqbOj3EeTV90+wy9lXH4VBQFbpHBmXqNwXWIHVs6ntXf/U1
GfpoXh1a+k8db/VLLbz/THieLS76W7g6PlhjfhNbR4ZJWaXW5xfUceZ5Wczm
GBnuam2u3UxQx+N7uppfLpFhD7ZLh14hzkNoxnCDjgLZRyLDdt8izjsUWaKk
iHe41/7HynfU8YxfvEYeiQJ0wVINXOnqeOJW6mToHgq4XfsqNpqljky/TU0W
T1FAuEyo5txrYrw/ZpEepRT4+nVu3vOdOi5d+fnlVgcFInoqBK0/quPKiyvc
br8o0LNw6rQQWR1Zf6q9GxEshxTpzzwfm9XxX+2lgoQL5bBLIwky29UxbSRZ
pu5BOSwae5y82K2O1IN9toUfCS8eZv1iN6SOB25cbgpbLAfWq0c9FmbVsbCJ
5/qMfwWUpKrf6FlUx6Bfs6pnb1SA7xP6j2Ur6hg6ZDH34lUF1H7O33ZjQx27
hx9wS1ErIH5uvVCRXQM5Elfn3BIqQWu9pX8HpwaefPfRN/hFJYwyP2X8w6OB
FJdmRuO2SkBJa6caEQ18obbI/1eiCtbtHtJ6qGgg70d7F+v6KggpNrZ9aKWB
E7/HRclQA++dauh6bTXQYjbbef/ZGlhZs33Pba+Bzlrybl0FNRBu6CF4zUUD
H2bGi3WJ1cK5z1fHIk5rIHvhi71T2+ug7Cj33aIgDVwp3joSZ1MHNP8eWiye
1cCpMxpHlW7UQazxm5cnYzTw0zP/e6856uFSaXeYY5IGGsRFW8xIfoVa1+NK
KSkaeGbSs8nG9yuwbE4NNKdp4Gf1T8+7C7/CNdjYufeRBsp3swT6722AJLI0
m06hBkbRHChlj2mEe+WBj7g6NPBerhxtIU8L9Ln/PbS/RwOffBv7L2JXCwhv
SWBM7NfAi+6FzMuBLZCxK+0U3bgGlqaKlzK3tsCTylLthWUN3OIut2Xybivk
V2+rb+LTRH/umqBzlu0w43UnikVYE+9Gy20ExbeDKpOY2h5xTWy3tySZlLXD
m72aKV/kNVF+V4a9u24HFNU6uubra2Izn7O8nGYnlNU/XbzirIljPb90xw51
QyF/S2D0MU3UltkpkHq3G7K91uYDTmji1EWJGtn+brhKt3/u8ClNLD02qz3j
3QN2Bqu/ZCI10dIiDfZd7YWpXMtxyj1NrG0AE831Puj/HeLxPkMTyc809Dpt
+qF5d+b35481MbZx19nwx/3wbmRp5GYeke+V13WNVgMQI/Bw0KVYE/dF0ggO
FgwC95W57j+9mijz29v0aeswMHYLHJ4Z0MQXN4rTQ7aMwB9ps67hEU0MCJHW
a9cegUFyWkfNT03k7OXKwwcjkLtq2nrnDzHesDDjzJlRMPFJqdcQ0MImHr7m
Bc0xOLlX/8tJRy2s2Bf6QlduEmblBareHNXCr+rfewYCJiGI5U/DHzctFFL3
ihAtmYSoxo/9V05qoWGK34vjB35C0iG99dwIIq6aJ92Kn4KiY7qGUw+08Okh
AfNI2hkwNOXbpflIC5/ZctuXHZwBsuRvy4inWpj3TWRpT/YM1I0XObG81MJx
c/n9//bOQv8pnQjFMi18FGYX9jdpDujCtD/5jmjhyRZmssz2Bbh0hIdSOK6F
Fl6Cwhq6C8BquFy79lML1dgr9BZdF4Bn413P1UUtfKOe+sWvYAHk40mreVtI
6NGqp8WzexEKPLlplphI+C63yC6TqN8191KZDFlJuMo5lRJ3fRGMWN7xfeUm
IZ5KPCHZvgj7k7R0f8mQUMfu1pyk3RJ0BHKBliIJTdvXhiYCl8Dx0NKeSFUS
2qTOE/XRErjzvnXYpkvCHt39iVqVS/Djd7LrIUMSpj9q+sE1sAR+vUFe94GE
W/C75U3qEpx9oHlWyZyEzLvTg9nFqPA3mvNcsBUJE14Nxs9oUOH8scWEElsS
1iuOKojuogK9adv1LfYkvB3G0nb9IBWuSBbe2XeEhPYMf0YUCC+y0yc/vO1C
wkQv7c0hwovJ44FP+46TkI21nz/jPyrw1RwokPIiIYXph8jBaMJbzzXen/Il
IdQHGk3FUqG290Rt5mkSnj3YP295kQpUltS+9iAS9vGOvowjfChuVDvLFErC
7ysP6RKI7/f5r9EaRZLwJ4vPS4wjvJuhzBMQQ8KvNEdL/v+7tMfNrvLZccT+
bzM0f0vM30Rzy7DnEgkvzQVXHyDyW9OosGG9RsLPMcduRLpSQfbE8nFMImEW
L4+S3H4qHEyR+y8khYReucajVoQPz1Udufw8jYSDV6xmJuQJ/64k3u9/QMI9
9gMG8zuo0CVX+pLjEQmpRdleXqtLQHdknmL2lIQHOIen9/YvgepVyc6wXBLy
8r19dufLEhwpsZvMLyDhcvqLwwcfLEH89MW/w2+I9Zt6K8WGLcFrkU/sPEUk
pLFlPKJ8cAmYz4toR5cS+xdzVJdrYxFIb/abvyknoe3uP83eLYvgNnrBebya
hL7/ka95Zi3CR7OJC9bNxH4Ja7M+0V+Esf/471xoJ+HoyXYKy5ZF4MixfP6+
m4QVb5IdT9UvgPfWV00iwyT87/Cdr5GHFoC3KVRodp4Y7yT5wdSBedi5masq
uUzCkXPcdqLs83Bavd/U4Q8JLfgTQvyS56A6GX1KabXRZvSQslb4LPx3eOv7
G5zaWGCe79WoOw0dw/ds1Eja6P+i6v7Gmx9Aw9l4/ISeNpa5/6M5KfMDlHdt
htw10sbVpBWuE/cmIO7pifubZkT73blh2VfGQdNXebLZXhtjTIa6mS58B9f7
rn+3OGnjuPHFpAL673C1IYldz1UbudliFJqvjsKo6jIpy0sbC/lklMozRuDW
0pcLAaHa2G1uuLnaMASn25KOH43UxnPP/ZOZWIfA6s0JU/MYbdQc+tH7df8g
MJ7ZSit+SRuZjg5ZeY/3Q9SU3fnmVG2MSs/6TN37DY7UybmV3NPG8+w07V0v
ekHn+RrkZGjjk+gtf/m5e2HBM2vz3DNt9HxgkfzfQjd4jfw6p1qkjZ9yf/93
fKATzMilroLF2hhwrfCRuHsnSGTeMmEs1UaDfTue3p/qgP6juhsDVUR/7xr+
U4wd8MmQZbCuThvtk7ilktPbIVVw4Mv7Rm0USqoMEVRvhwM9sdHXO7XxQe7K
D6pXG6h+sHcJ79VGt6l0S0GmNmBNlTf2HCDyHdnSsTevFaoPNa0bjWvjhyfX
7nr8aQGjZoGoaao2xr3JkfoQ0AwCL6ede1a1cfeJ7UW/+ptg5VqZYeW6NuZv
85z4ad0Ebyw9/96n18HvYh8OvzFuhBsKen2XmHXQfvCKuebnBvBj3lYSzKqD
BcwzF2ZNGkC2+nXEPm4dZMmOFLpj+xXon8Y56fLrILPR0luToXoYiXMwkBLW
QSNKi0R2YD08MF3/syalgwt/zO4rP6qDHV/2hudp6WCP1uYFZflamL0veCRV
Vwc7t+Tq5bTWQEPEjF6soQ7qZLgEbz1XAxf1bq8e2aWDfEfqfeSHqsGDz6tn
914dHFyP6P10uxpMV/Q+auzTwV5X2OizrIb1t4OhWw/p4BzfyY0L5CroTX5z
eNlBB0dkQ68Mn6uCosB43REnYn0P7C3ioQoC1RR/f3TXwbOW1a/tayphIu+/
sz5BOrhIZj7vNVcBDiIbg8/P6mA+q2y0UHEFVN28uPdnhA6OJiYe/3WxArJD
7vL7xumg4TR9SrpsBXD/ELuQd0kHSy/+/HPkTznEHXn+cypRB3eJMv793VgO
7iafik+l6OBm+JBfSlQ5tL02lcpP00E6v4s+4Q7lYCpVnzj9QAcbdN78YdIs
B3HmvqP+T3XQgly3fXGGAkkRJ6oKcnWwZvXtgm4T4b3pXyqzBTq496Dh0b+v
KDDYur5xukgHO5TWPdpCKWBjluD9qpjIT+T883YXCnwpYmuZK9XBnW77QWU3
BZQVUvXUK3TwetORG10qFHhwX/RRQI0Olq9fPVbDRwFW9pytb77qYEvEV7dV
ol6PPK8WtNCsgyeh1dV9jgxOnrgrqEcHj1JuV1Z+JUN9d+2Lwn4d7CqkcL4u
IYO+5QHupWEd3Br0ZkdxPhmef+6N0hrXwSxB7fL+DDLwq7mPB/8k9kPkhBVn
MhkuPZqyfjejg5HciZftCZ+scAUXURd0UJLzY8yjSDLh97+i2is6GLK8YLAQ
SHhvNe7Sf2vE/khtfoaTZDA7xTr/fkMHubNPZlw+ToZ3AymOK3S6uMgswFDr
RAYpWxGKDpMuftAXElgjvJVc/lQhdJsuaoqeoxOyJQOdtmryh+1EnLH/p6wV
GQJzitZ+c+li6p3E3wKE54YF4IQevy6yHZuvmSe8Z3ut5muYsC6KjCjffU54
kLyxn/RJXBdZWBQLTIhYLbDnwR9pXeSrbTnwmogzvrsxGCjo4tWtLI1rRH92
h5/+ESq6+OxzqZcQMf652sCuYg1dXL+dELmdmH/GYM3kr7YuHrO3/9dBePFo
QWyOoYEunv5nKexL5N8gto0jykQXbdsjmRsJLxol3w77vFMXZUX/LfwlvPiC
XnhkfY8u8siMMS8TXhQMzbYw3qeLJY3V0UWnCb/9VC6M3q+LykHyZJNQMqw5
vxcsPaSLl7YrvL12ngwnm4zjNg7r4u3XQbszr5LB/K2NXYybLv6Qv0LH/ojw
qkz35zIPXaTw5LH4FJBBLu2YDM1JXWSKu3s2tpgMjNEBK+cDdXHmpxDXShcZ
zs6tulL+08V3jHPHbCbIMH78Qg1thC4ez9Xl9lwhPL0nOS02VhfL46Knv/JT
YNyrpDHioi42y/LFDypQgPHSGF3wVV3M99bnSTWkgHmNjv+JZF2MKTx+hupG
gYa9faZmj3WRzmafcsBbCsx404caPdMl7s8ipYI6CrBfVskn5emiw/b0m0nD
FLCtjeGVKdTFa7cVDltxlEO7ufQvhnJdnD+3ovc0tByoPtbiG1W6OJZS5SB1
u5yop8/ar9Tp4i2R1NtWr8rBoa62bKJVF0nSZQ+e/CyHbxb+KTUjurirSXgh
0qsCRi2LjK/Q6qHmFcf6uguVsOXUUNAFBj1sfzQUGvS8EqQTmZ+Hb9VDZkXX
gJ7mSvD66sTpu0MPBecy10fEq2Bq3+aEpYQeXnvykkegoQq2+ckL75LRw0X5
hb09q1WgfO3AAUMFPdTNU/92XLYaTjc8KVHS0EPr/a47++KqYdHKPInVVA8/
5xROZpjXAJd/YBX9bj0cFdyx/UdkDZCu31tbN9dD+RqbQ1tf18DZxmmPGVs9
FIq5nDgmWAtr1rf0m9yI9lwvzuj8rQXa/d9Gb57XQ7WruqIuk/VQW2ovFRKv
h/uqVX13KHyFJNXWE46X9fAOD8PMZ8J74uy1Y+JJetjbGPtuy8JXwMb3E28y
9VBmNKzywdZGOL/v1lR7qR7qLa91h/s3g3kJq9LHcj3U4ctzmyttBg6ly6ce
VOvh3UeRalXMLZDFEjPt0aSHb08WZom6tAC5zm92eUAPz3pOPFtlbQUac/NF
vn96WELu3lp7tQ1qP1RortPoY6n2Zs3ZL22QJAfBw/T6OGc509Q+3wbiTDrU
56z6uB72TCjrSDtgtdSKvrA+2r9b+f1eqwPOm23+cTbUx7J1BVLiti4wfxdh
gKCPans1fegtu4BDeiVCepc+TidYKO+70gVZW2b+TlvqI631uXsWLN1ALv/2
L9pJHzOO3U7cxdsDNKZFtFnh+iiQeE1r/fA3cDL7Ud8TrY+prv5e9Xnf4N1e
/pQdsfqoxG1W9WbjG/jYRMjGXdVHEaEa567cPmh1NtnndV8fGyTvcJayDcDj
s9Upyl/0Ufbq7D4hpmFYD//t4knRxxOecV4j+sPgEC0vl1Glj+L6NPv3+g8D
S/zVT9ub9DHi3L+elc5hCL5lM7g4qI++kXdE/r0cAbP8LrlPNAbYsoVl2fL8
d8h4xbSwQG+AjXY7Cv2+fIfVQr1ixa0G2FdMF6v39zvkf7pn9WCHASbTfqlo
DBsDnhrXwBhJAyzzTaOZiByHiZGJ4t1mBngulL8MHv2Ay3y/rdsuGSAtJaip
xmkaUmprv5cnGiD9xqnbi9nTkBl+L/ztTQOsT7/i4Dk3DUV9xk9T7hpgjN6l
iywJMzCeGb/ukGOAgnJFQxmFs7BTnvNFX7UBfmh8w1V5aR5ser9jQ70B5pz+
krq7YB6OXH3f9bmJ6D8h+vJx2zwETDvSZXQZ4M62gNPtwguQ+TrziNuEAabv
Mn9k9nIB1vVUmMcZDDFI8aPj5pdFYJ7aeNi51RBrVdlCTg8sAtf9Fq1qNkO0
zRkyUFhfBMV/wcdyeAzxyzajj4d0l0Dn5e7luwKG2PilZyTv0BLsPMaXeFnE
EDMOc6wLnyG8QCkuOiljiPKFfI2iT5bAI+ialZOCIUYxvGZJKVmCACnXUUsV
Qzzmoi4017YEUR1qYYYahhgW0SAu+XMJLifQsitrG+ISZ4uh2MYSpOi0PxHW
N0TnZjGTHsIvmT+y9dmMDdFoX+Y7E2nCN2lnm/+hIbpobqqZaVOhyMLcc9bM
EOPV5/GbGRXK1wT+Dpobonf6Xu9FwoONL34lNVsZ4oGPukrnjlGh5+gXWbKt
IY77XHI640uFMbabn1/bGeIt7eiqD8FUmC91O/jI0RArXngaWURSYf2M5uSt
o4Zoqlk4wHOBCswS9Odi3QyRw+D0RY4EKnC1dXIFexDtKZ2qyoQHReNyck/4
GGKdpOuAMxErksLBzs8QHxoGZN8m2uuMW3aaBRjit7iZU7XEeDtThU9phxhi
u7yT+Bwxn83eWRrZMEM8zhYM/4h8jqyWpfJGGaLScweDqZNU8Mi9pcx0nuj/
uPxHgQsVApxOlP+OM8THi2e0kfAhe+bUsNFl4vzeN88KET7M/x64eeEasV4r
/rjDhA8t5f+I1CQZYpbxw4QZDir88DtvxHrHEA0OZzt8WyG894bJ+UC6IXK3
ykuIflsCyZUb4akP/7+/yVc+FS+Ba8zDIvFnRPu397zpQpZgvUK60zPPEINj
Gp59sVqCe8z5S3kvDXHTgHfyh+QSdN4qVtf+YIhsWc6jn2sWIajLdH9EiSHW
e+zfm5BKeE+ozr+szBB97vAnrbovglV2d55FLZHv3/8idJYXYGrSte5GgyGO
XIzMVC1ZgMsqEz/aWwxxx80zk2oxC1BRRJV27SWur9YutlLaBTCo25EZNGWI
aVNeY5OTcyA/u+/2fVYjNInnMX9/9BdUa7a/GeYwQm+uAUW32inwCHVqkeEx
QnO+ZLN9pCnIpDnJ9lrECPU2OvAb20/g5bp4qVLVCG22HD+23DgB7w6zPduq
ZYTb47jD200n4OCDlEobXSM8dXvLrqQP43Bd5gltLxghObBb0CB3DOj1yJEz
tkYYaCcTHvt8FB5H7b2naW+EsfRjxwpURwEpTR9DjxihdXZ2deyHEYi0HFim
dTfC1kIWLufWYVg8unaGN9gItXUvlJCtBiHp0YUbzqFGODk0QqObMACqE8wF
WZFGyCPfnqhT0Q++Z/imFOON8Hv0sQtP9/fByAWSB9wxwtys42nez3tAlpf9
RkC6Ea5fLXcH9h7wzfvx4dFDI6TZlXO7L6wbqG33ttE/M8JsT8Xov85doO8d
oq2dZ4SzRo5H9nV0wrm/1se8Xhrh0CEFtd+2ncAsTfu2tsgImadp0pYdOsD6
47f+P8XE/mRfH+QYbodkq3eMSmVGyOt5eVjAvx2E/vN2ul5jhDstE7IuJhMe
rG6kPdhjhHcWJxTbmFoh2ClHKa7fCJOkXKTcC1rg4+x5+3fDxHkENT9mcWgB
Uz5SLu9PIxQ93swY79YMF1+wte+dMcIru5k8dlY0QT38WA9bMMIv3lu+BSo1
gZ3PPdu+P8T5s95eCtjWCOnrwRGsG0YYkFMc+yu2AQaTrLON6YzRgsVwl+Lm
V/D+RLOayWKMNaOO3+wYvkIEi3emh5Ax1hY6c1ib1UFZBtbdETNGMaFfPl8H
aoFeS3CpWsoYNzrTwmcjauG6c+MeBWVj9E9NLcgpq4G2uWcBTurGmMK/o53e
uwZ448/fSyQZYw5JbPbWjhrIyteanTEyxq9S/ym2nqmGcWTjFzM1Ri4GV8WD
UtWg2DlharvbGHc9KLTI6K2Cd//S7xRaG6OV1KVnhjZVUGNDYxzqaowJZ7eE
7LKvBNbvvV7P3Y2xftyKqU64EmxD3yb1ehljtzvbaNhEBXzL9BozPGOM6YP0
sVznK0CMhOz+wcaYzeYWM7S/AjxqBfQyQo1xjW0oIFWiAmbnGxJpzhtjYqKl
amJ9OWglPHuvEW+M+VWxFS8flUOYwPkh98vGSKk6cvxSRDnQ7tTSqkoyxscj
jtayGuWwp4vVZSXFGMNIiwe72Mvhqu/ERbl0Yxwz4Utmm6UA9+30b1ceEeMx
jJJ/vKYASydXa9BTY4xUzPJxSKUADd+NGudcY2SmO6O8GkXUv/di36m8IWK2
stIP1hQY61/P431vjH9z+j1qdSnwTTT00eZHY3RanvNbkKRA9eNTN1rJxqje
ziAWsk6Gz2Pj8cWVxhjIR/5CmSJDoaxb5JNaYxSSLgjn+EZ4zudb4LUGY9zp
8tzX+f//D8uz8/mvxRh5wy4/f0j4L3W6ydW1wxibFaT3tRE+uKZqYb+3xxht
PJQDqFlkCCs03ikwbIziG/vV56+Q4TT1gx7dmDHaXzixTokhg4eOptqvH8b4
LoCVFHiW8GZYvkzHL2M0oFtb+ONPhgPFssJf5oh8hd6fdSR8Y76exflsyRhn
5phuXyH8Y2IitPXmb2NMbmnUu0r4iHT+zmboX2NkNx06cpjwk2L59hW3TWM8
WMU9OUP4Spz+6rTFFhM0vu/Sa0n4i28P/XdNJhN0NkqOOkX4jP3yuV6hbSZ4
2eN6iPVeMtDXrzbTbzfBxXIT71nCd2vbgqtnOE2whjF1bR8Rz1vPfO7iNUHN
odiOE0Q8cdP7bZmgCartuvdei/DfQOtI7nNRE6SZNK78RIzXwXU065akCapc
OGRCJeart+9KjZA1wQ8qZcdHiHzId22vn1A0wcesnn4xhFeLeuvjrFRN8MGe
HZkNxHryhXZHaGua4AoPKaKGWO8Tl7IAUR0TfJMxUnya2I97mfreTAZEPm/C
xCmeZEgaeesyb2yC/SKOvv//f+FFKVW7XlMT5Hs/eNg9hAxRns8ty3eb4OTv
8pKXUWQIypE0fWFhguwLJ94+SiB8+POBboq1CVqJvPY3uEkGNyU+1egDJtgl
dkcgLJ0MDv63pL3sTXD4Ps3EkWwy7FxI2KHnYoJO9JRixs9k0NOiYZY4boJB
KTdetNSSQfW/iI2tnia4jDxBRoQXhf6c/tXnZ4LCAQZ/fy+SgdPw50hlgAmq
a+3/u4eOAszRJ3oKQkxQNwqsdDgpQKVxrIqJIs4j76TCshYFpna2lficN8GP
FuM1lbspMBxvVXgg3gRvqD28S3KkQCOzaabUNRNsTs3doJ6jwDMOxfCa+yZ4
ytP/1992CvG+OLJKn2WCwc7HKVXTFPhQciV0Z7YJumcomdgwlkOt18//vuSb
IImh8MhDw3KY+vw86O0XEwx4HNi6l/BhUHLPwjzFBDfM+f0Em8rhrzdzoGq1
CT48mqJUOFMOrFw+Z3KbiPX0l4pqq1WAykk5v8whEzwtJ/Axv6QCikwO/+r/
boJrX/It6ocrwIT7kq/gpAnOk+p2f2CsBJuyCZ878ya4e4/DBAPxPAvgeeaZ
SAsoxJp+9dnfSnhHkT4WKgVYvyuRJS2oGozu2g2+kwP8XdOw/9LTaqjyi3dZ
VAJ0jFRO8uythi6+MWd/EtH/BUfb6q4a+O3/xPHEbsCEiC9lZdK1cH5Xe3eW
BcGkP6xzfsdqgVlgy+FBa8D8Sdohkfu1wF/pbn/EATC26IVWKk8dGAhKHtzv
DSjhtMVCg68eyucOtF47BXj8nOILa6d62Fd1wbb+DKDPtxejCRn1cDRgxGZ3
GCCDnle6g+JXOFedtc/wCmDlEKNfx/4GoASJ7ZZ7ASgZLuh0vLMJ1pbnkoRf
AeowdwmxyzYDKZzcv+Mt4DVb/8Njoc3wPOZ4yHoxYMWJZLi+vQWSrj150loP
+HBwxIihtAXcnsnRRU0Bch1qkknQb4N7CqvWgbOAcSaKSiun2qAjvzbd638V
3Hk4VO8XAHBtIpQlKSGhklSoEHLO3FlDKktR1vRFRLakkKgoUZRUIlpoISFa
0dh3yZ4l+551JlHid39/vs+d+865Z5k7n+c+M1OAhutND66NrwXW21Oqh/8A
PlG93H1ueR2s7TRVEVuGyFcy/aGVvH8v/LxnPbga0bYn7uzM+waI3XFpWc8a
xMls/punpxtA080xuX0tokh5r2fGnkbw4Gj+rpVC3MWxk8t+1wj9s99v5igg
FoVocZYUNEE1r1Tu7d2IKuO8Bwx5W8CZtfRkuDpid3D0ux6jFuAL/clPchsl
6tZkuyS0ACGUY+qvg1jqt4nlqNsK78SsRh1oiIsE5AV3B7fBI9kEqX0miPfR
8MIvRgesDFUt3X4EkWcX1M8+7oAATr6njBli46/4k3zzHWBT3Fe+cBxR/MI/
g0SLTpA7ve18vh3i8m29yiyZLkh6/66B6YnIoBZLPP/cDWs2sgI1zyIm6Ev9
+zrZDSGh35W3nkO0FhSKC1HsAUfLucsrfBEDFYnSp/d6QGkJoVYVhFg+djQ3
yq8XUg2rbhrdRnyjgMvUbftB5oOVFjUK0V285SA1oR9ubZzo2xWNeJJ5mtXS
0Q9uXNF94jFkPjIFdRNsBkAtxmyk6THibAER6ug4CO/6epiW6YifVuSc2npr
GHL8/vA41iAaEBf258uOw/Sb/omgWkTm4dfjH93HQaWntjOunszfvb4jafnj
8Gx/MruumazvXZOe3WoTELrG4hJ0IXK2ew9Vkp4s3M9yO9ZD7mcgLxv6ZwL+
+e22OduH2Ld/OFtIbhLcegQxeYiMZ0zMieo2CUfSchbWTCH+FjRsNeWbgoie
l+OqXMRNrS68e7ZPQdma6A6DacR5j5mmkMNToOPv+iXoD2L8+pQks/tT4J12
7E3cHJmPixCW/WkK3vQw4j/MI3Y0rR63aZsCOb0NAWOLKdhmekRktzQHLPwF
zvAvo+BQ7XcLug4H7qb9tlJYTsHglI/alsc4wCdRo3tMgILdkaPlJ+6QXtXL
3nFWiIIBRrwrVVJJf/q/kIlYRcGlQS6DBSUcGO+5NF8kRsHmHxfa/pL+UZRw
GesUp6Co6Hp3f0EunNAz//FXgoJXToQuCZTlQqw/vXqNJAXlzEYnuWpcaExT
zVWVomC/wuvIEioXhHulUw1kKGgz5q81QPpzv8SKRw6yFPxvZ7ImYcOFIL3p
8CA5Cmp+Hl5f4syFbP9u/zgFCkate/j25FkuTKdVu3zYTEHtTZer+f25sLP3
k2WdIgWXrTH1SgzigqPE8wNjShT8fVesfEswF57o3dnHv52CDndL1QNJb7b5
B2xX2EnBvUXz256Qx8XTnaVBlcyX2yGm32XSl71HhY7touDlb33eiy9y4ZoE
7Z/XHgq+/becvcWb9LOeyugtDQr+Ojzp3un8/+evUu2v9lJQxSimTI708+50
vqoibQo6GTRq9pHedO3lZnfuo2De2MPBDbpceCHRlfIXKBjbPT9buZULXXpV
sWsICnraTVIHRLkgefFjmCqNguuszQ1Oz3LAJD3Rz4BBwaCrd3yPtXPgZm/k
aQcWBe833IvJyOVAicRFiyA9ChbcHrQ49//fK+o7GcQZUPDces3elPMc0Lp4
ROeDIVkfRRerY8Yc8EonlOsOUfCg9J7mECUOpPbukBozouCGCdotXJiCjfrL
5+SPUvCSeOv1a4+nYHcDtVbSnIIzlm9yX3hMAcP60guR4xR8Hp8W3UqZAifP
WZMFKwrGvZMK+9IyCZkPR1632FNwouxPburMBBRvUrzyzZGCIjpDy25kT0Dz
m5PHSp0o+MDAc+emAHJ+Ctp537lS0MwmV3OOZwIYP79aR3qT+1ctLzTnjoKZ
t6D6NR8KHtmYbdzoMgpOPPsFAy5QkHK/Nfxy/0+4tTr/w+mLFHzWZL5Nr3EE
mnUyRVjBFMyPiealZQ2BU/j9gvm7FIymDnw2e9AHfhIND37do+DnE5dzzaX6
4OZjEbefD8j6adJKdz7uhbdZoVItcRTcZjb36X1aD8y1+53NSqTgt/ZH89uG
umCl40f9lOcUrI0Cq26/Ltg49Wvj05cUtFsX7zYo2gUM3jPVEa8p2GrzTeAv
vRNu7bDdcjqLgkXx0wo/I9rhyYe4fyfeU/DkcF/weHsbZBItdeYfKTioGa//
cGcbNB8xvsTMoWDI4qin7M4WkAugf5cromDCbdeFdJ9m2M0f9GZdCVnf5Xfl
fYaagHEn96pwGZkfe/dUR6smcH6uoTZfSUF+q/WqZ00aIfPr1hvf68n5yZZn
N7vWQ4R8XuKfRvL6NQlDg1914HzOjL3+OwXdfjr8qQ2oA7kNIb8s2ym48F9m
YWJCLfzzkBEO6KBgpqac2Qf1WmguzlJK6CLzkXVYzbnmG9xy7bXu7qPghV+V
SKz8Bk75vheWDJL5q/7evzOjBhhrxO4qDFPQe5vUy0PmNTCXQym3H6PgrRs7
3a/ZfgUnofjdI9MU3LyBPzlwSRUwbNUPCs5SMCndV1nufCVszKo6tf0vBY3L
menJnApotph7dGaBnB/u47Bv0+XwNu3Ox4hFBI6+jyiTDiiHm0u31acvITDq
8n9dGQLlQE8x5+cuJ7CTqbBEXrUMZHkm5cVXEHjvbsf3D2WlMGd8TVddkMAF
H6XlAvalkPH3naePMIF7Z+sZJ1+WgKz+6h9zawmMPcOkvD1aDHOPkmek1xMY
6GoQPLCiGJqmCDGQJvCzQuL1X+wiuBnjzgrcSL5/ASOd2FMEp8b47J7IEygh
3WRjwikEGpHgX7CJwF+SS8P63xbC36HqjGVKBBb8CfHQ0SmExn32VZuVCRwe
2afxfUkhZET+G2DuIFD+edWuV1UF4LhXWTpUjcAu6UPbnjkUQOO16yErtQk8
niDtofU2HzLaZJ/s3EdgaIBc6PvQfAhX+ZB9CAhUHA0lJuzygdbcP3mbSuCU
wdpIu/X5sEH5omAmncA5sXTh4Nk8+BMgvqWBSaBnBE1/z/c8SN9Cs5AwIPBj
xrM3wnF5EObb6q1pSKB6R46vYmAeOH71iDQ/RKBYatqJRPs8IHlZ/NCEwBmK
T0fyHnK/cs2u7CNk/PPDBgob8qBBpuZvuxmB69UY7p385H7F8yqylgS+8rPp
4+1hA7r3q0pbE7jDTCztSi0buOur1SRtCbQd7XuytID0Z3HWLgk7Mt8mpXWB
mWywcI/bvfo/AiNytMx/J7FBWOrqHhEHAoUIQt8mhg2FxafVV54iMP512+oP
N0l/uptoCDgTqBOi8/DPZTZsl9LR5HMhUPq6SpX8BTZ0F8vvXXaGrK9LyIOd
7qRn3QW0FrsTmJ4dObTuFBv0pDhaCx4EGj2FXR22bJgvbtGe8yIQdogd8jtO
etk9X2fWm8AN1mPrxkzZYC/1at+0D9kPGm+dVA+zQbIkUpdzgUD6R6oU9QAb
qt3Pw4QfgQ19gXyyemwIkrLF0YsEtnT/Vi36///PlLAow5fI/BLZWiqkH4fd
VYiBIAJV5W4OWv3/+aLUWmrvFQK3f1+/6CC5NipZoHYFEzifLaY3T655PQZo
P64RmCCvcN2J3O+T1Fd6ayiBAnZ/L0eS3jxT8o7RHEbgy3uw0Z30poLHI2bD
TQKdo8RKl5PebJYKZtVGkNdz49icMenNsBKX/V9vE8g9/5NiQnoTPUz1KqMI
lLJ+LLWc9CZXap9+WTSBhZqHhZ1Jb74oUTAovk/md1l9wkXSmxYeggcKYsh5
DBZ0QdKbwtLcA+xYAgUPy/q/Ib1ZWNJqmPOIwOLQxZPlpDd9PAoOfkogcHpd
/GAk6c3OktuHM58RaFzzrlsmkQ1RHheM0pMIPFDAv6knjQ0s6RPGqS8IZAEz
8GAOG9I9VE1fpBC4JNm6QaaZrIf0uiOJqQRulgwTDewn61HKc/RJGoGTxos6
yQGGIOkas9hMMl5xm3fh4nlgVOpqEZFNxncj9auZZR7weh6xDM8lkF99/tuQ
Wx58kta1CmUTqG25L1n2ah7IeQrZXCkkMPzup32X3uTBlHSKnU8lGe8n7UBh
wXxIKr1z8mw1gUkDvlLNCvlwzNP3P48aArM9sz1YuvmQX6rncLqePN9zXcwm
z3y44znkZNNGYJvLzZaB3nyQZFxwN/5Bnr85/brb4gJ4slbAh9FJYHu1JeOx
bAFk5ChfVe4l53XOb3beqgBqlrvFz4wQeP+naldpTwGYtfAkjYyS82kjs+8N
6cnOlMiUH+MEqpxU12MoFcL44bcfCzkEbkx7Un/DsxBWxk7XRfwl8IHiac2Y
lUUQ7RrScvkf+Xnz+XrrNo0ikKas7fJeIPtZb5f1eZsiUO7fO2axhIqBZ7f7
GWYVgb6KP99WASpq5jcbrXQshmuFS/blSVLx+8YNrl6cEhC+F0XNlKJi9B1X
+SjFUrh3apPecxkqvqcM7Qi3KoWklcyj4XJU/PLy5ZbVVaVQZBbqbq5ERZ4/
ZjlvM8tg8ahw0uReKoaPP7uul1YBoV8ep/RqU1E2Jv7uGm4FiNxWe9u0j4qx
r+5+6dasBFkNE3YOhYphnl1lwUWVAIH3Wq7vp+Krtl+6B0aqwE9cZpWcORUT
gudbM/bUQFU6/zE4TsWzv8siRuxqQMbw1zMLSyoSUTucmm7XwJfgSq17tlRk
LUqifpuqgcUzF+wFnai4SlpA9MbnbxDS0pQzfYGKy2L6Ald61EGzdwHfan8q
VvmXSgan1IGi2Btj1QAqutVoXWoYqINy/eAh58tUrNgbVbjMth4Ec3aLd92g
Yk7vzbIpywa4HR95uiKWird+8vzRvtIEPdr+7wcfUfEFI/rRiaom2N3suJj3
MRXNBG/YhUo0Q4MwSb9E8vipRtHB1GZYGzRWkPWajOf6h6zNw9/h0Un99Qm5
VEy6Lmi/9G4bjPNo2Oewqei0oDvnO95GwlkuvSWfisVD7GwZ/XboaphliJdQ
yftb5Oz4sh+gwHzhEfqViq5HrsgvDe2Al1uXlXt1UtGgaUp53L4LaqUof126
qSgWfId+LKYL5lb5Kzv0UnFaVHHjkeouMJzm3jQfpGLiAW7uYs1u4Ob3GutO
UPGRlr/wPtEeQIvC9uU8NKTwOT906+6F5puXJ2M20HAdu0A1fXwQFgd9kYva
SMMHpw9y+PcMwbazf43D5WnYuiZna8eFIbh43PNdwBYaGu5s+8xdPgwKina+
J3fSUL6so+jklhE4k0cs2wE0fPm1NPLZuVHg5S5al2dFQ6MDToJ6EpMwk3b/
Zq8NDUsHoix1YBJGXHYu5bOj4Se1qeFu+0moGbAYNyTBfSBHyls+axJiWt8X
tZ2h4aVFPKG6BlMQdt9Qm8eDhmts037Gu01BgGlfmrwXDXfzGqw0j5qCk19F
Y518aOiuZun/8PsU7Chw8Zi5RMPaRr7EInMOyF5aOrj+Mg03fZy6fuAcB8T2
PbSEqzS0lqfWvyX9NvOulBV8nYbdbocymko5MOxpnfvyBg03tv/rc+/iQLvK
9K6qcBrGbdqY8GyGA/mv5Desvk1e311D/RtyXMh0+BSlEUXDyfwFQ8k9XHiu
cHjF8WgaLrlt7zdD50JM10DAxfs0PBeoSRMz5ULYo4u/HsfQsHp1kprZCS6Z
X3Hnolgafu5d2JDlwgX3tSmdg49oWJ/C7pM4x4WTDcQRwcc0XKifcnYlPXXk
9veKnU9puFgo+vRz0lusg24U40Qa/jz/XjOD9Ji24PL33s9p6KNgvvki6bUd
ZXHKMS9pWMcW8fh7lQuywbuf5CST9VQNqFlPek+UWiHR9ZqGHcsLxb/5cmEZ
z4nwpWk0NCm/2SjkyYWZ7JnFihk0fOMqp1DiwIXh87d89DNpeH6KFj5lTnpQ
ffOY6zsaOv1WFw3ez4WvnGy72x9oKKDF13VBnfRemvH3rE80FKU6BlWQvs10
GTb8nk3DzWohKR58XEhSCiycy6WhtvAZLddRDjwYkNCSzaOh/c0Nn3O/cuCi
LX2TQxEN6ZVN6XZhHHCTaYsJLaHhf/1GLvn2HLBr9RBOLaPhnUjPJ9d0OcAy
TfjLraJh39qcrV79U6AlquG+toast5qg8rt3U7D9a1W/di0NbeOF8qOuTIHo
/r/fghppaJoVqHF+3RQs5b3NTGqmoXdpzObkzkn4na+YU9ZCw9Nahj9rEyeh
TefIC+EOGiZNfnjloTQJz1XSLz4aoGHgtpV5TNkJcBWfnH0/RK61GOe93o/D
7j8qZ7+N0NCZ9846E+VxYBekOS+doOEJ1/PmoiJjpFfSzJxmaBjhMfJiqmoE
+PzfqKnz09Eljf550YEBqLYdf31QgI4VCe82Jef1QxRj59ZTQnRcuDJUwqPZ
D7LCbzbEitBRoE1am67UB5pPUwUXS9KxuNLVLlaxB+ZDxkLWS9ExxHGXonxq
NxSe3rFkjwwd/72M0lBR74ZD6qmzDnJ0lPA12SZs2AWOZa/7q5ToODu0XOuh
dgfsSB21HVCm45CT2/Hfbj+Ae3t7O89OOvqd/BH6IbkdLlm8rtu1i44Z+q65
DNU2YFBGDQ/soeO60auP531bQXDz9nJ7DTruyBi6O1rRAvfHU9gPtOm4IW7N
rJLvd7Cq/6n9dh8dax8s0Tnc0gwKH5XfVwIdf1bn/rXSbYa0oJTXC1Q67jo5
plS7uglKxVNi/jOgY7KS5V3qTD3c/DMiHmBIx5klqZ86fOvBpGNb5P1DdEzH
TdTIJfXQ+SI5pMKE3I++ammRTB0khY8s7jtCR//9fV9WZdTCaY9tF+fN6NgU
nLlo0f5amNFO9lK1pOPKl1vMnQK/Qa7syLieNR3/RLZrv5b7BleWbXM+aUvH
rnMrm7eV1IDw11e29/6j48H3f7XOrauBrSdeGf5zoSNFVr9/T14VlMZppU2d
oaOlxgGl29pVYP+9XGTQnY4Fcm8C9n+qhGeHRuprz9KR7UD3gsIKoIb5qpee
o+Mj9z0UnYMV0F0icD/nPB1r3hntFPlRDrKgfPyFPx0H3rcdLeMthy8XsrPj
Augo7KLv7p5QBlbvDGTuBNJxs5yErv++Mni43aXL/yodaXqPaKaBpbBGKtXB
OJyOv+v3eTC2l0DWUd0y1i065j0bobI6isHkTrWSbiQddbxSjo3eKYbIFeOj
infJ+nv3/fi2tBhUGAEHZe6R/Wm2JnaI9Fp14Kp0sQd09DqpefFIQBEIzu70
mo+lY/6uAKeRxUWQvJvdwHlEx22Fp9wnSwpBz+2QxlACme+iSX7+W4UQMuD2
p+4ZHcV/HPqtKl8IixvTL71MoePpasO/rbYF8FiE6H6USvZv7FBc154CwAO1
1Kg0OkYcfXM7TKAA/AuneAMy6Zimv1Q98XM+SPFcdvR6R0djZlz3v7v58Elb
rPzUBzp6b6xtrHHPh5mMXeEm2XQ02KnEzdmeD/fGCsb259Jxj83JzcVC+aCu
ZHII2HS8pVsdLz+eB56PvcSUCsn8mB0SyM7KA9H2pWc3FNOxfLdm0EBMHqSt
vdu4upSOPr47Alik58ZuZT1YqKDjBWaOS/jhPAivoJOfR3Tkj/40YqedB8rL
Gy2Gv9LRoyW60WRzHpy6OL2hoY6OCqcFD7gssIHvU3BgeQMdnRP3JV0bZUPS
rzU9X5rouOrB4fqkNjb0ntZIetVKR6NJJqeJ/H5++UXJ8oR2OtbRqbxdb9gg
13v01N0Osn4rDHd/f8KGvA2D5aFd5PrE2t+fo9lgc9xH+VIPHSvVvc2v3mDD
QjTfzbN9dPw1nuGmGkh6qPb+uNMAHb/8WmeUfY4NOiu3HrYZoqNG2rSo3Bk2
tO7/mGE6QkeemI+dVg5sIA4+Mzs7SkcnDWubHtIvr0xuzUeN0/HBTmWuBekb
0WMXnmVOkvl/8ji9xJgNF6z/06vn0LH/DaZuOEh68eShCc4vOuY8N1llq0/6
0Ek7WmyG7Ce1lyHXWKQHz2zW2fWH7Kd/omJ3SL9JnhXpNpqj4/oj/a/9SZ8F
XZgL8ZinIzfknAmdXA8HDGy/zcPA7ZooNPB/z12trUtfzEAMcDxkQ/rtY2jO
+W9LGeimKdWWSvpNNuLFhkleBhK/Pc7UkH67dvdOkTA/A7UPXinLJ/02EXPR
WUWAgVo5FW8ukx41SzglckiIgX+vzxMipFfZiSbvz6xi4PIv7/tPkZ5VTAbL
WyIMtA1ewhPmyIaINKUlb8QYyL9ijHPWjQ0zWeIvq8UZuDfwzLbN58l6fOY5
OCbBwK74FLOHQWwoZY9whSQZONgX71IfxoZ7FXl4QIaBBr7lMjefkl6uSek/
LcvAymsKTwRJr9k33gsLk2Og89d6Xn2yH9S7XJorNjOwQPOp/bIWsp79ZhdH
FBmoPu3keGmI9OxPqoLANga+kO09+HGWDY3T69z0djJwk9m3wRNSeaA7t3SN
kyoDM9eaitTtyIOkRROfr+8i33/WTYmHyANvweLlZRoMrEmedYt0yoMfIumv
B/cy0KT41ZdfAXnAkIg15tNh4Fa2H0UiOg/E5TzimUjGW1bYcLswD/y2WNId
CAYW/34+PtqWB73KrJFgGgNL9nrMLp/Og0wNGY1iFgOP90wJ+irlg8mB8mra
YQa6/Lyx60xsPmQbZXmdNGZg5Ls9RvWf8kHBLEHyiikD7/SeeDz/PR+4J7zt
C8wZGG0jxU6SLIA7PnLzlBMMFC2oabBPLIA//kLPbE+S/RCpIbOmvABOXJ7Z
H2jPwN9CYy+ixgtA7Wb1XbYTA4PyfLyW7SuE2qcXtoMnAx3HXzH7uwpBlOfd
R62zDLRg+FOPrCgCY4tJuvo5Bib6fnwfvKsI6lc7Wm33ZeCMMvfrzmtF0HTV
9Nb6ywzssUjprtUqhrXdEeslrjIwcPhPpPepYjDTrXwuGsLA0W6nrMH7xdAy
TbD5bzBw/8gXK/xTDG0OKpO/bzPwn+Fpp1/FJSBV6OzPiSLj80uToc+VgKXs
c/7xaAbGux+v8VQrhR/N0nL9MQz8cuygybnHpdC5X8C4/gn5+ue6/EdDy6Bv
W39mWgYDO1pWrX16vQI2X9tISclkIGfJ9ydLqyvAvtei6vk7BiYdvXjDRawS
BmPr+h59IutreMzS9nElDAvlrQnPZ2CsDMVEobwKxsYf+pyqZaDvIUmlHsUa
2GHQtPS/egY2ufo68prUwJkXopE2jQwsFWmMKA6ogQmb6y+PtjDQW2XVGYXv
NcD55t1C72bgkVRd6+t3vsHM28M6clMMdH25UjxasQ4ENdWrxbgMDF8j9czI
sg5ksyVtlk0zsO+0RWP+7TpgFfZcHpxloNjhpOdFC3XwoP5sReoiJn6uKdAM
7a4HrV8PjmmLMFGtj7m6orIRDM9f/KksxsQkFZsbyUJNcOLfiYsy4ky0Z/Qe
sz7YBKHLlJ8sWsfEtAFzxv6GJmgVzx0qkWViudGOTTYjzeCn3u1josLEZHxa
eIpohYhPxSsYakyM8yvIPxfZCs90k2M1djPRR7pww4WuVqhkeLElNZkYdOoL
78krbSB9lJevC5h4WMeBurixHXLPKd1zOcjE3wOPCpabdkLt35VbrQ8zcUSY
4vf0Sif0B3A+HTJm4n5Fm/6SzE5YeS37x66jTLzik7MsdU0XWN033PzHion5
FoNei7q6YOGDR1awKxO/lovc1InogTbejBtP3Jg4bpV+6kJVD3wymbTN9SDX
FrRcW4Fe8Jo4s3Lam4nGM9Pe26/3wuAWF4f/Asj9neISU8P6oDbaYR0tgom7
JJLjszMGINHLwn9RBhOPZp3hmzj9E4LyHxpLZzLRwSKjzTn7J9gIt27d+46J
rYoLO/YKjoJkinmj2ycmWnufcUhKGYWbPUd2duYz8VKiYlfb+Bj4GB3uyq1j
onRr1k7tzxNgmhDxvqWBiYp/BLK29EyA2tjX8OkmJnLM6jZ2rJiE0euGWjva
yHz3m3uFmU/CiTz9O3G9ZH6rTY/VTE0CrLpx6mM/E6UoD4QE1k6BlGU5NAwy
8dvniadfdKagcYb1U3CUrB+P2BkH8vu/vgqD7veLiZd7/L7QBTjA09CwyOs3
Ex/KnpWuV+TAu/P/5TrPMlHIzK4sgs4BuYIrGsf/MbGoaKLQzo8DzQ6ruUYL
TCx+0qpoE82Bm4LP0vQWsdCuStj16BsO/DEt2Kq1jIX7TfP+8vzgQNofo37V
5SwcTpzyu8fhgH1895Ot/CwMq96UOrmcC1I0D+uNAiy8Olbpvmg9F2oHF0mt
E2Lh3ZWJZz4oc+FaeGSz8CoW8q3/o8G3jwu6ahvv8omwsCrqiXW3Phe4jWmH
ecRYWPFZ10eT9NkrX1w5s5qF06Ec8bmTXLCRrSkfX8PCozsVN244w4U1RdYh
A2tZmFyTEnGH9GblqXFqhyQLnerWmuuT3gxaGcDTJMXChb1RpZqkNzXfrsyp
lmHh2lIm/0HSm2NHH50vlmWh2JVEq/8/H3w2t109V46FLx1eixaQx489zpnK
UmDhX/UHR/iucEGYceDN680sNH0+eIERwIXi4TbnREUW5jj+6PLw4YLfrdOK
cUos1HLOu3qZjE9t91xvlDILv4s+V3cj4x9svvE4bAcLbStL16se5cIj//VW
V1RYGJvX15rL5IKJXLKknxoLLzh+01xN+pO/RKvJczcLVYV4g5RJr+c6l99x
Vmdhz6Z9uFSQC17Cxw7ZabLw+K3XPx6Q9VDKGhI8rsVCSuqkzs9mDnSany8z
0mFhUXvR1bnPHIie5wvW02Xh4z3WM5WxHDB4ep8gkIWBK9YK2vpy4MPP959V
aWS98zI0f6pywDWS6bOVwUI6JoVN8XNAQb1p90YWCzOfCg+2dkxBRMD0a2ED
Fn7Z8tEn5OoUOIruSRg3ZuGulEf7xz5Ogsz7QosBU7I/9id/exU0CfXHTdZ1
HCXrab5Po3b/JGCi5+3q4+T5B6rGcusmYK1mxpXXdixsr+KseJw+DiWWO085
e7JQw3D7C5WAERC1c/wcd5aF0rgm8Gb/MFg5PhaqOcdCmUHLk/KGwzDtIZax
24+Fr2R3/52XGQKFa7///LvCQl0lG2e16n5wC1c5oBLCwtx6P46Abj98vn0q
/sR1Mh8XXe93vekDo7hWakk4C4sr3mrLxvTCpYwvYRHRZD4T7TbZhHVD5fuZ
H/n3yet54CacvqobJHJUVX/FkPmRGitsvtsFqSVPG8zjWXhMWUmu6VUntLeF
yMi/YOH8oilnk4l2UOxmu5m+YuFq4e8bcze1g9fAbH5ICgsVMoitCzZtIDjl
7PAzjYW1V7fYfR1sAa3lh9KyPrKw0KtEw1+7GYIFry8e/EzOz3zLoai4Jvgm
km8imctC3kTJjXVLm8BRavfsxXwWUq2Hrx3qboDMjS766YXk9b0U5DUyawCe
LUlxPcXk/OhR+3nq6uGe6lqCVcHCghWfRgYa6qBb/XDUhSoWav/y1uwk71c7
dEL7U76y0LlWLIZ3uBaKGXOhIvUsFHoyetJ6ZS1wj3fWtbSxMFpT26H7cg2g
7brNQh0sPPhW9cDI1hq4YW/kA13kPPxd0Xki6SvIuRdKPetj4b3q3+UrrarB
1fufa+MACzFbRbIovwo++arn8Q2T/UWT6Ny4vQoOB7/4z2WMhW2albH8opUQ
e6PrffwEC/sP7z+kEVYBgxGSK2qnWJh9z36roUAFXHoYlqr+m4UCsf1C4RLl
UJlQxHNqloWlrc4aJ56VgUTSvNHDvyy8oVP/yHdPGZxI1kis+sdCE7veM2/L
SyE1ze33wgILN/C/pPXZlcL/AP7k1xY=
      "]]}}, {{}, {}, 
    {Hue[1.], LineBox[CompressedData["
1:eJwU2nc8V+8XAHAykiLZZO+9tw/nFBWKNFRmipAkCUVmFEkSWhLaSH1Lkig+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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True]], "Output",
 CellChangeTimes->{3.465482301101165*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Do a Stream Plot", "Subsection",
 CellChangeTimes->{{3.4654816873163548`*^9, 3.4654816970938883`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Last", "/@", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"interpret", "[", "net", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ")"}]}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "t", "]"}], "\[Rule]", " ", "X"}], ",", " ", 
    RowBox[{
     RowBox[{"Y", "[", "t", "]"}], "\[Rule]", " ", "Y"}]}], "}"}]}]], "Input",\

 CellChangeTimes->{{3.4653999598546*^9, 3.465400006411161*^9}, {
  3.465400104210102*^9, 3.465400122860921*^9}, {3.4654002611096888`*^9, 
  3.46540026179268*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"k1", " ", "X"}], "-", 
    RowBox[{"k2", " ", "X", " ", "Y"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "k3"}], " ", "Y"}], "+", 
    RowBox[{"k2", " ", "X", " ", "Y"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.46539996428751*^9, 3.465400007008271*^9}, {
   3.465400112912896*^9, 3.465400123267275*^9}, 3.465400262322987*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StreamPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"k1", " ", "X"}], "-", 
       RowBox[{"k2", " ", "X", " ", "Y"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "k3"}], " ", "Y"}], "+", 
       RowBox[{"k2", " ", "X", " ", "Y"}]}]}], "}"}], "/.", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"k1", "\[Rule]", " ", "1"}], ",", " ", 
      RowBox[{"k2", "\[Rule]", " ", "3"}], ",", " ", 
      RowBox[{"k3", "\[Rule]", " ", "1"}]}], "}"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"X", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"Y", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465400163538855*^9, 3.4654001912815313`*^9}, {
  3.465400229683795*^9, 3.465400293285183*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.483292423890731, 0.5058001431080666}, {0.4685181151765652, 
       0.5185404679318464}, {0.4530531120977923, 0.5303563059008325}, {
       0.4431383568319772, 0.5371980916061084}, {0.4332282909646349, 
       0.5434802814078254}, {0.4233229144957651, 0.5492028753059836}, {
       0.4150852437617618, 0.5534986456073191}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.41322845274805364`, 0.5544505543581492}, {
       0.393634921479991, 0.5630130815791051}, {0.373866373128504, 
       0.5694219062433921}, {0.35455328327396846`, 0.5735585732315167}, {
       0.33613235281944553`, 0.5753893084815519}, {0.33307951825641813`, 
       0.5753065476160897}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.3309932596924888, 0.5752499901575167}, {0.3186035817649348,
        0.5749141119934977}, {0.3019669701104367, 0.5721329837673543}, {
       0.2863485554529743, 0.5673734277938537}, {0.2718743753895704, 
       0.560962948063728}, {0.2585444299202253, 0.5529015445769773}, {
       0.25347427530902017`, 0.5488605000074392}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.2518422174804552, 0.5475597076389543}, {0.2463587190449391,
        0.5431892173336015}, {0.23525336317242418`, 0.5322368634694583}, {
       0.22516448271139322`, 0.5204553801204055}, {0.21609207766184632`, 
       0.507844767286443}, {0.20803614802378328`, 0.49440502496757077`}, {
       0.2016341920483387, 0.4817791487926555}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.20069036182355232`, 0.47991773587541536`}, {
       0.19936113818583512`, 0.4772962537654228}, {0.19186408235612484`, 
       0.45997930871110077`}, {0.18554498053465235`, 0.4424541898046045}, {
       0.18040383272141766`, 0.424720897045934}, {0.1762833506479815, 
       0.40710117870930307`}, {0.17507598204102504`, 0.40073113464855004`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.17468732997573624`, 0.3986806168812933}, {
       0.17302624604590458`, 0.38991678306892535`}, {0.17063251891518688`, 
       0.373167710124801}, {0.16910216925582833`, 0.3568539598769297}, {
       0.16841732297882442`, 0.3437049822544948}, {0.168190987506606, 
       0.3310424040099163}, {0.16842316283917302`, 0.31886622514319424`}, {
       0.16861465957932795`, 0.31562516593527645`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.16873775597658836`, 0.31354177427294544`}, {
       0.16911384897652554`, 0.30717644565432883`}, {0.1702630459186635, 
       0.2959730655433199}, {0.17187075366558696`, 0.28525608481016734`}, {
       0.17646170157379032`, 0.2652813214774319}, {0.18284165597715776`, 
       0.2472419730403187}, {0.1897633877962611, 0.23351245167279566`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.1907029150664104, 0.23164886318540512`}, {
       0.19096558015171147`, 0.23112785688302423`}, {0.2008334740974515, 
       0.2169389730055485}, {0.21244533781437785`, 0.20467532140789155`}, {
       0.22851202586997293`, 0.1925272105087228}, {0.24728160662932466`, 
       0.1828048225427786}, {0.25423932209899147`, 0.18015497312290188`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.2561896875024976, 0.1794121754825615}, {
       0.25770419296824704`, 0.17883537531772112`}, {0.26884643707177336`, 
       0.1754473990807977}, {0.28070160723688764`, 0.17265715224038403`}, {
       0.29326297176057387`, 0.17048089320485577`}, {0.3065582599454894, 
       0.168915261070193}, {0.32058763228975284`, 0.1679725903822923}, {
       0.33530300388353995`, 0.16769268272440413`}, {0.33842246975110174`, 
       0.1677785577580413}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.3405087044381121, 0.16783598921635118`}, {
       0.35065628981702623`, 0.16811533967977887`}, {0.3667219132382588, 
       0.16923394482979384`}, {0.3834762908489877, 0.17107901615732482`}, {
       0.40072432806994285`, 0.1737460568478701}, {0.41827093032185414`, 
       0.17733057008692782`}, {0.42311497666748843`, 0.1785990462592949}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.42513392742408795`, 0.17912773462129564`}, {
       0.4366524229069819, 0.1821440016053506}, {0.4552345246795276, 
       0.18802964589676033`}, {0.473676926416962, 0.1951425173705826}, {
       0.49179056744010236`, 0.20356873514316504`}, {0.5025375124455352, 
       0.20962935575459823`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.5043553936073248, 0.21065452970242327`}, {
       0.5092651082439502, 0.21342330889576092`}, {0.5257902093235073, 
       0.22482124830962355`}, {0.5409409849513783, 0.23799840399891406`}, {
       0.5542973068436611, 0.2529620094116839}, {0.5642526931086711, 
       0.26751563517528454`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.5654081999898256, 0.26925136355205387`}, {
       0.5739167027744355, 0.2870174860596555}, {0.5796067703625207, 
       0.30681161480511954`}, {0.5820721813335922, 0.32830925954155454`}, {
       0.5819704302186683, 0.340194937215933}, {0.5810808681689253, 
       0.34981602830924524`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.5808887222661144, 0.35189418939388756`}, {
       0.5808445143596079, 0.3523723216339785}, {0.5786952951729047, 
       0.3647812393389393}, {0.575514445632451, 0.3780033670794163}, {
       0.5713141691385772, 0.3911862475514253}, {0.5660923121500485, 
       0.4044803143968458}, {0.559848874666865, 0.41788556761567797`}, {
       0.5532674815546565, 0.43013013503524017`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.5522493069093529, 0.43195120428234723`}, {
       0.5443894611530815, 0.4448539307435358}, {0.5353578909955781, 
       0.45806563579247883`}, {0.5254891462165162, 0.4710371223547508}, {
       0.5147832268158961, 0.4837683904303518}, {0.5075370246617269, 
       0.49198295748196685`}, {0.5017295556470951, 0.49816512145163994`}}]}, 
     {Arrowheads[{{0.00010427490801377205`, 1.}}], 
      ArrowBox[{{0.5003006232089572, 0.4996862478858742}, {0.5000026196118678,
        0.5000034785238884}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.8726072210364042, 0.224516476329236}, {0.8831515087907215, 
       0.23947654522213}, {0.8921787903269205, 0.2557689914420527}, {
       0.8994989710231089, 0.2734318766776255}, {0.9049219562573947, 
       0.29250326261746995`}, {0.9063465988178123, 0.2999737046804973}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.906737556975518, 0.3020237840108189}, {0.9068470748066636, 
       0.30259806603437506`}, {0.9082012106794524, 0.3130904051508868}, {
       0.9089690681572894, 0.3239746585479811}, {0.9091353515217031, 
       0.3352452048066335}, {0.9086847650542219, 0.34689642250782}, {
       0.9076020130363742, 0.3589226902325163}, {0.9058717997496885, 
       0.3713183865616982}, {0.9034788294756929, 0.3840778900763415}, {
       0.9032637522351471, 0.3849531203645418}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.9027657084114699, 0.3869798482425229}, {0.8994517920906412,
        0.4004654217471416}, {0.8941608381534379, 0.41756683874942874`}, {
       0.887665725016196, 0.4352923938836253}, {0.8800262100310287, 
       0.4535523399501533}, {0.8745220919374799, 0.46535316401476284`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.8736399054423154, 0.4672445710384989}, {0.8713020505500485,
        0.4722569297494364}, {0.8615530039253684, 0.49131641608189736`}, {
       0.8563128221066761, 0.5009511994482018}, {0.8508388275091013, 
       0.5106410517479592}, {0.8451384898016578, 0.5203747545812224}, {
       0.8392192786533595, 0.5301410895480453}, {0.832953033784336, 
       0.5400751273869053}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.8318395787002342, 0.5418403161352766}, {0.8309087595009477,
        0.5433159675565226}, {0.8222182878949921, 0.5564916564733716}, {
       0.8131691228905955, 0.569642927007798}, {0.8037825235428607, 
       0.582744549869008}, {0.79407974890689, 0.5957712957662082}, {
       0.7840820580377865, 0.6086979354086043}, {0.7832766953606712, 
       0.6097016685593704}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.7819705927809112, 0.6113294798484432}, {0.773810709990652, 
       0.6214992395054031}, {0.7614728577851765, 0.636302878246869}, {
       0.7500341396081573, 0.6495893655672885}, {0.7383642823633122, 
       0.6627000587605236}, {0.7274719468283498, 0.67453866933032}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.7260516918908974, 0.67606782252118}, {0.7143311506701449, 
       0.6883940627654398}, {0.7019678762218227, 0.7009773735771209}, {
       0.6893734627056738, 0.7133848902616182}, {0.676547910121699, 
       0.7256166128189312}, {0.6666818040626972, 0.734726506175031}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.6651484614626786, 0.7361423218454687}, {0.6634912184698984,
        0.7376725412490596}, {0.6503060804090399, 0.7494593826360096}, {
       0.6370951885978918, 0.7608838440637872}, {0.623858543036454, 
       0.7719459255323924}, {0.6105961437247273, 0.7826456270418245}, {
       0.6012955971365774, 0.7898808492902568}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.5996483249384096, 0.7911623202602097}, {0.5973079906627109,
        0.7929829485920842}, {0.5839940838504042, 0.802957890183172}, {
       0.5706544232878078, 0.8125704518150874}, {0.557289008974922, 
       0.8218206334878302}, {0.5407427477233275, 0.8327507802059857}, {
       0.5311163420361256, 0.8387690571982936}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.5293466948763208, 0.8398754126888497}, {0.524441880641314, 
       0.8429418251818666}, {0.5083864077288821, 0.8523937684154723}, {
       0.4925763289860303, 0.8611066099068039}, {0.4770116444127594, 
       0.8690803496558609}, {0.46169235400907005`, 0.8763149876626428}, {
       0.4556462541273336, 0.8789203300658756}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.4537296040586111, 0.8797462392956066}, {
       0.44661845777496095`, 0.8828105239271505}, {0.43178995571043277`, 
       0.8885669584493836}, {0.41728213039890116`, 0.8935948982505612}, {
       0.40317026442378184`, 0.8979049503519024}, {0.38945435778507553`, 
       0.9014971147534073}, {0.3761344104827809, 0.9043713914550762}, {
       0.37424424312685445`, 0.9046867690388918}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.37218567609497943`, 0.9050302443902144}, {
       0.3632104225168986, 0.9065277804569086}, {0.3506823938874293, 
       0.9079662817589048}, {0.33855032459437173`, 0.9086868953610648}, {
       0.32681421463772653`, 0.9086896212633885}, {0.31547122340302325`, 
       0.9080606904851509}, {0.3045185102757915, 0.906886334045627}, {
       0.2892913232599142, 0.9039598146283309}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.287241806648756, 0.9035659171768599}, {
       0.28378391834374306`, 0.9029013441827205}, {0.26461043884158064`, 
       0.8967346516746688}, {0.24699807176930405`, 0.8883862565214719}, {
       0.2367226810704312, 0.8822441615150779}, {0.226922256805271, 
       0.8756090745910218}, {0.2175967989738231, 0.8684809957493035}, {
       0.21397147338856679`, 0.8653592636816242}}]}, 
     {Arrowheads[{{0.019999999999999987`, 1.}}], 
      ArrowBox[{{0.2123899745096825, 0.8639974506115677}, {
       0.20874630757608814`, 0.8608599249899235}, {0.2003707826120658, 
       0.8527458623128814}, {0.19247022408175585`, 0.8441388077181771}, {
       0.1850446319851588, 0.8350387612058109}, {0.17809400632227418`, 
       0.8254457227757824}, {0.17153817610680236`, 0.8155139526871156}, {
       0.16529697035244376`, 0.8053977111988345}, {0.16133261034766727`, 
       0.7985074430707318}}]}, 
     {Arrowheads[{{0.020000000000000014`, 1.}}], 
      ArrowBox[{{0.16029180411291635`, 0.7966984665857016}, {
       0.15937038905919818`, 0.7950969983109387}, {0.15375843222706542`, 
       0.7846118140234278}, {0.14846109985604589`, 0.7739421583363028}, {
       0.14347839194613934`, 0.7630880312495629}, {0.13881030849734566`, 
       0.7520494327632081}, {0.1344568495096652, 0.740826362877239}, {
       0.12946415188194088`, 0.7269919555781728}, {0.1271553099886584, 
       0.7202200721549133}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.12648181732324384`, 0.7182447035383454}, {
       0.12475496201288255`, 0.713179799404101}, {0.12032927990249023`, 
       0.6993898943550241}, {0.11618710555076392`, 0.6856222404309418}, {
       0.1123284389577036, 0.671876837631854}, {0.10875328012330927`, 
       0.658153685957761}, {0.10546162904758097`, 0.6444527854086627}, {
       0.10401804435794844`, 0.637888507446411}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.10356978725135092`, 0.635850189731217}, {
       0.10245348573051866`, 0.630774135984559}, {0.0992564835498182, 
       0.6151472586838488}, {0.09627417493588093, 0.5997782334874995}, {
       0.0935065598887067, 0.5846670603955103}, {0.09095363840829558, 
       0.5698137394078816}, {0.08861541049464765, 0.5552182705246138}, {
       0.08840118594505793, 0.553771875508137}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.08809541370419754, 0.5517073714809169}, {
       0.08649187614776276, 0.5408806537457062}, {0.08458303536764099, 
       0.5268008890711589}, {0.08288888815428237, 0.5129789765009725}, {
       0.08140943450768683, 0.4994149160351463}, {0.0801446744278544, 
       0.48610870767368053`}, {0.07909460791478512, 0.47306035141657565`}, {
       0.07881429629020989, 0.46876846356690866`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.07867827837949681, 0.4666858755928595}, {
       0.07825923496847892, 0.4602698472638309}, {0.07763855558893583, 
       0.44773719521544664`}, {0.07723256977615588, 0.43546239527142316`}, {
       0.07704127753013901, 0.42344544743175994`}, {0.07305552700128393, 
       0.41185917709844494`}, {0.07247364523585004, 0.4004125697144439}, {
       0.07196955085903005, 0.38926493939641005`}, {0.07177627794967589, 
       0.38393821277806656`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.07170060292863628, 0.38185256016248564`}, {
       0.07119241537605278, 0.3678465819190624}, {0.070719502761994, 
       0.3475640485880382}, {0.07054619522649559, 0.3283772833249738}, {
       0.07066787497919944, 0.3102462300515059}, {0.07095328899771648, 
       0.2983909134038607}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.07100351909070526, 0.296304492909462}, {
       0.07107992422974743, 0.29313083268927126`}, {0.07177772518778147, 
       0.2769910351599062}, {0.07275666006294343, 0.26178678138504713`}, {
       0.0739855707153972, 0.24746605989357004`}, {0.07544295004148047, 
       0.23398120662990057`}, {0.07713865680509585, 0.22129868663899893`}, {
       0.07845651662064343, 0.213221793863018}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.07879260009443313, 0.21116200711669347`}, {
       0.079082549770146, 0.2093849649658254}, {0.0812844877005335, 
       0.19820650665534062`}, {0.08375432936016099, 0.1877297767525049}, {
       0.08953715892274648, 0.168747362349622}, {0.09633846059851095, 
       0.15209869717313762`}, {0.10420281490455287`, 0.13750135259399046`}, {
       0.10720110231033514`, 0.13335823837175598`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.1084246546154014, 0.13166750087041054`}, {
       0.11341482951682824`, 0.12477194290433061`}, {0.12425911211129313`, 
       0.11372708239630812`}, {0.13282345314676988`, 0.10697513827485965`}, {
       0.14240158820530616`, 0.10081853671963006`}, {0.15307867913415324`, 
       0.09522654602940646}, {0.16403149474321574`, 0.09049623931591369}, {
       0.17646649453521965`, 0.08619225081196877}, {0.1765208437658578, 
       0.08617717721480998}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.17853195301585278`, 0.08561940205735548}, {
       0.19017077389203682`, 0.082391409770604}, {0.2051443328136672, 
       0.07909371619181939}, {0.22138717130011099`, 0.0762991700756149}, {
       0.2391132814597951, 0.0739939660062883}, {0.2585366554011467, 
       0.0721642985681373}, {0.2607353215296262, 0.07200781336537597}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.2628170805917648, 0.07185964876470317}, {
       0.26888481628994787`, 0.07142779108575265}, {0.2796572931241658, 
       0.0708101677611619}, {0.2908540859038006, 0.07031142859436505}, {
       0.3024751946288523, 0.0699315735853621}, {0.31860350004475546`, 
       0.06962805788259772}, {0.3356368501540601, 0.06956642658313357}, {
       0.3462442315968463, 0.06967301434918871}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.34833115128568604`, 0.06969398466205713}, {
       0.353575244956766, 0.06974667968696965}, {0.3724186844528733, 
       0.07016881719410596}, {0.39221424129545474`, 0.07087381127549588}, {
       0.41300898813758313`, 0.07190263410209283}, {0.4237810578084774, 
       0.07253848129484392}, {0.4317336258396078, 0.07305567457082005}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.4338162512808558, 0.07319111759631494}, {
       0.43480292497925843`, 0.07325528567389676}, {0.4460745896499262, 
       0.07405304723925135}, {0.45759605182048063`, 0.0749317659909077}, {
       0.4693630583961541, 0.07591293491571226}, {0.481371356282179, 
       0.07701804700051149}, {0.49362094547855534`, 0.07824710224530541}, {
       0.506111825985283, 0.07960010065009401}, {0.5169347905053572, 
       0.08085557272379239}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.5190077710015809, 0.08109725131482094}, {
       0.5318174609297925, 0.08267792693965526}, {0.5450322153675744, 
       0.08440275482442788}, {0.5584882611157076, 0.08625152586919521}, {
       0.5716459853227849, 0.08817359386193822}, {0.584992437198061, 
       0.09026280191445489}, {0.5985276167415359, 0.09251915002674521}, {
       0.6016163708161165, 0.09306458937216672}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.6036715971789387, 0.09342751930927508}, {
       0.6122515239532094, 0.09494263819880917}, {0.6261354447927897, 
       0.09755972513319405}, {0.6401506652199849, 0.10039686953244713`}, {
       0.6542971852347949, 0.10345407139656837`}, {0.6685750048372195, 
       0.1067313307255578}, {0.6829357434058936, 0.11026526385375382`}, {
       0.6852832123710615, 0.11088937743514968`}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.6873001700808706, 0.11142561911436734`}, {
       0.6973310203194516, 0.11409248711549486`}, {0.7117608355778934, 
       0.11821300051078092`}, {0.726225189181219, 0.12262680403961196`}, {
       0.7406720881244058, 0.12737036702001547`}, {0.7550263901807103, 
       0.13260223502655225`}, {0.7667425796507636, 0.13692586812621502`}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.7687005377693451, 0.1376484146974266}, {0.7693691176261674,
        0.13789514116136042`}, {0.7833409957425327, 0.14417760014254638`}, {
       0.7942632219251856, 0.1491278173185978}, {0.8050371430636544, 
       0.1543706669763963}, {0.8156296945897252, 0.15992500786912117`}, {
       0.8260078119351845, 0.16580969874995177`}, {0.8361445816708254, 
       0.17204089936538933`}, {0.8425334582662525, 0.1763133018771728}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.844268318066402, 0.1774734462714246}, {0.8460081694562359, 
       0.17863692866727757`}, {0.8555581293563936, 0.18561988421680958`}, {
       0.8647540154362764, 0.19301186357517844`}, {0.8776687700605178, 
       0.2047748708568344}, {0.8895976441972928, 0.2175601397043098}, {
       0.9003712791034659, 0.23143218387108583`}, {0.9031609115153718, 
       0.23586751179282026`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.9042720556062589, 0.23763415616874184`}, {
       0.9098203160359019, 0.24645551711064373`}, {0.9177588438187011, 
       0.2627328737126978}, {0.9240141932221753, 0.2803364115379758}, {
       0.9284368684225061, 0.2992847796964793}, {0.9304422325866961, 
       0.3159750337198994}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.9306912017386307, 0.31804715531456357`}, {
       0.9308773735958751, 0.31959662729820987`}, {0.9312783536417755, 
       0.33030993854333884`}, {0.9310798807885358, 0.34143698456654376`}, {
       0.9302792178776681, 0.35295813933956866`}, {0.9288736277506842, 
       0.3648537768341575}, {0.9268603732490961, 0.37710427102205424`}, {
       0.9242367172144156, 0.38968999587500297`}, {0.9214936372371033, 
       0.40062345987162434`}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.9209836211410393, 0.4026471655659891}, {0.9171472519118253,
        0.41578863346303213`}, {0.9107291716153483, 0.4345997950370846}, {
       0.9030574082517853, 0.4539095401407676}, {0.8987575968097751, 
       0.4637320244737705}, {0.8941518062689078, 0.47365592623824093`}, {
       0.890862690265462, 0.4803674826818845}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.8899442653449174, 0.48224156091051085`}, {
       0.8892425171851549, 0.48367350261719894`}, {0.8838205360049223, 
       0.4944377311759595}, {0.8782319002862302, 0.5048684889458098}, {
       0.8723447271365955, 0.5153774356961877}, {0.866159016556018, 
       0.5259645714270931}, {0.8596747685444979, 0.5366298961385259}, {
       0.8528919831020351, 0.5473734098304862}, {0.8482347731498018, 
       0.5544905745590849}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.8470920176910594, 0.5562369374947895}, {0.8458106602286296,
        0.558195112502974}, {0.8384307999242814, 0.5690950041559893}, {
       0.8307524021889905, 0.5800730847895322}, {0.8228068427085599, 
       0.5910827962632096}, {0.8146254971687925, 0.6020775804366283}, {
       0.8062083655696884, 0.6130574373097886}, {0.7978677934673242, 
       0.6236265643152812}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.7965578838358924, 0.6252512669832075}, {0.7886667441934699,
        0.6349723691553333}, {0.7795422544163556, 0.6459074441277177}, {
       0.7701819785799046, 0.6568275917998437}, {0.7605859166841167, 
       0.6677328121717111}, {0.749592687204411, 0.6798871730124671}, {
       0.742055481806219, 0.6884679592175237}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.7406781655081769, 0.6900359749562317}, {0.7388296887540394,
        0.6921403867367671}, {0.7274911127303324, 0.7041464682522073}, {
       0.7161525367066254, 0.7161525497676473}, {0.7063608787521369, 
       0.7250759549608671}, {0.6965692207976486, 0.733999360154087}, {
       0.6867775628431602, 0.7429227653473067}, {0.6809319882624845, 
       0.748249997039121}}]}, 
     {Arrowheads[{{0.003788684384137475, 1.}}], 
      ArrowBox[{{0.6793894330243656, 0.7496557697373338}, {0.6769859048886717,
        0.7518461705405266}, {0.6668789070599251, 0.7593066749358371}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.3402060760199272, 0.36915127159674666`}, {
       0.32018983448245103`, 0.36768527412028923`}, {0.3047225182205096, 
       0.35513743438068984`}, {0.29792830192869413`, 0.33603058071547903`}, {
       0.3013338709078369, 0.316759786094404}, {0.3037606113545752, 
       0.314038873892603}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.3051497601264343, 0.31248133120255206`}, {
       0.3139048201518924, 0.30266497458197206`}, {0.3314246797025048, 
       0.2972643393376641}, {0.35040686173878993`, 0.3009151830485947}, {
       0.3656867635444987, 0.3134830359682689}, {0.3675129896743353, 
       0.3163147734936979}, {0.36905727275906036`, 0.3193174772470521}, {
       0.3702999524587885, 0.32247009076542427`}, {0.3705109988957581, 
       0.32311699332523497`}, {0.3707091534830352, 0.32376877624716527`}, {
       0.3708492388166634, 0.3242606944757142}, {0.370862915614761, 
       0.32513229550927697`}}]}, 
     {Arrowheads[{{0.01152188168460142, 1.}}], 
      ArrowBox[{{0.3708956603059836, 0.3272190636628785}, {
       0.37112259785034574`, 0.3416814397840129}, {0.3626943364423284, 
       0.3580687684018792}, {0.36184347599348116`, 0.359065934928684}, {
       0.36096038822910675`, 0.3600369033660983}, {0.36066508771672, 
       0.36033836517124734`}, {0.3599307445608989, 0.3610627131597328}, {
       0.35924784560723994`, 0.361705111353269}, {0.3585508391764572, 
       0.3623317267426356}, {0.3509600161961885, 0.3676167318716735}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{1., 0.6507787613830965}, {0.9960218214011877, 
       0.6562252135574842}, {0.9861964531583912, 0.6693441043168257}, {
       0.9761138052472638, 0.6824804504940698}, {0.9657738776678054, 
       0.6956342520892166}, {0.955176670420016, 0.7088055091022661}, {
       0.9487266859045975, 0.7166425438341072}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.9474004445052803, 0.7182539895491177}, {0.9443221835038956,
        0.7219942215332185}, {0.9332104169194443, 0.7352003893820733}, {
       0.9218413706666619, 0.7484240126488311}, {0.9102150447455486, 
       0.7616650913334915}, {0.9026013210576634, 0.770189613624662}, {
       0.8949046542668705, 0.7786927990338512}, {0.8925935450063759, 
       0.7812125241801231}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.8911828393435057, 0.7827505693922137}, {0.8871250443731697,
        0.7871746475610593}, {0.8799260361998233, 0.7958058542621361}, {
       0.8720220116517611, 0.8042556974663722}, {0.8641179871036987, 
       0.8127055406706082}, {0.8562139625556364, 0.8211553838748442}, {
       0.8483099380075741, 0.8296052270790802}, {0.8336715432883973, 
       0.8431698195387479}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.8321407151154502, 0.8445883535166985}, {0.8188586925136889,
        0.8568960707964464}, {0.8041330697667463, 0.8705414926551295}, {
       0.7894074470198036, 0.8841869145138126}, {0.7779888686696396, 
       0.8940426057111308}, {0.7703144884434634, 0.900666575816736}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.7687345823925891, 0.9020302364827741}, {0.7665702903194754,
        0.9038982969084491}, {0.7551517119693113, 0.9137539881057674}, {
       0.7437331336191472, 0.9236096793030857}, {0.7323962272362154, 
       0.9318748707072376}, {0.7209920615861511, 0.9414498854704677}, {
       0.7095975044028201, 0.9508377826109724}, {0.7043319562898673, 
       0.9550931506792455}}]}, 
     {Arrowheads[{{0.01716791491603516, 1.}}], 
      ArrowBox[{{0.7027087390934178, 0.9564049583918465}, {0.6982125556862223,
        0.9600385621287516}, {0.6868583143487081, 0.96903602390208}, {
       0.6755558793026277, 0.9778139678092324}, {0.6643052505479813, 
       0.9863723938502088}, {0.6531064280847687, 0.994711302025009}, {
       0.6458456363733197, 1.}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.3436202804724632, 0.7231157295449249}, {
       0.32316996019368566`, 0.7232396883416397}, {0.30390252108244237`, 
       0.7211606321323869}, {0.2858977862789018, 0.7171544177474769}, {
       0.26915575578306394`, 0.7112210451869098}, {0.26251883126815095`, 
       0.7078507596519061}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.26065798754190694`, 0.7069058077122886}, {
       0.25367642959492853`, 0.7033605144506854}, {0.23659313104507224`, 
       0.6919397093137041}, {0.2210635524457204, 0.678905779342815}, {
       0.20708769379687283`, 0.6642587245380182}, {0.19823522588283854`, 
       0.6526711290342533}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.19696824222462744`, 0.6510126882148344}, {
       0.19466555509852937`, 0.6479985448993133}, {0.18357276330866543`, 
       0.6306612829305167}, {0.17358494538525587`, 0.612782981135444}, {
       0.16470210132830088`, 0.5943636395140955}, {0.15780338254439616`, 
       0.5775463956621114}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.15701130410954323`, 0.5756155188419259}, {
       0.15692423113780052`, 0.5754032580664714}, {0.1509708860265897, 
       0.5589805691107537}, {0.145504912897433, 0.5427002316451516}, {
       0.14052631175033042`, 0.5265622456696653}, {0.13603508258528205`, 
       0.5105666111842948}, {0.1323358541790531, 0.4959195066279392}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.13184710333415572`, 0.49389070871655266`}, {
       0.12851474020134757`, 0.47900239668390054`}, {0.12548562698246146`, 
       0.4634338166688768}, {0.12294388574562949`, 0.4480075881439689}, {
       0.12078435919761644`, 0.4328569035331033}, {0.11890189004518717`, 
       0.4181149552602072}, {0.11817123783350762`, 0.4115916487277426}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.11793893028766193`, 0.4095175931002746}, {
       0.11729647828834161`, 0.40378174332528033`}, {0.11596812392707975`, 
       0.3898572677283225}, {0.11491682696140162`, 0.37634152846933394`}, {
       0.11414258739130724`, 0.3632345255483146}, {0.11364540521679657`, 
       0.3505362589652646}, {0.11342528043786965`, 0.33824672872018385`}, {
       0.11345605143712856`, 0.3262110880886163}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.11347990463951649`, 0.3241242996589656}, {
       0.1137414594324977, 0.3123770112127722}, {0.11427270549571353`, 
       0.30018607428691146`}, {0.11505272260286391`, 0.288491085246281}, {
       0.1160815107539488, 0.2772920440908806}, {0.11735906994896828`, 
       0.26658895082071016`}, {0.1206605014708108, 0.24667060793605974`}, {
       0.12194984324774008`, 0.24122931611396334`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.12243104961586637`, 0.23919852464929656`}, {
       0.12495696089824755`, 0.2285386510222314}, {0.1302483919611346, 
       0.21199567450912682`}, {0.13653479465947196`, 0.19704167839674605`}, {
       0.1438161689932596, 0.18367666268508911`}, {0.15220928380602367`, 
       0.1717168270415294}, {0.15828512043798304`, 0.16493573656659585`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.1596778255142247, 0.16338137299513023`}, {
       0.16183090794129026`, 0.1609783711334405}, {0.17268104139905935`, 
       0.15146129496082233`}, {0.18475968417933095`, 0.14316559852367494`}, {
       0.1938043329735399, 0.13813062564736894`}, {0.20349930038131062`, 
       0.1335842629827642}, {0.21384458640264312`, 0.12952651052986067`}, {
       0.22520176400112685`, 0.12588334415935604`}, {0.2320372100559814, 
       0.12407987290134934`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.23405517913568696`, 0.12354744982235942`}, {
       0.2371961022034933, 0.12271874538508631`}, {0.2500147952136912, 
       0.1199918430160745}, {0.26368719162946974`, 0.11771191228603137`}, {
       0.2782426400485787, 0.11588822842866763`}, {0.29373134153910124`, 
       0.11450821927614296`}, {0.3101868151928536, 0.11357679058185792`}, {
       0.31674941049109046`, 0.11340832272337961`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.31883574820584276`, 0.1133547645149432}, {
       0.3276133866431846, 0.11312943446138449`}, {0.34601538152344286`, 
       0.11320164303029465`}, {0.36546297691669233`, 0.11379102952619835`}, {
       0.38597366874622474`, 0.11492551028907518`}, {0.39660433329137523`, 
       0.11572245688598053`}, {0.4022215728131864, 0.11622047121697368`}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.4043004436022028, 0.11640478015398682`}, {
       0.40747276090573037`, 0.11668603208805158`}, {0.4185696145760016, 
       0.11782635424142915`}, {0.4298855572888999, 0.11915354169225403`}, {
       0.44641110814037754`, 0.12136569320075273`}, {0.4633952377621257, 
       0.12397520614283888`}, {0.48077789591699704`, 0.12702899853608593`}, {
       0.48689882144473645`, 0.12825344703587402`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.48894530093724065`, 0.12866283099800324`}, {
       0.49849903236784393`, 0.13057398839806733`}, {0.5165511245844226, 
       0.1346339799546292}, {0.5348846278709661, 0.13925126846499947`}, {
       0.5533764587420424, 0.1445005084968243}, {0.5696621845115232, 
       0.14973583446202676`}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.5716490696271144, 0.150374552771715}, {0.5719035337122195, 
       0.15045635461774992`}, {0.5904124960432827, 0.1571746441681734}, {
       0.6087942075992435, 0.16472626827029105`}, {0.6268419127980086, 
       0.17320846216444796`}, {0.6443488560574846, 0.1827184610909891}, {
       0.6475523221988134, 0.18473618759811639`}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.6493182500362581, 0.18584847012275957`}, {
       0.6612231931623297, 0.19334688535537808`}, {0.6772811508038006, 
       0.2051896472109835}, {0.6921780797597026, 0.2183519198200084}, {
       0.7055693308078402, 0.23293887634465568`}, {0.7113217765981922, 
       0.24084618812941389`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.7125495392776021, 0.24253387066613014`}, {
       0.715507017175874, 0.24659921968295867`}, {0.7240918556728159, 
       0.26140876923492395`}, {0.7310481391327442, 0.2774320559525442}, {
       0.736222696907925, 0.29470493036470413`}, {0.7394439378458271, 
       0.3132379069585764}, {0.7398322786773889, 0.32025269556722796`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.7399476403759712, 0.32233652982651756`}, {0.74054027079392,
        0.3330415002213335}, {0.739401170468027, 0.35409606406410365`}, {
       0.7382451306655385, 0.36493117710828626`}, {0.7358596387258565, 
       0.3763481069426714}, {0.7331288564691345, 0.38798550855894226`}, {
       0.7297524064683945, 0.3998703735129096}, {0.7282402149960618, 
       0.4044317525043881}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.7275834723848587, 0.4064127529295064}, {0.7257302887236362,
        0.4120027018045733}, {0.7210625032348599, 0.42438249343393336`}, {
       0.7157571528873349, 0.43695819316792617`}, {0.7098223405663305, 
       0.44967824577348814`}, {0.7032580662718467, 0.4625426512506192}, {
       0.6960643300038838, 0.47555140959931935`}, {0.692315954877086, 
       0.48189489535945706`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.6912542341965301, 0.4836916765754566}, {0.689803421113143, 
       0.48614693033842504`}, {0.6831971242574655, 0.496720230389843}, {
       0.6762454394368511, 0.5072713097535732}, {0.6689483666513002, 
       0.5178001684296155}, {0.6613059059008124, 0.5283068064179701}, {
       0.6533180571853879, 0.5387912237186371}, {0.6449848205050267, 
       0.5492534203316162}, {0.642959737800565, 0.5516894992663997}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.6416255953455365, 0.5532944096848901}, {0.6363061958597287,
        0.5596933962569075}, {0.6273566653960405, 0.5700243364377856}, {
       0.6182107112605087, 0.580159425817525}, {0.6088683334531333, 
       0.5900986643961257}, {0.599329531973914, 0.5998420521735877}, {
       0.5895943068228513, 0.6093895891499109}, {0.5845503189863818, 
       0.6141390312777193}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.583030872062388, 0.6155697494843746}, {0.5796626579999448, 
       0.6187412753250954}, {0.5695345855051946, 0.6278971106991412}, {
       0.5592100893386007, 0.6368570952720483}, {0.54626486540057, 
       0.6475854907129335}, {0.5333088615485709, 0.6577661126953841}, {
       0.5203420777826039, 0.6673989612194}, {0.5186319219951987, 
       0.6685961731218495}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.5169222127669398, 0.6697930724060398}, {0.5073645141026688,
        0.6764840362849814}, {0.4943761705087655, 0.6850213378921282}, {
       0.481377047000894, 0.6930108660408404}, {0.4683671435790544, 
       0.700452620731118}, {0.45534646024324665`, 0.707346601962961}, {
       0.4451972889462801, 0.7122965859023386}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.4433214761497409, 0.7132114628853414}, {0.4424376826905147,
        0.7136425092536498}, {0.4297634966179025, 0.7192900421204649}, {
       0.4173239020254099, 0.7242892005634063}, {0.40511889891303704`, 
       0.7286399845824739}, {0.3931484872807839, 0.7323423941776679}, {
       0.3814126671286504, 0.7353964293489882}, {0.36991143845663665`, 
       0.7378020900964347}, {0.3641297004124582, 0.7387038826205452}}]}, 
     {Arrowheads[{{0.012186673702531686`, 1.}}], 
      ArrowBox[{{0.36206760736896987`, 0.739025512565802}, {
       0.3586448012647426, 0.7395593764200075}, {0.3454272382327835, 
       0.7412583178257329}, {0.33264357032394126`, 0.7420721827901845}, {
       0.31154692351351554`, 0.7393798937757493}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{1., 0.8211793504310884}, {0.9871736219971153, 
       0.8354452674866548}, {0.9780953738256896, 0.845388841302901}, {
       0.9689271362952292, 0.855307049039226}, {0.9596689094057342, 
       0.86519989069563}, {0.9510406080294816, 0.8752702949114819}, {
       0.9437855169988442, 0.8828819005155926}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.9423455710016144, 0.884392605340087}, {0.9416473971014346, 
       0.8851250874480041}, {0.9322541861733877, 0.8949798799845262}, {
       0.9228609752453407, 0.9048346725210484}, {0.9134677643172937, 
       0.9146894650575705}, {0.8979737107386349, 0.9290314162656962}, {
       0.8829198028467322, 0.9429659500131891}}]}, 
     {Arrowheads[{{0.019969114351237553`, 1.}}], 
      ArrowBox[{{0.8813882093931562, 0.9443836576821574}, {0.866985603581317, 
       0.9577153186819474}, {0.8514915500026582, 0.972057269890073}, {
       0.8388176063095233, 0.9830647517575544}, {0.8261436626163883, 
       0.9940722336250357}, {0.8193184706090954, 1.}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.1225509548127072, 1.}, {0.11985305106154749`, 
       0.9931892031339719}, {0.11559573419330257`, 0.9818075903663789}, {
       0.11155585905156028`, 0.9703407914736332}, {0.1077334256363206, 
       0.9587888064557345}, {0.10412843394758353`, 0.947151635312683}, {
       0.10074088398534906`, 0.9354292780444786}, {0.09663522546655164, 
       0.9206975347633851}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.09607493491254393, 0.9186871248457866}, {
       0.09530147072503564, 0.9159118146743919}, {0.09032253151879915, 
       0.8963550036999309}, {0.08610195553570546, 0.8751566173233292}, {
       0.08188137955261177, 0.8539582309467275}, {0.07910286846913789, 
       0.8369939081111298}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.07876553852143497, 0.8349343251319635}, {
       0.0785026520749052, 0.8333292602558291}, {0.07478718519504379, 
       0.8124725232906493}, {0.07137464588434056, 0.7918755034651753}, {
       0.06823122230979885, 0.7715701516448313}, {0.06549546212002696, 
       0.7525211692424458}}]}, 
     {Arrowheads[{{0.019999999999999987`, 1.}}], 
      ArrowBox[{{0.06521123343976645, 0.7504536226279043}, {
       0.06275172236919992, 0.7318344520195338}, {0.06037305569951286, 
       0.7124419460259706}, {0.058178324158727604`, 0.6934167916603184}, {
       0.05616752774684415, 0.6747589889225772}, {0.05544746828895685, 
       0.6675497867607344}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.05524004703284676, 0.6654730946881818}, {
       0.0543406664638625, 0.6564685378127472}, {0.05267074749201595, 
       0.6385581472582436}, {0.05113077801353784, 0.621040526186482}, {
       0.04972075802842814, 0.6039156745974623}, {0.048440687536686865`, 
       0.5871835924911846}, {0.04809033695870399, 0.5823015361842906}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.04794095013442706, 0.5802198644718389}, {
       0.04724511831491602, 0.5705236049636059}, {0.04613592507794844, 
       0.5542590339217877}, {0.04511310782578414, 0.5383898793657301}, {
       0.04417666655842312, 0.5229161412954331}, {0.043326601275865365`, 
       0.5078378197108966}, {0.042757781939939656`, 
       0.49690153927289177`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.04264937783536159, 0.4948173314877131}, {
       0.042562911978110886`, 0.49315491461212063`}, {0.04188559866515968, 
       0.4788674259991052}, {0.04129466133701174, 0.4649753538718503}, {
       0.040773062122576094`, 0.45145629966180817`}, {0.04030376315076177, 
       0.4382878648004312}, {0.039886764421568764`, 0.42547004928771925`}, {
       0.03952206593499707, 0.41300285312367235`}, {0.03948069493552373, 
       0.4113982509763972}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.03942690363993072, 0.40931191925823557`}, {
       0.039209667691046696`, 0.4008862763082906}, {0.038949569689717634`, 
       0.3891203188415738}, {0.03874177193100988, 0.3777049807235221}, {
       0.038586274414923454`, 0.36664026195413546`}, {0.038467968063548984`, 
       0.3457133586297121}, {0.038393185357140154`, 
       0.32584005078743206`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.03840140541609476, 0.32375305458491616`}, {
       0.03849630701585344, 0.3065401323255189}, {0.038767017223038436`, 
       0.2888161533960453}, {0.039075203636335445`, 0.2762323227593581}, {
       0.0394714276506656, 0.2642446426694237}, {0.039951209154161456`, 
       0.2528202659787175}, {0.04051006803495557, 0.2419263455397147}, {
       0.040616210405047565`, 0.24031258353812915`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.04075318485899328, 0.23823005825841342`}, {
       0.04184709748096878, 0.2215984848267207}, {0.04344667509376566, 
       0.20299828335024417`}, {0.04532381881010524, 0.18599534109772198`}, {
       0.04752260875628858, 0.1705349021523822}, {0.0500507973216892, 
       0.156467655477714}, {0.05029716105544314, 0.15536509429512646`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.050752276827421346`, 0.15332829701120607`}, {
       0.05291613689568058, 0.1436442900372064}, {0.05614778926099919, 
       0.13197168291182237`}, {0.05978715013944599, 0.12138881867822401`}, {
       0.06386032282899129, 0.11179454754344935`}, {0.0683934106276054, 
       0.10308771971453644`}, {0.07903177544117737, 0.0880682762733541}, {
       0.0874909725098034, 0.08011534302521953}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.08901152116018955, 0.07868579577399011}, {
       0.09208713235843653, 0.07579425295279345}, {0.10298190056603321`, 
       0.06855124272547414}, {0.11554772606866387`, 0.06235470910906747}, {
       0.1299654519635008, 0.057059423619907096`}, {0.14641592134771622`, 
       0.05252015777432672}, {0.1652264056469625, 0.048684521998822075`}, {
       0.1657637848957378, 0.048599491181239275`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.16782516359669794`, 0.04827331424625362}, {
       0.17565161060498863`, 0.047034916616646376`}, {0.18680784961745217`, 
       0.04555317752569575}, {0.19873341682097967`, 0.04423109819160072}, {
       0.21146660635219758`, 0.04306047207999178}, {0.22504571234773266`, 
       0.04203309265649942}, {0.23950902894421114`, 0.04114075338675416}, {
       0.25090447552621814`, 0.04059043774090544}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.2529890711673364, 0.04048976721533019}, {
       0.25493781919385283`, 0.04039565712310246}, {0.2714265673536752, 
       0.039816286529188026`}, {0.28903339936750116`, 0.03940385478758719}, {
       0.3078164411791543, 0.039159575080876294`}, {0.3278338187324579, 
       0.03908466059163167}, {0.33645098102210175`, 0.03912334466781691}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.33853798503846944`, 0.039132713624748953`}, {
       0.34914365797123537`, 0.03918032450242964}, {0.3603014150801217, 
       0.03929250247739972}, {0.3718040848393102, 0.03944777999584657}, {
       0.38365893299177856`, 0.03964630870559223}, {0.3958732252805052, 
       0.03988824025445876}, {0.4084561327600268, 0.040187523219718975`}, {
       0.4214171313347288, 0.04056031368735782}, {0.4220039582248601, 
       0.040580088579328114`}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.42408979931286883`, 0.04065037725027391}, {
       0.43476394402236385`, 0.041010074568265525`}, {0.4485042938406839, 
       0.041540268773332334`}, {0.46264590380744053`, 0.04215435921344844}, {
       0.4771964969403864, 0.04285580879950412}, {0.49216379625727324`, 
       0.04364808044238958}, {0.5074779550458058, 0.04453016907158066}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.509560975417328, 0.04465938357390132}, {0.5233794055138773,
        0.045518941542210714`}, {0.5396431614890992, 0.046604456820926884`}, {
       0.5563545157192702, 0.04779464580003376}, {0.5735211912221418, 
       0.049092971390421535`}, {0.591150911015467, 0.050502896502980496`}, {
       0.5928255057090683, 0.0506439830956992}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.5949051628302855, 0.050819196679246836`}, {
       0.6092513981169974, 0.05202788404860084}, {0.6278303755444844, 
       0.053671396938172765`}, {0.6468955663156811, 0.055436898082586575`}, {
       0.6637829928412192, 0.057085680777253116`}, {0.678023804223379, 
       0.058569683060853514`}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.6800995889734612, 0.05878599582750134}, {
       0.6809814948846878, 0.05887789721928723}, {0.6984745862764395, 
       0.06083148599178627}, {0.7162457808468271, 0.06296438567784764}, {
       0.7342897215400105, 0.06529048387742684}, {0.7526074107937533, 
       0.0678213533429696}, {0.7629040764591222, 0.06934503956845571}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.7649686195743669, 0.06965054777944879}, {
       0.7711919016788154, 0.07057146038630895}, {0.7900362472659559, 
       0.0735552713192778}, {0.8091128867699657, 0.07679808148499004}, {
       0.8283824800593694, 0.0803313742444346}, {0.8471873273154428, 
       0.0840535859792772}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.8492302237834818, 0.08448023995276095}, {
       0.8674020641997875, 0.08836440089910105}, {0.8870791224731936, 
       0.09292554363130424}, {0.9067897261308788, 0.09790793643674034}, {
       0.926488944355351, 0.10334725236236089`}, {0.9302539729907617, 
       0.10448424418372179`}}]}, 
     {Arrowheads[{{0.017246037575167, 1.}}], 
      ArrowBox[{{0.9322518841892332, 0.10508758851717587`}, {
       0.9461318463291186, 0.1092791644551175}, {0.965118200391604, 
       0.11560737320723444`}, {0.9838145498748537, 0.12255628798516058`}, {1.,
        0.12928301602368206`}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.4698484210054072, 0.3465605443799955}, {
       0.46738706166913335`, 0.3596410817249591}, {0.4633240490960383, 
       0.3726876306690261}, {0.457659383286122, 0.38570019121219656`}, {
       0.4503930642393844, 0.39867876335447067`}, {0.44177044194476445`, 
       0.41120429878325154`}, {0.4339281246165717, 0.42059345444586943`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.43259023021881526`, 0.4221952384894099}, {
       0.432036866391201, 0.4228577491859427}, {0.42119233757869384`, 
       0.4336391145625443}, {0.40923685550724315`, 0.4435483949130561}, {
       0.39659293613013735`, 0.452242949991347}, {0.38368309540066464`, 
       0.45938013955128604`}, {0.3705073333188251, 0.4649599635928731}, {
       0.36342482183390484`, 0.467079423467663}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.36142540355621916`, 0.46767775455706523`}, {
       0.35706564988461903`, 0.46898242211610813`}, {0.3437268824263662, 
       0.47139452611713756`}, {0.3308598682723866, 0.4721432865921076}, {
       0.3184646074226806, 0.4712287035410182}, {0.306541099877248, 
       0.4686507769638694}, {0.2952551824293374, 0.4646306126995153}, {
       0.28477269187219784`, 0.45938931658680987`}, {0.28131462016300185`, 
       0.4570804631609876}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.2795789151661305, 0.4559215836566713}, {0.2750936282058291,
        0.4529268886257532}, {0.2662179914302313, 0.4452433288163452}, {
       0.2566433358093963, 0.4348704793557795}, {0.24831380866110223`, 
       0.42371364654124627`}, {0.241229409985349, 0.41177283037274554`}, {
       0.23539013978213663`, 0.3990480308502772}, {0.2319727952296946, 
       0.3892000471140389}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.231288600812923, 0.38722835962821683`}, {
       0.22905103883735486`, 0.3807802319647438}, {0.22467506652018276`, 
       0.3627907321413029}, {0.22226222283062036`, 0.3450795313799545}, {
       0.22181250776866765`, 0.3276466296806986}, {0.22318161461700559`, 
       0.3109879879964376}, {0.22436776241397155`, 0.30499087630393384`}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.22477270325629517`, 0.30294351301035183`}, {
       0.22622523665831515`, 0.2955995672800741}, {0.23094337389259637`, 
       0.2814813675316079}, {0.23733602631984924`, 0.26863338875103904`}, {
       0.2453305450169379, 0.25719340789123313`}, {0.2548542810607266, 
       0.24729920190505564`}, {0.26590723445121534`, 0.2389507707925065}, {
       0.27049685236472826`, 0.2364693553367982}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.2723327313742442, 0.23547677193772906`}, {
       0.27848940518840404`, 0.23214811455358578`}, {0.290996391583095, 
       0.22741173016261976`}, {0.3045888444074499, 0.2240129273140036}, {
       0.3191647977414293, 0.22199743235854402`}, {0.3346222856649941, 
       0.2214109716470477}, {0.35077997622539153`, 0.22231989401610966`}, {
       0.35348137971115845`, 0.22272011046379708`}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.35554587116810865`, 0.22302596756420245`}, {
       0.36745653746986917`, 0.22479054830232487`}, {0.3844491893673939, 
       0.2288971636413363}, {0.40137503048693624`, 0.2347703223417191}, {
       0.4184519300111757, 0.24299618271046705`}, {0.43278751582095143`, 
       0.2522958825611998}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.43452816240140885`, 0.25344519973078644`}, {
       0.4487128179356064, 0.26593993531103}, {0.4606353814207669, 
       0.28076134754844156`}, {0.4661966867906484, 0.29023946288035085`}, {
       0.47054346659247903`, 0.3003697519907294}, {0.47367572082625875`, 
       0.3111522148795772}, {0.4755934494919876, 0.3225868515468943}, {
       0.47567331292897874`, 0.32330358276274873`}}]}, 
     {Arrowheads[{{0.004025146755871499, 1.}}], 
      ArrowBox[{{0.47590443415229833`, 0.325377770922444}, {
       0.47607580120362925`, 0.3269156976594488}, {0.4763642501200673, 
       0.33131751451552677`}, {0.4754286632132563, 0.3421195353169626}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.41380171752704636`, 0.3449640905072288}, {
       0.40770285004477563`, 0.3646772241123813}, {0.4026344258834112, 
       0.37426769917470565`}, {0.3964234555565299, 0.38314586218079005`}, {
       0.38906993906413195`, 0.39131171313063445`}, {0.38057387640621726`, 
       0.39876525202423885`}, {0.37132730795356556`, 0.40515919147263163`}, {
       0.3645551387853685, 0.4086753856254054}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.3627028983242328, 0.4096370918257705}, {0.3617222740769566,
        0.4101462440868412}, {0.3414368100518672, 0.4158996888127105}, {
       0.3213187615482785, 0.4158713859780676}, {0.30296940578352005`, 
       0.40990713535913315`}, {0.2871634430168323, 0.39908845875597837`}, {
       0.2853921416839861, 0.3970187633225438}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.2840351269106667, 0.39543314532104357`}, {
       0.27467557350745536`, 0.38449687796867454`}, {0.26858465455945146`, 
       0.37393104979808384`}, {0.26396513656776327`, 0.3630094632021528}, {
       0.2608170195323907, 0.3517321181808814}, {0.25914030345333394`, 
       0.3400990147342695}, {0.25886511437978454`, 0.3285872769337602}, {
       0.2598340127913053, 0.31857857912599513`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.2602652299313875, 0.316547011643625}, {
       0.26602946548733086`, 0.29764300183750503`}, {0.2770715262946723, 
       0.2809458984219935}, {0.29265532224510676`, 0.26852268333186013`}, {
       0.3110356890909092, 0.2610931382560211}, {0.3149477919338616, 
       0.2605853947911781}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.3170174581274978, 0.26031677724035923`}, {
       0.3320431195349979, 0.258366628767564}, {0.3431834274987341, 
       0.2588696914683982}, {0.35452161473672983`, 0.26066795812494853`}, {
       0.3658887071296785, 0.2637938569975954}, {0.3769802283533336, 
       0.2682965534441237}, {0.3865526825367719, 0.2736196344723284}, {
       0.3954208485040193, 0.28009094019793657`}, {0.39542579002741995`, 
       0.2800956731249308}}]}, 
     {Arrowheads[{{0.013833784659198827`, 1.}}], 
      ArrowBox[{{0.39693300876401444`, 0.28153926767387705`}, {
       0.4033364174380819, 0.28767236941426905`}, {0.41005108052196565`, 
       0.29632582091464665`}, {0.4171835977159737, 0.3106667736265743}, {
       0.4206584806801402, 0.32675243309917046`}, {0.42092066592217714`, 
       0.32945350408387497`}, {0.4210753909962162, 
       0.33218508411923914`}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{1., 0.4358896004140806}, {0.999202823522861, 
       0.4382347304706924}, {0.9917468438923973, 0.45737524087153514`}, {
       0.9829293799058535, 0.47725348456514516`}, {0.9780331118533612, 
       0.4874383643713502}, {0.9728240974010205, 0.4977706070702818}, {
       0.9673115447785552, 0.5082378558517849}, {0.9653812554480024, 
       0.5117580867164219}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.96437780963231, 0.5135880512069676}, {0.9615046622156893, 
       0.5188277539057045}, {0.9554126579421467, 0.5295279444218852}, {
       0.9490447401876512, 0.5403260705901722}, {0.9424101171819266, 
       0.5512097756004104}, {0.9355179971546969, 0.5621667026424446}, {
       0.928377588335686, 0.5731844949061199}, {0.9209980989546176, 
       0.584250795581281}, {0.9206954971762256, 0.5846923072257416}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.9195156206943651, 0.5864138080329564}, {0.9133887372412157,
        0.595353247857773}, {0.9055587114252043, 0.6064794949254406}, {
       0.8967163094348741, 0.6187018726643475}, {0.8876246435111246, 
       0.630913645848573}, {0.878296948194151, 0.6430997460907035}, {
       0.8700251991585966, 0.653618929827209}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.868734962917753, 0.655259343726222}, {0.8589864075413133, 
       0.6673346541990249}, {0.8490300312858398, 0.6793533252903885}, {
       0.8388905637979236, 0.6912860498900025}, {0.8274518921877563, 
       0.7044035953364166}, {0.8165602348125903, 0.7166039215854292}, {
       0.8145785647426624, 0.718771406810349}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.8131703164090877, 0.7203117022926098}, {0.8055119552853724,
        0.7286881645678648}, {0.7943070536061028, 0.7406563242837236}, {
       0.7829455297747812, 0.7525084007330057}, {0.7714273837914076, 
       0.7642443939157109}, {0.7597526156559823, 0.7758643038318392}, {
       0.7551621371663846, 0.7803276904245985}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.753665819466676, 0.781782581102013}, {0.747921225368505, 
       0.7873681304813909}, {0.7359332129289761, 0.7987558738643655}, {
       0.7238496123834913, 0.8099700293054332}, {0.7117314577781471, 
       0.8209530921292633}, {0.6995787491129434, 0.831705062335856}, {
       0.6921094596329983, 0.8381530631766317}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.6905296634604433, 0.839516851134809}, {0.6873914863878803, 
       0.8422259399252112}, {0.6751696696029577, 0.852515724897329}, {
       0.6629132987581756, 0.8625744172522093}, {0.6506223738535342, 
       0.8724020169898521}, {0.6382968948890333, 0.8819985241102575}, {
       0.6254179497137078, 0.8917355063241746}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.623760678555952, 0.8930039253419465}, {0.6104598988773183, 
       0.9033812257065638}, {0.5966293709584766, 0.9133323624536986}, {
       0.5827988430396347, 0.9232834992008335}, {0.566076226187383, 
       0.9334481844334773}, {0.5549977558045452, 0.940182128366753}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.553214345091308, 0.9412661577803756}, {0.5493536093351313, 
       0.9436128696661212}, {0.5332961081703107, 0.9520743704638802}, {
       0.5169725607305177, 0.9612171450355931}, {0.5009412474278216, 
       0.9696693954840184}, {0.4852283561243472, 0.9774218714598227}, {
       0.4793566073096926, 0.9801119084382323}}]}, 
     {Arrowheads[{{0.012279471853945307`, 1.}}], 
      ArrowBox[{{0.47745922170732696`, 0.9809811618061431}, {
       0.4698338868200945, 0.984474572963006}, {0.45475783951506343`, 
       0.9908274999935681}, {0.44002737136096814`, 0.9964878620763413}, {
       0.42989143828966614`, 1.}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.8073798586120533, 0.36389245567567624`}, {
       0.8044717838404383, 0.3790625668593176}, {0.8005048899298021, 
       0.39474319572648103`}, {0.795499442135885, 0.4108799417670934}, {
       0.7894757057144269, 0.4274184044710816}, {0.7828087495997152, 
       0.44345095897577497`}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.7819630100305467, 0.4453584515705254}, {0.7744544280118492,
        0.4614828778288923}, {0.7654055077919176, 0.4789418980177234}, {
       0.7552689626851101, 0.4966534501017085}, {0.7441151903745985, 
       0.5145403278134176}, {0.7415793124112844, 0.5183093765253715}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.7404142773730986, 0.5200409558338318}, {0.7320145885435551,
        0.5325253248854206}, {0.7256312258338253, 0.54153049122296}, {
       0.7190375548751518, 0.5505312350502873}, {0.7122423753779312, 
       0.5595179055839731}, {0.7052544870525608, 0.5684808520405878}, {
       0.6980826896094363, 0.5774104236367036}, {0.6907357827589545, 
       0.5862969695888914}, {0.690331924440794, 0.5867718170349379}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.6889798034471953, 0.5883616102165682}, {0.6832225662115119,
        0.5951308391137227}, {0.6755518396775043, 0.6039023814277692}, {
       0.6677311827457219, 0.6125891994675575}, {0.6597683872000165, 
       0.6211711129139699}, {0.6516725710433775, 0.6296417961001113}, {
       0.6434528522787945, 0.6379949233590863}, {0.635118348909257, 
       0.6462241690239992}, {0.6319454239240302, 0.6492688519385599}}]}, 
     {Arrowheads[{{0.020000000000000014`, 1.}}], 
      ArrowBox[{{0.6304395563758626, 0.6507138559070889}, {0.6266781789377543,
        0.654323207427955}, {0.6181414603672765, 0.6622857129040578}, {
       0.6095173112008138, 0.6701053597854114}, {0.6008148494413552, 
       0.6777758224051208}, {0.5920431930918901, 0.6852907750962909}, {
       0.5832114601554084, 0.6926438921920257}, {0.5743287686349003, 
       0.6998288480254291}, {0.5673417402783386, 0.7053173536937318}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.565700525610089, 0.7066065735952269}, {0.5654042365333553, 
       0.7068393169296062}, {0.556446981853762, 0.7136689732376618}, {
       0.5474661225991108, 0.7203114912826999}, {0.5384707767723919, 
       0.7267605453978246}, {0.520551729027548, 0.7389133829284715}, {
       0.5028128209422276, 0.7499880592493501}, {0.49670295719561186`, 
       0.7534813737869596}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.4948911629215736, 0.7545172671454917}, {0.4852841065697078,
        0.7600101015210857}, {0.46799563996326543`, 0.7690050369043041}, {
       0.4509774751761776, 0.7769983925596308}, {0.4342596662617212, 
       0.7840156956476911}, {0.41926116626351373`, 0.7895682891439187}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.4172952329149406, 0.7902675981452374}, {0.4018453322638108,
        0.7952242527645152}, {0.3880246626565423, 0.799004759015934}, {
       0.37460873366756603`, 0.8020626308818766}, {0.3615963326119711, 
       0.8044255633849513}, {0.34898624680484713`, 0.8061212515477667}, {
       0.3367772635612837, 0.8071773903929309}, {0.3358142503294071, 
       0.8072136211083012}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.3337287007395474, 0.8072920841564502}, {0.3249681701963704,
        0.8076216749430523}, {0.31355775402519687`, 0.8074818002207391}, {
       0.30264828480853984`, 0.8044221526526907}, {0.2818891530181773, 
       0.7996614539056237}, {0.2627150285234902, 0.7927856782496849}, {
       0.2535393614170705, 0.7880954445555096}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.25168103872734965`, 0.7871455443909885}, {
       0.24512591132447897`, 0.7837948256848744}, {0.22912180142114402`, 
       0.7726888962111925}, {0.214526932425031, 0.7599445480299446}, {
       0.2011655379476863, 0.7460384393424363}, {0.1898929654062279, 
       0.7320332637548576}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.18863473526027638`, 0.7303703893007638}, {
       0.17814317254930176`, 0.7147409404486383}, {0.17116133377753057`, 
       0.7029159230814476}, {0.16457946027764045`, 0.69093445109263}, {
       0.15839755204963107`, 0.678796524482185}, {0.15261560909350266`, 
       0.6665021432501128}, {0.14862939273940043`, 0.6572803054027494}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.14780131020002632`, 0.6553645933028575}, {
       0.14723363140925513`, 0.6540513073964134}, {0.14225161899688854`, 
       0.6414440169210869}, {0.13766957185640288`, 0.6286802718241332}, {
       0.13348748998779808`, 0.6157600721055523}, {0.12962280311000318`, 
       0.6028088404637836}, {0.12599294094194702`, 0.5899519995972662}, {
       0.12259790348362962`, 0.5771895495060003}, {0.12229012773130792`, 
       0.5759557966555962}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.12178497321388883`, 0.5739308293829668}, {
       0.11943769073505096`, 0.5645214901899857}, {0.11651230269621105`, 
       0.5519478216492225}, {0.11382173936710989`, 0.5394685438837107}, {
       0.11136600074774747`, 0.5270836568934503}, {0.10914508683812384`, 
       0.5147931606784414}, {0.10706431150346235`, 0.5023570180498141}, {
       0.10544152848740804`, 0.49210140522016815`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.10511636701680058`, 0.49003987052121845`}, {
       0.10334888289858407`, 0.47818072256267186`}, {0.10170807315586564`, 
       0.46643811902012994`}, {0.1002077621379598, 0.45492424448892194`}, {
       0.09884487160861576, 0.44363787362703444`}, {0.09761632333158268, 
       0.4325777810924539}, {0.09651903907060963, 0.42174274154316593`}, {
       0.09526007244185622, 0.407160959630964}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.09508055005986386, 0.4050816700272646}, {
       0.09470594965184036, 0.40074292003241413`}, {0.09338097746230106, 
       0.38062860635866846`}, {0.09251949661198494, 0.3613899977858194}, {
       0.09209688121088513, 0.34301729157775634`}, {0.09204050477963806, 
       0.3255396889709389}, {0.09209976134079702, 0.32168508613587077`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.09213184125197468, 0.3195983076567342}, {
       0.09229519559864623, 0.30897220793907376`}, {0.09286250991755193, 
       0.2932837708519218}, {0.0937440039859974, 0.27844330007924434`}, {
       0.09494123405362492, 0.2644197179908022}, {0.09645575637007676, 
       0.2511819469563562}, {0.09828912718499519, 0.2386989093456675}, {
       0.09869856187348246, 0.23646344019383597`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.09907455408808416, 0.2344105633353158}, {
       0.10044290274802245`, 0.22693952752849714`}, {0.10287229054369727`, 
       0.21586448069801578`}, {0.10554935215295971`, 0.20543744556615426`}, {
       0.11175384638922413`, 0.18642108498989535`}, {0.11927108461076924`, 
       0.1696777949829289}, {0.1273615840512988, 0.1565439156520064}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.12848364480748323`, 0.15478636821196842`}, {
       0.13621150480131633`, 0.1451860183447364}, {0.14517945051870867`, 
       0.13625174413637012`}, {0.15530440870393783`, 0.12814477583855935`}, {
       0.16576659208161915`, 0.12132260067775581`}, {0.1777674130380921, 
       0.11511476323588385`}, {0.1910948576228263, 0.10963957917495674`}, {
       0.19596393228046638`, 0.10806378905228596`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.1979495609433084, 0.10742117536196416`}, {
       0.20574892583582166`, 0.10489704849497454`}, {0.2217296176770782, 
       0.10088717119593724`}, {0.23924249706981132`, 0.09758373932056916}, {
       0.25849312793723644`, 0.09496054491159464}, {0.26877010017395847`, 
       0.09390403675700497}, {0.2794815102793535, 0.0930175879690137}, {
       0.2799583801765773, 0.09298693758238123}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.2820411076153421, 0.09285307213685863}, {
       0.29062735825342145`, 0.09230119854762081}, {0.3022076440961624, 
       0.09175486849282631}, {0.3136479069953205, 0.09140181509283925}, {
       0.32554358466018635`, 0.09121951082518208}, {0.33789467709076015`, 
       0.09120795568985482}, {0.3507011842870418, 0.09136714968685747}, {
       0.3639752262037902, 0.09171364506613382}, {0.3654779498112923, 
       0.09177377598776691}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.36756330601969933`, 0.09185722073443808}, {
       0.3777289227957643, 0.0922639940776277}, {0.39196227406296413`, 
       0.09301819672133911}, {0.4066752800053898, 0.09397625299726804}, {
       0.42186223284755003`, 0.09516739193282833}, {0.4375174248139535, 
       0.09662084255543384}, {0.45079610759085187`, 0.09803388319810613}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.45287141533717934`, 0.09825472544886876}, {
       0.45364085590460035`, 0.09833660486508453}, {0.47023252611949035`, 
       0.10031467886178042`}, {0.48727123638722386`, 0.10259023303132987`}, {
       0.5048777346302155, 0.10530931874576187`}, {0.5225552063701242, 
       0.10808384590330573`}, {0.53540084886298, 0.1106474390090812}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.5374475147208976, 0.11105589023961339`}, {
       0.5410876683557392, 0.11178235236616202`}, {0.5616779246553788, 
       0.11596585960283748`}, {0.5826587640061222, 0.12072001062486018`}, {
       0.593253662475065, 0.12333902075355077`}, {0.6038958188860722, 
       0.12613422366638696`}, {0.6145684372989069, 0.12911679664263837`}, {
       0.6186388306326558, 0.1303284816741421}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.6206391093987331, 0.13092392974044934`}, {
       0.6252547217733317, 0.13229791696157464`}, {0.6359938462208291, 
       0.13566709757081008`}, {0.6468046318795286, 0.13922172935674276`}, {
       0.6576397537991644, 0.1429848065068179}, {0.6684518870294707, 
       0.14697932320848073`}, {0.6791937066201813, 0.1512282736491764}, {
       0.6898178876210306, 0.15575465201635014`}, {0.6988373253904687, 
       0.15991701184185703`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.7007250343912708, 0.1608065865892243}, {0.7105240340520811,
        0.16573166927991273`}, {0.724739370043852, 0.17374801117554642`}, {
       0.7382509925534011, 0.18256948283871066`}, {0.750935705407927, 
       0.19225044582453263`}, {0.7639844049445084, 0.20226540510011623`}, {
       0.7695236744894917, 0.20754434731485225`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.7710344988297665, 0.20898416791288588`}, {
       0.7756518120484609, 0.21338448269642984`}, {0.7862459171517877, 
       0.22547177472565555`}, {0.7957667202544889, 0.23852728118779332`}, {
       0.8042142213565644, 0.25255100208284315`}, {0.8113069607449845, 
       0.26762978394356524`}, {0.8150808332134601, 0.27884844269654396`}}]}, 
     {Arrowheads[{{0.0191128817499882, 1.}}], 
      ArrowBox[{{0.815746252165247, 0.28082654561608367`}, {
       0.8167634787067198, 0.2838504733027197}, {0.8205837752417702, 
       0.3012130701603065}, {0.8227678503501358, 0.3197175745163257}, {
       0.8237614867416204, 0.333593536017711}, {0.8237428738971012, 
       0.34810104829645205`}, {0.821746187648731, 0.3596880726484256}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.3647124520024183, 0.6427311205669334}, {
       0.35355903003505706`, 0.6444911204178811}, {0.3427309540085721, 
       0.6456326870351539}, {0.3220562037739203, 0.6461722712389611}, {
       0.30269892928983855`, 0.6445733745189285}, {0.2845554266396916, 
       0.6386754839161787}, {0.2826015839974952, 0.6378567379231354}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.28067672789459713`, 0.6370501385648262}, {
       0.2677776757013072, 0.6316448684221698}, {0.2523388564962453, 
       0.6229227746854682}, {0.238238969024506, 0.612509202706074}, {
       0.22547801328608896`, 0.6004041524839868}, {0.21457829782926355`, 
       0.5878237786304217}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.21327480935214707`, 0.5861957449958124}, {
       0.2034276770048433, 0.5729435675083837}, {0.19400199146091984`, 
       0.5580440203040299}, {0.1856426276481294, 0.5423649699553079}, {
       0.1802620161968396, 0.5309232873272529}, {0.1752570439059912, 
       0.5194645044400383}, {0.1728537769000644, 0.5135069268467558}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.17207301116058565`, 0.5115714479908277}, {
       0.1706277107755842, 0.507988621293664}, {0.16637401680561864`, 
       0.49649563788813017`}, {0.16249596199609448`, 0.4849855542234367}, {
       0.15899354634701166`, 0.4734583702995833}, {0.1558667698583702, 
       0.4619140861165703}, {0.15311563253017013`, 0.4503527016743974}, {
       0.1506747124080406, 0.43888096654741}, {0.1492224350275804, 
       0.4314246893587928}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.1488234378372577, 0.42937615945083357`}, {
       0.14847858753761062`, 0.42760563030995297`}, {0.14652725791888027`, 
       0.41652669296202627`}, {0.1448207235518495, 0.40564415450362995`}, {
       0.1421420405728868, 0.38446827425542834`}, {0.14044253860072245`, 
       0.3640779895653483}, {0.13969583932915872`, 0.34836219154846265`}, {
       0.13965863402168105`, 0.34648950289945346`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.13961717860473385`, 0.34440288961709986`}, {
       0.13939639628996278`, 0.3332900521537369}, {0.1395442094831346, 
       0.31886157138117094`}, {0.1401392789086742, 0.3050767492307647}, {
       0.14118160456658158`, 0.2919355857025182}, {0.14267118645685675`, 
       0.2794380807964313}, {0.14460802457949973`, 0.2675842345125041}, {
       0.14593095504217754`, 0.2613637178123502}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.14636509764215236`, 0.2593223472569204}, {
       0.14699211893451042`, 0.25637404685073695`}, {0.1530738492636582, 
       0.2357020654282128}, {0.16088815036632315`, 0.21723955456338978`}, {
       0.17043502224250526`, 0.20098651425626812`}, {0.18171446489220455`, 
       0.18694294450684767`}, {0.18315412082174196`, 0.18554221637680343`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.18464995523152467`, 0.18408682881323188`}, {
       0.18923860799590528`, 0.17962225163600418`}, {0.19747211434045603`, 
       0.17293541631836365`}, {0.2064149839258568, 0.1668824385539261}, {
       0.21606721675210766`, 0.16146331834269143`}, {0.2264830917660421, 
       0.15665174612063076`}, {0.23771688791449366`, 0.1524214123237151}, {
       0.2497686051974624, 0.1487723169519444}, {0.25807029058668945`, 
       0.14679336600057674`}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.2601004314530318, 0.14630942219754223`}, {
       0.2626382436149483, 0.14570446000531867`}, {0.27636659575866074`, 
       0.1432245425000902}, {0.29099445422030923`, 0.14133926545251124`}, {
       0.30652181899989367`, 0.14004862886258176`}, {0.32294869009741406`, 
       0.13935263273030182`}, {0.33734821535849757`, 0.13922629858992397`}, {
       0.34309727937744855`, 0.13933492957599697`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.3451839319504397, 0.139374357755236}, {
       0.35243524191425424`, 0.13951137431116464`}, {0.36820976976468417`, 
       0.14020785989402382`}, {0.3842975414898819, 0.14170941821909533`}, {
       0.4011463051999996, 0.14357641560300285`}, {0.4185742738876364, 
       0.14600633089750167`}, {0.42816730664361763`, 0.14764728279922013`}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.4302244522609357, 0.14799917120601674`}, {
       0.4364792240712496, 0.14906909142395305`}, {0.4547589322692965, 
       0.15283462450371818`}, {0.47339834976586903`, 0.15734732381451583`}, {
       0.49231268803255157`, 0.16267200994897874`}, {0.5109754527079444, 
       0.16880421641785429`}}]}, 
     {Arrowheads[{{0.020000000000000014`, 1.}}], 
      ArrowBox[{{0.5129289008807785, 0.16953787242770388`}, {
       0.5301387940750312, 0.17615961346382966`}, {0.548802969329665, 
       0.18450017486829628`}, {0.5671140212085269, 0.1940268042352943}, {
       0.58466582785598, 0.20486825889461924`}, {0.5873277968393052, 
       0.20686395711091893`}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.5889976512626947, 0.20811585956174147`}, {
       0.601052267416387, 0.21715329617606655`}, {0.6132789775296256, 
       0.2283784858357823}, {0.6244740723797668, 0.24068117870555653`}, {
       0.6343344413973138, 0.25413993877806823`}, {0.6426916898214347, 
       0.2687984127159168}, {0.6433192884820186, 0.2702974146496551}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.6441252879772226, 0.27222252201170527`}, {
       0.6493417610779026, 0.2846819228299584}, {0.6540805985924905, 
       0.301815791431049}, {0.6565740419391667, 0.32029455472547924`}, {
       0.6567621734438132, 0.3399764412913882}, {0.6555306131281988, 
       0.35378916872152644`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.6553452665944643, 0.3558679472581006}, {0.6553179620956335,
        0.35617418447213295`}, {0.6522857379679696, 0.3730432391949896}, {
       0.6476860252883574, 0.39047177422126933`}, {0.6415393482843327, 
       0.4083479583122832}, {0.6337267151126894, 0.4266590849240871}, {
       0.6295577883233758, 0.4348572381965688}}]}, 
     {Arrowheads[{{0.019999999999999987`, 1.}}], 
      ArrowBox[{{0.6286117836755561, 0.43671754697416254`}, {
       0.6242407467868151, 0.44531314775694103`}, {0.6189289942886744, 
       0.45469666123364216`}, {0.613269386819136, 0.46407936593846233`}, {
       0.6072854173172529, 0.4734324142623536}, {0.6010005787220787, 
       0.4827269585962682}, {0.5946633009312716, 0.49161933767371324`}, {
       0.5880984067644569, 0.5003778453282381}, {0.5832066059862181, 
       0.5065926124941568}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.5819157666471307, 0.5082325537560175}, {0.5813237576821605,
        0.5089846689880592}, {0.5743572151449087, 0.5174219960813928}, {
       0.5672166406132275, 0.5256720140364551}, {0.559919895547643, 
       0.5337169102814625}, {0.5524848414086813, 0.5415388722446313}, {
       0.5434051616919756, 0.5506400934797205}, {0.5351725301409153, 
       0.5585357202229034}, {0.5268373124375297, 0.5661727875406802}, {
       0.5242397867421068, 0.5684442155297705}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.5226687186728074, 0.569818049094405}, {0.5183995085818193, 
       0.5735512954330511}, {0.5098591185737837, 0.5806712439000158}, {
       0.501216142413423, 0.5875326329415745}, {0.4924705801007374, 
       0.5941354625577272}, {0.47467169701839085`, 0.6065654435138144}, {
       0.45674559763961664`, 0.6177775339153692}, {0.45513135744271677`, 
       0.6186687220040804}}]}, 
     {Arrowheads[{{0.01886448952114178, 1.}}], 
      ArrowBox[{{0.4533042791805667, 0.6196774135157268}, {
       0.43897541027728726`, 0.6275880809094831}, {0.4213611349314028, 
       0.6359970844961564}, {0.40390277160196325`, 0.643004544675389}, {
       0.39242556922519917`, 0.6471691846992335}, {0.38112448336314103`, 
       0.6506791876289283}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.2648522945743053, 1.}, {0.24852511911139763`, 
       0.9928036364239187}, {0.23330210675428587`, 0.984310128602532}, {
       0.21919584047618548`, 0.9745250226053563}, {0.20620632027709646`, 
       0.9634483184323919}, {0.19604464417376338`, 0.9538659138700518}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.19452625095635007`, 0.9524340774342108}, {
       0.1943430502503111, 0.9522613201780731}, {0.18336091145146066`, 
       0.9401728412321555}, {0.17611444701309453`, 0.9291064466920915}, {
       0.1688679825747284, 0.9180400521520276}, {0.16264387943800987`, 
       0.9062677667155407}, {0.1560108317806323, 0.894777837637623}, {
       0.14975908304744204`, 0.8830456588218595}, {0.14950923004419558`, 
       0.8825401013542956}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.14858455631960016`, 0.8806690984027395}, {
       0.14386098764196742`, 0.8711113368889737}, {0.1383165455642084, 
       0.8589748718389656}, {0.13312575681416497`, 0.8466362636718352}, {
       0.12824910976953657`, 0.8341585381398612}, {0.12364709280802258`, 
       0.8216047209953223}, {0.11931970592962299`, 0.8089748122382187}, {
       0.11750479196767444`, 0.8032847847738857}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.11687058622822502`, 0.801296454665041}, {
       0.11526694913433781`, 0.79626881186855}, {0.1115272935624612, 
       0.7834311183086744}, {0.10788273608565964`, 0.7707768071652308}, {
       0.10448203177973718`, 0.758090885671336}, {0.10130979218857614`, 
       0.7453955944580469}, {0.09822795157679348, 0.732171029727423}, {
       0.09570522388252577, 0.7205768503790708}}]}, 
     {Arrowheads[{{0.020000000000000014`, 1.}}], 
      ArrowBox[{{0.09526737779495953, 0.7185363027119914}, {0.092682577944064,
        0.7058524466369427}, {0.09018330096388247, 0.6928073151734866}, {
       0.08784246790166664, 0.6798708816954864}, {0.08564220677779917, 
       0.6670675896511423}, {0.08356464561266269, 0.6544218824886545}, {
       0.08159191242663989, 0.6419582036562228}, {0.08074039786969833, 
       0.6363398563943471}}]}, 
     {Arrowheads[{{0.009820011824047207, 1.}}], 
      ArrowBox[{{0.08042766059825569, 0.6342763959656644}, {
       0.07972851433263081, 0.62966338439105}, {0.07798584431815625, 
       0.6175126829423397}, {0.07635635921552997, 0.6055131832762931}, {
       0.07483251585706574, 0.5936719693591114}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.7558400967533421, 0.1720442335822622}, {0.76825321571921, 
       0.17983743416780953`}, {0.7802269093205281, 0.1882198556804739}, {
       0.7916729781633575, 0.1972329821142624}, {0.8025032228537593, 
       0.2069182974631821}, {0.812645979639961, 0.21732232483812344`}, {
       0.8194474135043865, 0.22542654357132982`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.8207890647335577, 0.22702518221747603`}, {
       0.822016356256457, 0.22848755605647023`}, {0.8305063105387092, 
       0.2404494281719694}, {0.8380078003221797, 0.25324337823836807`}, {
       0.8453909684111173, 0.26943714098688226`}, {0.8510572522767583, 
       0.2869295591073323}, {0.8542153934777307, 0.30250017655407857`}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.8546302510847511, 0.3045455534649647}, {0.8548680796799628,
        0.3057181223395924}, {0.8566848783815905, 0.32580032042353674`}, {
       0.8567661807875685, 0.3363707299420495}, {0.8562380493897259, 
       0.3473372135115786}, {0.8551028166710865, 0.3586749217877277}, {
       0.8533628151146739, 0.3703590054261001}, {0.8510203772035121, 
       0.3823646150822993}, {0.849826755744366, 0.3873549513436241}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.8493412618280314, 0.3893847220693197}, {0.8480778354206246,
        0.3946669014119288}, {0.8445375222490356, 0.40724101507059196`}, {
       0.8404017701717683, 0.4200621067138923}, {0.8335407204612532, 
       0.4384919515192678}, {0.8254618553980224, 0.45730316181999003`}, {
       0.8209760150398937, 0.4668283433729782}, {0.8205977639370918, 
       0.4675877324968092}}]}, 
     {Arrowheads[{{0.020000000000000018`, 1.}}], 
      ArrowBox[{{0.8196672597904188, 0.46945584265809864`}, {
       0.8161980483604923, 0.4764207435100495}, {0.8111320645321198, 
       0.4860709879679527}, {0.8054315233573077, 0.4965696396142045}, {
       0.7996696543721852, 0.5066089887252646}, {0.7936279865826957, 
       0.5166874336306542}, {0.7873065199888395, 0.5268049743303733}, {
       0.7807052545906163, 0.5369616108244221}, {0.7776368736864078, 
       0.541508057324123}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.7764693628118502, 0.5432379682754377}, {0.7738241903880264,
        0.5471573431128003}, {0.7666633273810696, 0.5573921711955081}, {
       0.7592226655697459, 0.5676660950725455}, {0.7515022049540553, 
       0.5779791147439125}, {0.743540026531167, 0.5882800097248886}, {
       0.7353742112982503, 0.5985175595307533}, {0.7270047592553049, 
       0.6086917641615065}, {0.726096563155937, 0.6097628650536531}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.7247468380417282, 0.6113546928262978}, {0.7184316704023311,
        0.6188026236171484}, {0.7096549447393288, 0.6288501378976791}, {
       0.7006745822662979, 0.6388343070030982}, {0.6914905829832385, 
       0.648755130933406}, {0.6821029468901506, 0.6586126096886025}, {
       0.6723528784060638, 0.6685624655649248}, {0.6682961782470421, 
       0.6728245813007073}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.6668573078017345, 0.6743363105698917}, {0.6627551946004911,
        0.6786461388883832}, {0.6527765490986333, 0.6883952685940017}, {
       0.6427979035967754, 0.6981443982996202}, {0.6344484900797913, 
       0.7051324251325969}, {0.6260990765628072, 0.7121204519655736}, {
       0.6177496630458231, 0.7191084787985503}, {0.6094002495288391, 
       0.7260965056315271}, {0.6045053663811645, 0.729700401311655}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.6028247258045671, 0.7309377859705155}, {0.5925794050143681,
        0.7384809828606933}, {0.5758073674920983, 0.7515020906645744}, {
       0.5590539676366975, 0.7638391796269073}, {0.542386650107236, 
       0.7754448614808581}, {0.5353545682862629, 0.7800566282651771}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.533609369716329, 0.7812011611363473}, {0.5258054149037139, 
       0.7863191362264272}, {0.509310262026131, 0.7964620038636145}, {
       0.4929890127866728, 0.8058287733849974}, {0.4769294884975245, 
       0.814374753783153}, {0.4611316891586861, 0.8220999450580816}, {
       0.46095891414091916`, 0.8221767281742407}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.45905174287079187`, 0.8230242960406029}, {
       0.4455956147701575, 0.8290043472097831}, {0.43037820156040674`, 
       0.8350838639012108}, {0.41553638575790147`, 0.8403343987953182}, {
       0.4010701673626418, 0.8447559518921054}, {0.38697954637462767`, 
       0.8483485231915723}, {0.38016804645943975`, 0.849766830051367}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.3781248445592521, 0.850192270454665}, {
       0.37486993151887704`, 0.8508700162596536}, {0.3630966899272642, 
       0.8528212696777577}, {0.35165982159978904`, 0.8542022834458843}, {
       0.3405593265364516, 0.8550130575640336}, {0.31936745620219, 
       0.8549238868503999}, {0.2995210789244792, 0.8525537575368567}, {
       0.2952439788727772, 0.8515514880435259}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.29321199869025033`, 0.8510753262228107}, {
       0.2809772897671576, 0.8482083192869969}, {0.26369318379406326`, 
       0.8421932217644138}, {0.24766876100519622`, 0.834508464969107}, {
       0.23290402140055647`, 0.8251540489010768}, {0.21971602862650527`, 
       0.8138593839594848}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.2181428421161896, 0.8124879906695244}, {0.2067418578068746,
        0.8025293064807956}, {0.19506651341030062`, 0.7899968007139605}, {
       0.184465571926266, 0.7762865160646794}, {0.17819171287517652`, 
       0.7669757633904906}, {0.1722828874710676, 0.7573404609703555}, {
       0.16672069797854738`, 0.7474421470243946}}]}, 
     {Arrowheads[{{0.018502056695204765`, 1.}}], 
      ArrowBox[{{0.16575997982069637`, 0.7455894001831227}, {
       0.16146744453794953`, 0.7373080102623158}, {0.15651438047601926`, 
       0.7270167636594461}, {0.15183345699522746`, 0.7166127706806997}, {
       0.14740145082911357`, 0.706148982168594}, {0.14319513871121706`, 
       0.6956783489656463}, {0.1392137513947269, 0.6851848787974639}, {
       0.13546342856195492`, 0.6746313661229129}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.050398621317108504`, 1.}, {0.04976279366974351, 
       0.9947319355691668}, {0.047988578038598975`, 0.9792136128052202}, {
       0.04632280447680771, 0.9638342757497915}, {0.04476285896070038, 
       0.9485916466885079}, {0.043304325493195565`, 0.9334870964343814}, {
       0.0419385032147101, 0.9185304155690547}, {0.04180308546480711, 
       0.9169662285494343}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.04162307692096611, 0.9148869809773946}, {
       0.04065722220817172, 0.903730560156088}, {0.03945284349901899, 
       0.8890956517409598}, {0.038318259055201254`, 0.8746329773510656}, {
       0.03724689178717869, 0.8603489894957186}, {0.03623269554792228, 
       0.8462493061661495}, {0.035265354044680224`, 0.8323467660632595}, {
       0.03521838732805239, 0.8316533721207898}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.03507734683029333, 0.829571118265065}, {
       0.03433755715492307, 0.8186492204524481}, {0.03344818031366286, 
       0.8051541988127899}, {0.0325961177823442, 0.7918592553295704}, {
       0.03178028264884422, 0.7787619688942863}, {0.030999606827472666`, 
       0.7658599431046457}, {0.030253041058971808`, 0.7531508062645678}, {
       0.029859951011063052`, 0.7462537766979328}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.02974119560213447, 0.744170133087682}, {
       0.029539554910516446`, 0.7406322113841821}, {0.028858136775714027`, 
       0.7283018361798309}, {0.02820779387460455, 0.7161573830740675}, {
       0.027587552253660493`, 0.704196579195655}, {0.02699645678578695, 
       0.6924171763795688}, {0.026433571170321565`, 0.6808169511669947}, {
       0.025897977933034548`, 0.6693937048053304}, {0.025508817604546333`, 
       0.6607969816113927}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.02541443787048617, 0.6587120916844451}, {
       0.025388778426128668`, 0.6581452632481843}, {0.02490509282823925, 
       0.6470694771553764}, {0.024010838206213962`, 0.6254273975331095}, {
       0.023208552024692533`, 0.6044507653413116}, {0.02249187346432982, 
       0.584123275282143}, {0.022206213583508484`, 0.5752932803955013}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.02213873137091623, 0.5732073466255382}, {
       0.021854742928701633`, 0.5644290173571429}, {0.0212914020443048, 
       0.54535247686723}, {0.020796393660557112`, 0.5268785344127017}, {
       0.020364561849797326`, 0.5089924658932339}, {0.019991051907285187`, 
       0.49167994250788116`}, {0.019953116506185774`, 
       0.48975549875437446`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.01991198422874002, 0.48766887907713546`}, {
       0.01969326889728206, 0.47657356068792417`}, {0.019422277003557316`, 
       0.46190507726578345`}, {0.019177683288023533`, 0.4476658906432516}, {
       0.01895913761965183, 0.43384759569974346`}, {0.018766332674471916`, 
       0.42044198379229714`}, {0.018599003935572046`, 0.407441042755573}, {
       0.018562459754514284`, 0.4041990335955143}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.01853893613921727, 0.40211214112554555`}, {
       0.018456929693099033`, 0.3948369569018536}, {0.01833993104425825, 
       0.38262210702104393`}, {0.018247871893313634`, 0.37078907038067177`}, {
       0.018180658951587682`, 0.3593306207258873}, {0.018138241737461456`, 
       0.34823972827946315`}, {0.01812061257637457, 0.33750955974179453`}, {
       0.01815695994290824, 0.31863284760039634`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.01816054531233494, 0.31654582575717827`}, {
       0.018182429410352745`, 0.2975298205088523}, {0.01834306717379008, 
       0.2794403421326403}, {0.01856324549879876, 0.2624216020972727}, {
       0.018844786499472407`, 0.246427579021301}, {0.019151385066235028`, 
       0.2330729707554289}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.019201897620639653`, 0.23098656345591254`}, {
       0.01959924498418909, 0.2173295982217518}, {0.02007580669641938, 
       0.20413359773527753`}, {0.020621019540689123`, 0.1917782286824059}, {
       0.021236705631091937`, 0.18021746968168872`}, {0.02266503388061709, 
       0.15917695228536557`}, {0.02372516338328334, 
       0.14764540289724024`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.023916224087294307`, 0.14556714176132118`}, {
       0.024371017932532976`, 0.14062012568960996`}, {0.026395337250853586`, 
       0.12432131167350532`}, {0.028778671299592967`, 0.1100548320161348}, {
       0.031528867039119404`, 0.09751865744702448}, {0.03468003743271776, 
       0.08647183953534626}, {0.04250561605568574, 0.06831004583849504}, {
       0.04454328244651459, 0.06543108037836975}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.04574898828492935, 0.06372757018676498}, {
       0.05102574663539031, 0.05627217655570779}, {0.06173728417730136, 
       0.04665975642253011}, {0.0751596274399602, 0.03900481728972042}, {
       0.09196902370484901, 0.03294274502132427}, {0.10184646425481253`, 
       0.030414684658063018`}, {0.11281378510535302`, 
       0.028171621847043242`}, {0.11799059584790612`, 0.02733546994707884}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.12005091876418142`, 0.027002689204908198`}, {
       0.12504441710866254`, 0.02619614569079321}, {0.13871179111693327`, 
       0.02447084529184118}, {0.15387709991924015`, 0.02296643190281708}, {
       0.17069132675515192`, 0.021663119056269494`}, {0.18946258815260117`, 
       0.0205577492746047}, {0.20318849458222088`, 
       0.019963608355564266`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.20527356715628706`, 0.019873353701580294`}, {
       0.21049900063952043`, 0.01964716508022897}, {0.22649848208252732`, 
       0.019128510863113346`}, {0.24370472529904608`, 
       0.018695409317960772`}, {0.2622620807698868, 0.01834908333603296}, {
       0.2822507432066105, 0.018090212301364192`}, {0.28873064734877885`, 
       0.018031436609705517`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.2908175865467466, 0.018012507117521837`}, {
       0.29280930968655444`, 0.017994441278496073`}, {0.30378069320672124`, 
       0.017922271770930955`}, {0.3151648937671108, 0.017873703778668842`}, {
       0.3269619113677231, 0.017848737301709734`}, {0.3391937911645542, 
       0.01784852684472633}, {0.35188257831360037`, 0.01787422691239134}, {
       0.3647998191387634, 0.01791288224238058}, {0.3742978329731726, 
       0.017977854742802512`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.37638480919015377`, 0.017992130997343977`}, {
       0.3786941176639381, 0.018007928146980014`}, {0.39708551493364136`, 
       0.018159193044862496`}, {0.41639771365881834`, 
       0.018368324236164198`}, {0.4366307138394691, 0.01863532172088512}, {
       0.4577845154755938, 0.018960185499025263`}, {0.4598594420865214, 
       0.01899574039988816}}]}, 
     {Arrowheads[{{0.020000000000000014`, 1.}}], 
      ArrowBox[{{0.46194616079808437`, 0.01903149736426832}, {
       0.46872672731594894`, 0.019147685748506733`}, {0.4799391604731529, 
       0.01935638957210139}, {0.49142181494720555`, 0.01958629696980923}, {
       0.503174690738107, 0.019837407941630258`}, {0.5151977878458573, 
       0.020109722487564475`}, {0.5274911062704565, 0.02040324060761188}, {
       0.5400546460119043, 0.02071796230177247}, {0.5454068797903875, 
       0.020858057676755207`}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.5474931902542498, 0.0209126671087909}, {0.5528884070702009,
        0.021053887570046247`}, {0.5646970765148889, 0.021379577672870652`}, {
       0.5767561191176801, 0.021732284813619444`}, {0.5890655348785747, 
       0.02211200899229263}, {0.6016253237975727, 0.0225187502088902}, {
       0.6144354858746739, 0.022952508463412166`}, {0.6274960211098786, 
       0.023413283755858518`}, {0.6309324831132314, 0.023539216544163837`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.6330181082008377, 0.023615646483556605`}, {
       0.6408069295031864, 0.02390107608622926}, {0.6543682110545976, 
       0.024415885454524392`}, {0.6681906163859798, 0.02496688871993138}, {
       0.6822848961192003, 0.025563262741637702`}, {0.6966510502542594, 
       0.026205007519643355`}, {0.7112890787911569, 0.026892123053948332`}, {
       0.7164238872441063, 0.027144383367923484`}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.7185083983101519, 0.0272467901900715}, {0.7261989817298928,
        0.027624609344552638`}, {0.7413807590704673, 0.02840246639145628}, {
       0.7568344108128802, 0.029225694194659247`}, {0.7725599369571315, 
       0.03009429275416154}, {0.7885569357953194, 0.031026781938585095`}, {
       0.8018613089277731, 0.03185678845770957}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.8039442844270921, 0.03198673695106579}, {
       0.8048250056195417, 0.03204168161655184}, {0.8213641464297985, 
       0.03313899178806177}, {0.8381743582260898, 0.03431871245311488}, {
       0.8552556410084156, 0.03558084361171118}, {0.8726079947767758, 
       0.036925385263850675`}, {0.8871995365590074, 0.03810684869364071}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.8892797538040779, 0.03827528192967216}, {
       0.8902314195311706, 0.03835233740953335}, {0.9081259152715997, 
       0.03986170004875922}, {0.9198184440381043, 0.04088579933283123}, {
       0.9314025759980555, 0.041863473764422475`}, {0.9432576999743901, 
       0.042957210327215625`}, {0.9551128239507247, 0.04405094689000877}, {
       0.9711742741201357, 0.04603663169166552}, {0.9723760299675361, 
       0.0461852053444998}}]}, 
     {Arrowheads[{{0.006168410316035686, 1.}}], 
      ArrowBox[{{0.9744472859883329, 0.04644127572154888}, {
       0.9872357242895466, 0.048022316493322274`}, {1., 
       0.0496003700323903}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{1., 0.9105154744540197}, {0.9917089242449686, 
       0.9192541852412615}, {0.9816436267098302, 0.9298629080108896}, {
       0.9715783291746917, 0.9404716307805177}, {0.9615130316395532, 
       0.9510803535501458}, {0.9458104956274584, 0.9658189089947338}, {
       0.941415495306826, 0.9699440997190046}}]}, 
     {Arrowheads[{{0.01002155752870169, 1.}}], 
      ArrowBox[{{0.9398937758627763, 0.9713724006240277}, {0.9301079596153636,
        0.9805574644393216}, {0.9144054236032689, 0.9952960198839095}, {
       0.909393777960601, 1.}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.8384086776768955, 0.14993744239381046`}, {
       0.8571222325378518, 0.1598873007215805}, {0.8751827439077362, 
       0.17084743905331287`}, {0.8922986496971423, 0.1829805965601176}, {
       0.9077753961612346, 0.1959315257174224}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.9092890418317403, 0.19736551209129619`}, {
       0.9229782488137369, 0.2111559830666709}, {0.936077024330715, 
       0.22743577609817298`}, {0.9472390641683002, 0.24545143948427178`}, {
       0.9562672945344152, 0.26522436704973706`}, {0.956340068232019, 
       0.26543702484291387`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.9570157982842108, 0.2674116292180366}, {0.9612367982878501,
        0.2797461480803316}, {0.9649971165621162, 0.2951916958122373}, {
       0.9674655227041693, 0.31157018722902174`}, {0.9685592900609655, 
       0.3288907993142526}, {0.9681928518319477, 0.3471738411380166}, {
       0.9679616754376076, 0.34950466745852643`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.9677556904490315, 0.35158150248475506`}, {
       0.9662829133345692, 0.3664307161011853}, {0.9647243444614859, 
       0.37642303428496665`}, {0.9627501560928021, 0.38665724268350354`}, {
       0.9603504334190142, 0.3971328186067639}, {0.9575152616306186, 
       0.4078492393647159}, {0.9516074283807056, 0.4265176486860293}, {
       0.9492638270107627, 0.4326981909630762}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.9485238596264897, 0.43464963192090733`}, {
       0.9442143615345144, 0.44601463430224464`}, {0.9399868378083504, 
       0.45603864495084484`}, {0.9354191724377596, 0.46622756174905583`}, {
       0.9305217543409564, 0.4765673053888393}, {0.9253049724361553, 
       0.48704379656215685`}, {0.9197792156415704, 0.49764295596097036`}, {
       0.9139548728754161, 0.5083507042772415}, {0.9129725464975513, 
       0.510086699986756}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.9119447294765917, 0.511903088082157}, {0.9078423330559067, 
       0.519152962202932}, {0.9014519851012563, 0.5300356504300036}, {
       0.8947942179296795, 0.5409846896504179}, {0.8878794204593905, 
       0.5519860005561369}, {0.8807179816086035, 0.5630255038391221}, {
       0.8733202902955329, 0.5740891201913353}, {0.867483338324882, 
       0.5825202971089788}}]}, 
     {Arrowheads[{{0.019999999999999987`, 1.}}], 
      ArrowBox[{{0.8662953851355052, 0.5842362343926631}, {0.8633324849118854,
        0.5885159913788901}, {0.8529728788554318, 0.602912437958043}, {
       0.8422666232109932, 0.6172504360782455}, {0.8312388690633904, 
       0.6315019618889498}, {0.8199147674974443, 0.6456389915396079}, {
       0.8157600645850449, 0.650653354297967}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.8144285157356664, 0.6522604172100546}, {0.8083194695979758,
        0.6596335011796716}, {0.796478126449806, 0.6734574669585927}, {
       0.7822696632330378, 0.6894742336059266}, {0.7692026562801885, 
       0.7037744739702153}, {0.7589688283482139, 0.7146340091245915}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.75753748458647, 0.7161528667800041}, {0.7559399062482796, 
       0.7178481227722653}, {0.7424814131373109, 0.7316951800120767}, {
       0.7288271769472826, 0.7453156456896494}, {0.7149771976781948, 
       0.7587095198049834}, {0.7009314753300473, 0.7718768023580788}, {
       0.6979444261066611, 0.7745910231081762}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.696399823611934, 0.7759945460595281}, {0.6866900099028401, 
       0.7848174933489355}, {0.6722528013965733, 0.7975315927775534}, {
       0.6577313744307001, 0.8099218909044877}, {0.6432372536246735, 
       0.8218911779902934}, {0.6328918043005455, 0.8301495339258065}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.6312607278431517, 0.8314515566336824}, {0.6287704389784937,
        0.8334394540349703}, {0.6143309304921607, 0.8445667190385187}, {
       0.5999187281656744, 0.8552729730009383}, {0.5855338319990347, 
       0.8655582159222293}, {0.5711762419922419, 0.8754224478023915}, {
       0.5636544527250356, 0.8803790779650271}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.5619117768768906, 0.8815274483016264}, {0.5568459581452958,
        0.8848656686414251}, {0.5393761680467392, 0.8958392890848905}, {
       0.5222226328270965, 0.9060238590441602}, {0.5053853524863677, 
       0.915419378519234}, {0.4898177872679451, 0.9235291515854099}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.4879528939843205, 0.9244655361487059}, {0.4726595564416526,
        0.9318432660167948}, {0.45677104073766606`, 0.9388716340392815}, {
       0.44119877991259354`, 0.9451109515775725}, {0.425942773966435, 
       0.9505612186316678}, {0.41500416424249753`, 0.9540463326917257}, {
       0.4105964606462608, 0.9555925373914103}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.40862709388812646`, 0.9562833833320107}, {
       0.40384164213251605`, 0.9579621005672069}, {0.3932389009876446, 
       0.9608012339041301}, {0.38263615984277305`, 0.9636403672410532}, {
       0.3697289832990706, 0.9649378816341263}, {0.35682180675536823`, 
       0.9662353960271994}, {0.3450040264894853, 0.9658721313715678}, {
       0.3327504877124746, 0.966173178335418}, {0.32632110048131535`, 
       0.9659891015446479}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.32423493028505934`, 0.9659293733775738}, {
       0.3209271326399068, 0.9658346693640893}, {0.3095283864650968, 
       0.9648813601418849}, {0.2985542491880447, 0.9633132506688044}, {
       0.28800472080875045`, 0.9611303409448481}, {0.2681158924743374, 
       0.9551334819116706}, {0.2497983031927595, 0.9471041442097151}, {
       0.24453812979664866`, 0.9440127146231577}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.24273883456577347`, 0.9429552600313011}, {
       0.23297954512454885`, 0.9372196779790658}, {0.21752928415866335`, 
       0.9257993134718743}, {0.20842300043555878`, 0.9176988934339922}, {
       0.1998332145067147, 0.9090336296012732}, {0.19173226042978492`, 
       0.8998643865464434}, {0.18409247226242326`, 0.8902520288422293}, {
       0.1817265545807529, 0.8869706697550828}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.18050596171798775`, 0.8852777945071524}, {
       0.17688618406228354`, 0.8802574210613572}, {0.17008572988701964`, 
       0.8699414277765537}, {0.16366344379428532`, 0.859364913560545}, {
       0.15759165984173443`, 0.8485887429860577}, {0.15186022581115133`, 
       0.8376158392934375}, {0.1464643783225143, 0.8264312976207595}, {
       0.14138453469076825`, 0.8150692403873436}, {0.14025218504943976`, 
       0.8123456271764148}}]}, 
     {Arrowheads[{{0.0017784999416905326`, 1.}}], 
      ArrowBox[{{0.13945098405931095`, 0.8104185178087074}, {
       0.13660111223085797`, 0.8035637900125099}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.509442872901589, 0.38491710305359467`}, {
       0.5033399260721817, 0.39896107112274243`}, {0.4959586873816792, 
       0.41277807235953967`}, {0.4872991568300816, 0.42636810676398607`}, {
       0.47736133441738904`, 0.4397311743360818}, {0.4664033759789125, 
       0.45255054222341135`}, {0.46439387949241306`, 0.454601017002267}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.46293309944031436`, 0.4560915857464312}, {
       0.4546834373499632, 0.4645094775735596}, {0.4422015185305412, 
       0.4756079803865265}, {0.4289576195206465, 0.485846050662312}, {
       0.4121038092576162, 0.49690627782736596`}, {0.3961190565875751, 
       0.5053834813617268}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.3942333643891408, 0.5062715145193073}, {0.3780513388435256,
        0.5128432092286788}, {0.36085267869246507`, 0.5177199134649377}, {
       0.34397999594075457`, 0.5205063665586046}, {0.3278742179504209, 
       0.5211734916766858}, {0.3130226703624157, 0.519767426216483}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.31098374860473843`, 0.5193409988546704}, {
       0.2979633762538832, 0.5161497579860908}, {0.28430648648242224`, 
       0.510786833729681}, {0.27171284934182366`, 0.5039604506022182}, {
       0.2601824648320876, 0.49567060860370227`}, {0.24971533295321383`, 
       0.4859173077341333}, {0.24144480097173074`, 0.47645097558930716`}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.24009058761809773`, 0.47486408584071965`}, {
       0.231792022888568, 0.463628531018226}, {0.22429114365292455`, 
       0.4514951055809852}, {0.21776411494840076`, 0.4387023220908863}, {
       0.2100825312085408, 0.4203761472775862}, {0.20392925207522772`, 
       0.402095290607931}, {0.20350468750829234`, 0.4004213000870487}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.20299161206458935`, 0.3983983252649716}, {
       0.19930427754846142`, 0.38385975208192047`}, {0.19620760762824196`, 
       0.3656695316995549}, {0.19446648128036687`, 0.3479143786963138}, {
       0.19390813747063357`, 0.3309840423076766}, {0.19449897524915177`, 
       0.31574515802286873`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.19467583404605504`, 0.31366722612186426`}, {
       0.1963397974655925, 0.2995978193742142}, {0.19945124535333125`, 
       0.2844969119912636}, {0.20372677228830358`, 0.2705523094225395}, {
       0.20916637827050943`, 0.2577640116680419}, {0.2157700632999488, 
       0.24613201872777085`}, {0.22293960520245204`, 0.23646294242218485`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.22428739200507106`, 0.23487490944814138`}, {
       0.23246047603879474`, 0.2263486673603953}, {0.24254490513276797`, 
       0.21820023895091256`}, {0.253788816043108, 0.2112139753908999}, {
       0.2661839862929088, 0.20539477554265276`}, {0.2797221934052644, 
       0.2007475382684667}, {0.2944034373801746, 0.1972722635683417}, {
       0.2967524365842934, 0.19693035366377584`}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.29881769854044654`, 0.19662974329443483`}, {
       0.31022771821763956`, 0.1949689514422778}, {0.32621781535399275`, 
       0.19392045450974138`}, {0.34308884468409157`, 0.19403236647511915`}, {
       0.3607164917998269, 0.19537199771677355`}, {0.37897644229308936`, 
       0.19800665861306707`}, {0.3818381532662171, 0.1986232757056521}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.3838783544432056, 0.19906288086838742`}, {
       0.397653412719373, 0.20203101303274645`}, {0.4165321196341716, 
       0.20753972484455835`}, {0.43538219813310275`, 0.2146297292722599}, {
       0.4537733908259373, 0.22346989780599844`}, {0.4616090951574234, 
       0.22825055720678405`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.4633907070380878, 0.22933754048557176`}, {
       0.46922755120664833`, 0.23289867076370432`}, {0.48361899587370705`, 
       0.24388917473206817`}, {0.49654818460502814`, 0.25650291610464376`}, {
       0.5076155771785262, 0.2708014012749849}, {0.5131678362591524, 
       0.2801070854612231}, {0.5177539635382397, 0.289994237651831}, {
       0.5179683336174239, 0.29061417183519284`}}]}, 
     {Arrowheads[{{0.019651215548244366`, 1.}}], 
      ArrowBox[{{0.5186503892834843, 0.29258660018879246`}, {
       0.521373959015788, 0.30046285784680876`}, {0.5240278226917974, 
       0.3115129460461563}, {0.525590431257517, 0.3230682452424992}, {
       0.5259366614041959, 0.3350524984284631}, {0.5250665131318343, 
       0.34746570560404777`}, {0.5229799864404319, 0.36030786676925347`}, {
       0.5216573759028308, 0.36671627784151845`}, {0.5200245960537507, 
       0.37319320208556744`}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{1., 0.7354170803765526}, {0.998058552799605, 
       0.7378005495018296}, {0.9865710153096146, 0.7516069684911033}, {
       0.9748241935379448, 0.765435143746216}, {0.9628180874845957, 
       0.779285075267168}, {0.9505526971495675, 0.7931567630539589}, {
       0.9455599958196923, 0.7986948042551751}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.9441625412505061, 0.8002448991776716}, {0.9380802957314439,
        0.8069914926658348}, {0.9254531564288091, 0.8207305496620414}, {
       0.9126712792416631, 0.8343739340425785}, {0.8997346641700058, 
       0.8479216458074464}, {0.8869649581511546, 0.8610431761690891}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.8854984450859494, 0.8625280822667505}, {0.8733972203731578,
        0.8747300514901741}, {0.8599963916479669, 0.887990745408034}, {
       0.8464408250382648, 0.9011557667102246}, {0.8376574753194456, 
       0.9095551785844112}, {0.8288400198087893, 0.9178840999344613}, {
       0.8257219389933244, 0.9207932426093104}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.8241959481121145, 0.9222169790217665}, {0.8199884585062959,
        0.9261425307603751}, {0.8113756377466621, 0.9348943952552439}, {
       0.802472917756413, 0.9430470902949529}, {0.793570197766164, 
       0.9511997853346621}, {0.784667477775915, 0.9593524803743712}, {
       0.7757647577856659, 0.9675051754140803}, {0.7645091438502752, 
       0.9766659208109617}, {0.7624549385901149, 0.9783378021929354}}]}, 
     {Arrowheads[{{0.007721509898849931, 1.}}], 
      ArrowBox[{{0.760836264880393, 0.9796552121379198}, {0.7532535299148846, 
       0.9858266662078431}, {0.7419979159794938, 0.9949874116047244}, {
       0.7358390547351404, 1.}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.019999999999999987`, 1.}}], 
      ArrowBox[{{1., 0.5569998219326342}, {0.9953444992610668, 
       0.5647193064230431}, {0.9871932489785259, 0.5788338991276933}, {
       0.9778682399521417, 0.5933981095972528}, {0.9685432309257574, 
       0.6079623200668123}, {0.9613196329732935, 0.6175832292838368}, {
       0.9543854706300146, 0.6268186472624964}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.9531323769196269, 0.6284876079255066}, {0.9468724370683654,
        0.6368250477178855}, {0.9396488391159014, 0.6464459569349099}, {
       0.9311059387156385, 0.6561674984917668}, {0.9236495226841511, 
       0.6658061663569969}, {0.9160378945999816, 0.6754566733210308}, {
       0.9082710544631298, 0.6851190193838685}, {0.9011706442044767, 
       0.6937913935990132}}]}, 
     {Arrowheads[{{0.020000000000000018`, 1.}}], 
      ArrowBox[{{0.899843002908243, 0.6954016612481205}, {0.8923313460023654, 
       0.704413363268796}, {0.884173379671199, 0.7140288947065957}, {
       0.8758900052728432, 0.7236233324746195}, {0.8674812228072981, 
       0.7331966765728674}, {0.8589470322745635, 0.7427489270013392}, {
       0.8502874336746395, 0.7522800837600351}, {0.8448352913652296, 
       0.7581822098820743}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.8434191392909072, 0.7597152417943582}, {0.8415024270075262,
        0.7617901468489551}, {0.8326161053634585, 0.7712531736307947}, {
       0.8236525618326715, 0.7806432214682498}, {0.8146117964151655, 
       0.7899602903613202}, {0.8054938091109399, 0.7992043803100062}, {
       0.7962985999199952, 0.8083754913143074}, {0.7870261688423313, 
       0.8174736233742241}, {0.785048090560366, 0.8193830481878781}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.7835465133341117, 0.8208325099415245}, {0.7776765158779482,
        0.8264987764897562}, {0.7682496410268457, 0.8354509506609037}, {
       0.7583996089682865, 0.8446556534451901}, {0.7490340932554281, 
       0.8532588101540662}, {0.7396043688967561, 0.8617767431201557}, {
       0.7301169425127229, 0.8702033299442574}, {0.7220369748006285, 
       0.8772587524450398}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.7204640882598587, 0.8786304959997225}, {0.7109950101503844,
        0.886757975569693}, {0.7013735174129846, 0.8948737895726249}, {
       0.6917203491320347, 0.9028737678367647}, {0.6792134558849796, 
       0.9130329726014641}, {0.6666897953407781, 0.9229786810831174}, {
       0.6558093182940388, 0.9314218200930163}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.6541604558693827, 0.9327012437110695}, {0.6416533449705443,
        0.9421782665424127}, {0.6291711414493166, 0.9514064721926176}, {
       0.6167333432405515, 0.960369838904903}, {0.6043552434966513, 
       0.9690555310155503}, {0.5920521353700181, 0.9774507128608411}, {
       0.5862843988057519, 0.9812722352493876}}]}, 
     {Arrowheads[{{0.007832996488104076, 1.}}], 
      ArrowBox[{{0.5845446055186244, 0.9824249680283762}, {0.5798393120130545,
        0.9855425487770569}, {0.5677320665781626, 0.9933182031004794}, {
       0.5569768064092713, 1.}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.629964432620705, 0.07224084419331171}, {0.6431070552479029,
        0.0739125856625167}, {0.6564288353879638, 0.07570542090693744}, {
       0.6699100260583402, 0.07763592770734049}, {0.683530880276484, 
       0.07972068384449238}, {0.6972716510598476, 0.08197626709915967}, {
       0.712498076214072, 0.08469788735348466}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.7145525401143419, 0.08506510884547108}, {
       0.7157177654453489, 0.08527338497263817}, {0.734302082226273, 
       0.08894360056741885}, {0.7529743939715681, 0.09302500895067574}, {
       0.7722200391814025, 0.0971493578063933}, {0.7913277459158742, 
       0.10185632725287018`}, {0.7960360019736228, 0.10313707999661999`}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.7980498479575511, 0.10368489191206604`}, {
       0.810423032752613, 0.10705067962217131`}, {0.8295058996916189, 
       0.1127324149142967}, {0.8485763467328918, 0.11890153312924633`}, {
       0.8674660885668941, 0.1256703304778533}, {0.877331474382421, 
       0.1296507899292039}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.8792668990826261, 0.13043168990456866`}, {
       0.8860068398840877, 0.1331511031709507}, {0.9041986006844729, 
       0.1413438512085385}, {0.9220413709680495, 0.15024857459061675`}, {
       0.9375143319670066, 0.15835862612434082`}, {0.9525496323133786, 
       0.16713106716312454`}, {0.9536890726046402, 0.16801705461440047`}}]}, 
     {Arrowheads[{{0.014580745983237308`, 1.}}], 
      ArrowBox[{{0.955336641335478, 0.16929814431416945`}, {0.96135011443152, 
       0.17397400292873524`}, {0.9701505965496612, 0.18081693869434598`}, {
       0.9780194000980196, 0.18861442744178156`}, {0.986260875074291, 
       0.1960300949964872}, {0.9940893872921792, 0.20384979231204373`}, {1., 
       0.2104581755246327}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.00521279434830267, 0.13774670202225162`}, {
       0.005794774725042567, 0.11646531384102578`}, {0.0065056769557622195`, 
       0.09848112733603025}, {0.007368195970945003, 0.08332070192180997}, {
       0.008405026701074294, 0.07051059701290976}, {0.009637780108308831, 
       0.05977966721646827}, {0.010493971194851638`, 0.0544935749617316}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.01082765899632056, 0.05243339875741324}, {
       0.011106328690040026`, 0.05071290232530438}, {0.01679666510341154, 
       0.0321678056021691}, {0.026046147693640463`, 0.020592171873915197`}, {
       0.026818691485181956`, 0.019992080323120293`}, {0.02761567576380512, 
       0.019410941117084236`}, {0.02793955589687334, 0.01919285981053002}, {
       0.02837721457160853, 0.01890595206262967}, {0.028821674803035775`, 
       0.018623449004665994`}, {0.031158274522575875`, 0.01727815998935878}, {
       0.03369504348976938, 0.01603970754780979}, {0.0364490448287661, 
       0.014899760084102771`}, {0.04827402635193764, 0.011554282817088521`}, {
       0.0639270715761443, 0.009072362001154704}, {0.07137935662978365, 
       0.008429047054452996}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.0734586486929003, 0.00824955316054888}, {
       0.08488355369565387, 0.007263303694778756}, {0.09790384853899768, 
       0.006539587754604019}, {0.1126188459047342, 0.005936413956438107}, {
       0.12420987703767725`, 0.005574253723695429}, {0.13716696776325407`, 
       0.005248838570970824}, {0.15149011808146473`, 0.004960168498264292}, {
       0.1568513639766823, 0.0048740818284683735`}}]}, 
     {Arrowheads[{{0.010785625003150218`, 1.}}], 
      ArrowBox[{{0.1589381200213569, 0.004840574341202627}, {
       0.16717932799230917`, 0.004708243505575834}, {0.1845592562672324, 
       0.004491033766003687}, {0.2039545616776797, 
       0.004306509452646089}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.525343560199503, 0.1544005234616233}, {0.5455221697170028, 
       0.1611662627450191}, {0.5655242321686124, 0.1689832725290955}, {
       0.5754389964794905, 0.17331240313911064`}, {0.5853071088735138, 
       0.1779320489153132}, {0.595073833547524, 0.18286139635949755`}, {
       0.6021519624238802, 0.18673404373646318`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.6039828623977641, 0.18773578163996935`}, {
       0.6046844346983631, 0.1881196319734582}, {0.6140841765228728, 
       0.19372594225898948`}, {0.623218323217895, 0.19969951371788583`}, {
       0.6404708880068443, 0.2128251861629512}, {0.6529710449204543, 
       0.22449361899611903`}, {0.6644047208796612, 0.23726112251600992`}, {
       0.6672740604999176, 0.24124044956003513`}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.6684947022748894, 0.24293328954032933`}, {
       0.6744683228063658, 0.2512177705978642}, {0.682993187879402, 
       0.2664136042834819}, {0.6897729369173713, 0.28288447380503157`}, {
       0.694601190738875, 0.30066622939468185`}, {0.6971364327172488, 
       0.31987064929216447`}, {0.6971384827438202, 0.32010606070728953`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.6971566564359489, 0.32219300662383915`}, {
       0.6973149358547105, 0.3403687622334855}, {0.6955159813571953, 
       0.3593667652306495}, {0.6916526065187953, 0.379294790963026}, {
       0.6889576311867273, 0.3895584425563033}, {0.6857595944273943, 
       0.39999565607504495`}, {0.684311323061546, 0.4041449292146497}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.6836235550557817, 0.40611537300018014`}, {
       0.6820628441267818, 0.4105867835998047}, {0.6778717281708752, 
       0.42131217721113634`}, {0.6731344898434048, 0.4321906238344754}, {
       0.6678197741016485, 0.4432269340880275}, {0.6619625313419124, 
       0.4543804955915019}, {0.6555977119605029, 0.46561069596460786`}, {
       0.6487602663537264, 0.47687692282705435`}, {0.6463563125564435, 
       0.48059816168414154`}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.6452238310894651, 0.48235120454403946`}, {
       0.6414851449178893, 0.4881385637985507}, {0.6338072980492978, 
       0.499355006498806}, {0.6257616761442584, 0.5104856385475294}, {
       0.6181443069322318, 0.520504719082423}, {0.6102919069693704, 
       0.5303545464117985}, {0.6022264936304687, 0.540014196252671}, {
       0.5946610023599259, 0.5486720649451353}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.5932703969744798, 0.5502281314562234}, {0.5855446963237223,
        0.5586792663369679}, {0.5769723471054665, 0.5676428380144227}, {
       0.5682750540103482, 0.5763325350714356}, {0.5575960184307024, 
       0.5865129720397226}, {0.5480066641503544, 0.5952652114429073}, {
       0.5383364007427328, 0.6037017276596803}, {0.5331393504012849, 
       0.6080298400010667}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.5315356341202181, 0.6093654176407156}, {0.5285852282078376,
        0.6118225206900417}, {0.5187531465456687, 0.6196275905339914}, {
       0.5088401557562263, 0.6271169371915296}, {0.4988462558395103, 
       0.634290560662656}, {0.4887714467955207, 0.6411484609473709}, {
       0.47861572862425744`, 0.6476906380456741}, {0.4684600740589878, 
       0.6538686811073245}, {0.46307301615899843`, 0.6569515842797261}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.46126163537048404`, 0.6579882004964089}, {
       0.458385455832979, 0.6596341792820812}, {0.448391873946231, 
       0.6649871325699441}, {0.43847932839874376`, 0.6699275409709132}, {
       0.4188973463215517, 0.6785707231121699}, {0.3996395096014028, 
       0.6855637257058517}, {0.3868261959979139, 0.6897024132738379}, {
       0.3845109461632761, 0.6903222067261036}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.382494909463733, 0.6908619006836241}, {0.3742779346513273, 
       0.6930615886438473}, {0.35298440415874865`, 0.6953294443211274}, {
       0.3329053799496584, 0.6952721052511407}, {0.31344642257232735`, 
       0.6941323556767802}, {0.299681696216214, 0.6916356791341307}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.2976281776877914, 0.6912632073967953}, {
       0.29522759885851463`, 0.6908277850936723}, {0.2782515532925883, 
       0.6855359078438572}, {0.26252093035891666`, 0.6784342382693758}, {
       0.24800460051236056`, 0.6696842751084953}, {0.23464653057166968`, 
       0.6595767160900972}, {0.22573080109436144`, 0.6511039792954931}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.22421794585793242`, 0.6496662927596663}, {
       0.2211024071010977, 0.6467055546700649}, {0.20885895324175902`, 
       0.6324801165143625}, {0.19783093874693092`, 0.6172160231098597}, {
       0.18793313336989076`, 0.6012288959434258}, {0.17908148971208773`, 
       0.5846865510396989}, {0.17739113009033647`, 0.5810408845832908}}]}, 
     {Arrowheads[{{0.003030298747377871, 1.}}], 
      ArrowBox[{{0.17651323076145836`, 0.5791474838570725}, {
       0.17119263628821205`, 0.5676723441591849}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.17636890879546754`, 1.}, {0.16807128235308266`, 
       0.9892933585573604}, {0.15795552323784282`, 0.9742858879899076}, {
       0.1513202450873451, 0.9609620976539174}, {0.14468496693684738`, 
       0.9476383073179273}, {0.1390589450218731, 0.9337950269409997}, {
       0.13617737018961085`, 0.9272786978531843}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.13533331467373233`, 0.9253699695257883}, {
       0.13302922061268946`, 0.9201595425804471}, {0.12737303433632213`, 
       0.9063569219896946}, {0.12206022183137806`, 0.8924278249549178}, {
       0.11709078309785728`, 0.8783722514761163}, {0.11246471813575976`, 
       0.8641902015532904}, {0.10813972256027737`, 0.8499436607294236}, {
       0.1072492180736503, 0.8468231196471478}}]}, 
     {Arrowheads[{{0.01629675047947652, 1.}}], 
      ArrowBox[{{0.10667650960075103`, 0.8448162119395644}, {
       0.10407349198660204`, 0.8356946145474997}, {0.10026602641473371`, 
       0.8214430630075186}, {0.09671732584467242, 0.8071890061094802}, {
       0.09346662120041127, 0.7928811214384706}, {0.0902916039126559, 
       0.7788102360123365}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.667510318174931, 0.16848922556912496`}, {
       0.6807786901901159, 0.17594360842129392`}, {0.6934478592991719, 
       0.18411371048008465`}, {0.7064864199495918, 0.19256212853259688`}, {
       0.7184748802786705, 0.20192988452877064`}, {0.7296637388504145, 
       0.21210385694802827`}, {0.7346900847134996, 0.21741609705812454`}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.7361244768516932, 0.21893207619240604`}, {
       0.7400529956648239, 0.22308404579036978`}, {0.7496426507218987, 
       0.23487045105579518`}, {0.7581906272823544, 0.24754539752558793`}, {
       0.7654548486069065, 0.26119120998103157`}, {0.7714353146955547, 
       0.2758078884221261}, {0.776060143545827, 0.29115686932172496`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.7765815908579446, 0.29317746743627504`}, {
       0.7790711501810877, 0.3030458463481904}, {0.7812019580909865, 
       0.31524242616665876`}, {0.7808647489593837, 0.3363900101108709}, {
       0.7791647440428112, 0.3477570402105305}, {0.7780772992665472, 
       0.35880677505916875`}, {0.7763684156201579, 0.37016086300688045`}, {
       0.7752472087156175, 0.37574268876393613`}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.7748362029732473, 0.3777888431621738}, {0.7740292143738264,
        0.38180636190171763`}, {0.7710596955275527, 0.3937432717436803}, {
       0.7674598590813367, 0.40597159253276843`}, {0.7632220141438111, 
       0.4184573600761614}, {0.7583384698236084, 0.4311666101810385}, {
       0.7528092261207288, 0.44409934284739977`}, {0.7470862117071548, 
       0.45629268752018715`}}]}, 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.7461702015330541, 0.4581676530457962}, {0.73979182873894, 
       0.4707035583108482}, {0.7324054635906883, 0.4840562963586595}, {
       0.7243908485221577, 0.49757787501093625`}, {0.7157567082645477, 
       0.5112409732891691}, {0.7069258828702656, 0.5244301209815588}, {
       0.7032335696653969, 0.5296609156465238}}]}, 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.7020300200951716, 0.5313659499493164}, {0.6976057742736657,
        0.5376336526482943}, {0.6878171674858558, 0.5508141063012691}, {
       0.677580847517943, 0.5639340199523766}, {0.6669175993810351, 
       0.5769559316135102}, {0.6558482080862394, 0.5898423792965636}, {
       0.6498694708280917, 0.5964781251379361}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.6484724772549542, 0.5980286355372244}, {0.6443934586446636,
        0.60255590101343}, {0.632574136067415, 0.6150590347760032}, {
       0.6204404185217047, 0.6273189080588243}, {0.6080515282227759, 
       0.6393040604787879}, {0.5954418162537838, 0.6509791482613171}, {
       0.5890698403224609, 0.6566208655424808}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.587507270640185, 0.6580043573312967}, {0.5826456336978839, 
       0.6623088276318352}, {0.5696973316382313, 0.6732577548157653}, {
       0.5566312611579816, 0.6837905860385309}, {0.5434817733402899, 
       0.6938719775255552}, {0.5302832192683117, 0.7034665855022613}, {
       0.521749104214519, 0.709342069761842}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.5200300870839926, 0.7105255619023504}, {0.5170674681452884,
        0.7125652368811588}, {0.5038656255191034, 0.721166811093861}, {
       0.4907108969898748, 0.7292480431444467}, {0.477636488157721, 
       0.736785668036994}, {0.46467560462276, 0.7437564207755815}, {
       0.45186145198510996`, 0.7501370363642879}, {0.44770798319970484`, 
       0.7520329941940429}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.44580940857598467`, 0.7528996474925738}, {
       0.43922723584488926`, 0.7559042498071914}, {0.426806161802216, 
       0.7610347961083708}, {0.41460160766242454`, 0.7655519091633027}, {
       0.40260777344783927`, 0.7694931302186634}, {0.39084409808406273`, 
       0.7728566553053307}, {0.3793300204966976, 0.775640680454182}, {
       0.36808497961134645`, 0.7778434016960953}, {0.3664741165171337, 
       0.7780815215207461}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.3644095263873448, 0.7783867118509779}, {
       0.35712841435361214`, 0.7794630150619483}, {0.34647976364909716`, 
       0.7804977165826186}, {0.336158466423404, 0.7809457022889839}, {
       0.32450235052343634`, 0.7807772179518326}, {0.31323241156842696`, 
       0.7799266567912773}, {0.3023561390398608, 0.778415618139607}, {
       0.29188102241922265`, 0.7762657013291113}, {0.28189509518014216`, 
       0.7731610181607783}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.2799021691709092, 0.772541405811473}, {0.2721642148276708, 
       0.770135630560802}, {0.2541419046456509, 0.7617092391446652}, {
       0.23772577640140363`, 0.7512564703508752}, {0.22274281100966173`, 
       0.7391027809420975}, {0.21090579991417863`, 0.7272817620763954}}]}, 
     {Arrowheads[{{0.004713468348726072, 1.}}], 
      ArrowBox[{{0.20942905311982674`, 0.7258070104203326}, {
       0.20912586890204277`, 0.7255042358153839}, {0.1968078105101644, 
       0.7107168998677865}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.019999999999999993`, 1.}}], 
      ArrowBox[{{0.42287576700515395`, 0.16377064276399622`}, {
       0.44127027719345757`, 0.16784701879712718`}, {0.4599104249748138, 
       0.17284710652402677`}, {0.4785977184342593, 0.1788673245197346}, {
       0.4973194665224269, 0.18597638747908987`}, {0.502509190345648, 
       0.18828974091858283`}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.504415408518528, 0.1891394501741938}, {0.5159143374974726, 
       0.1942651732010921}, {0.5339608784057173, 0.2038633449170214}, {
       0.5510376362934821, 0.2149005658581579}, {0.5639111070788008, 
       0.22505303547286776`}, {0.5739304371338073, 0.23443027323031462`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.5754542043507188, 0.23585638928812852`}, {
       0.5758935262621113, 0.23626755710000488`}, {0.5866684067444824, 
       0.2486241207070251}, {0.5960599223598406, 0.26216716516473726`}, {
       0.603849390183653, 0.2769235430262445}, {0.6098181272913864, 
       0.29292010684464986`}, {0.6133006421989073, 0.30878641530734274`}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.6136710796553975, 0.31083652676034496`}, {
       0.6151694472276793, 0.3287774798547511}, {0.6149616554837106, 
       0.3420022136562226}, {0.6135744031033419, 0.35573265100422724`}, {
       0.6110087537455012, 0.36989756839651056`}, {0.6072657710691169, 
       0.3844257423308179}, {0.6043789664502381, 0.39300602488985215`}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.6037134518043574, 0.3949840956160414}, {0.6022552564830076,
        0.3993182053100681}, {0.5959600211960794, 0.41451818503304133`}, {
       0.5884906435673923, 0.4298677507912747}, {0.5799577019560063, 
       0.44520897187630554`}, {0.5703366631029205, 0.4605637397535637}, {
       0.5647696083356761, 0.4685207008146599}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.5635731845471501, 0.4702307428199738}, {0.5598616632097623,
        0.47553560005485973`}, {0.5486363121034438, 0.49000780225542456`}, {
       0.5356590481238117, 0.5051089347613591}, {0.5223976771521255, 
       0.5191850318051016}, {0.5085931746211039, 0.5325279696985747}, {
       0.5084112893367326, 0.5326878241511014}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.5068436572022121, 0.5340655770434981}, {
       0.49424554053074704`, 0.5451377484417785}, {0.479354774881055, 
       0.5570143680347129}, {0.46415661632731686`, 0.567977670020286}, {
       0.4488868035248219, 0.5778474959414057}, {0.43956426855576436`, 
       0.58318061227025}}]}, 
     {Arrowheads[{{0.019999999999999997`, 1.}}], 
      ArrowBox[{{0.4377527219290858, 0.5842169386479218}, {0.4335453364735702,
        0.5866238457980721}, {0.4181322151735617, 0.5943067195902851}, {
       0.4080439159445137, 0.5989666790197703}, {0.3980231660702663, 
       0.6031045300327239}, {0.37812054690112756`, 0.6083057675453455}, {
       0.3594612313472633, 0.6112292482345283}}]}, 
     {Arrowheads[{{0.020000000000000004`, 1.}}], 
      ArrowBox[{{0.3573883241575616, 0.611467426015731}, {
       0.34037193173556984`, 0.6132297570198603}, {0.32263445702605564`, 
       0.6130377854829302}, {0.3058734945331738, 0.6108444868186736}, {
       0.29015609017494487`, 0.606771706919114}, {0.27575292693253833`, 
       0.6010590101837128}}]}, 
     {Arrowheads[{{0.020000000000000007`, 1.}}], 
      ArrowBox[{{0.27390139902565114`, 0.6000994762690703}, {
       0.26190166346318955`, 0.5936419978953913}, {0.24891093826814978`, 
       0.5844898372292979}, {0.2369911526073188, 0.574012230513952}, {
       0.2261261118055835, 0.5624442807135239}, {0.21629962118783086`, 
       0.5500210907921843}, {0.21273142722289518`, 0.5447285202214264}}]}, 
     {Arrowheads[{{0.00935425576919208, 1.}}], 
      ArrowBox[{{0.21156475742950975`, 0.542998041924859}, {
       0.20745162034364537`, 0.5368971773115389}, {0.1994969827281529, 
       0.5231810074602995}, {0.19238191446455263`, 0.5090386101432958}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.01999999999999999, 1.}}], 
      ArrowBox[{{0.8084316607753865, 0.12012732586227841`}, {
       0.8248715381840959, 0.12601365680652915`}, {0.841001356297159, 
       0.13248657410575565`}, {0.8575683130205227, 0.1390858704531071}, {
       0.8734773769402994, 0.14648598759138207`}, {0.8852260295442794, 
       0.15263394949604087`}}]}, 
     {Arrowheads[{{0.02000000000000001, 1.}}], 
      ArrowBox[{{0.8870751762465094, 0.15360159096648357`}, {
       0.8889217888942338, 0.15456790638949847`}, {0.9039015488823259, 
       0.16333162684745622`}, {0.9184166569045759, 0.17277714896525542`}, {
       0.9322495360186457, 0.18302529600553183`}, {0.9451826092821974, 
       0.19419689123092126`}, {0.9539413195595171, 0.20300056669062638`}}]}, 
     {Arrowheads[{{0.02, 1.}}], 
      ArrowBox[{{0.9554132859184541, 0.20448008978265525`}, {
       0.9572158766952312, 0.2062919346414237}, {0.968349338257747, 
       0.21931042623703917`}, {0.9781188695294707, 0.2316373477420061}, {
       0.9869197607811189, 0.24485728799002504`}, {0.9945628658951065, 
       0.2642880643309528}, {0.9969395033906011, 0.2750819023668297}, {
       0.997008752830698, 0.2753247757052859}}]}, 
     {Arrowheads[{{0.00214057113984176, 1.}}], 
      ArrowBox[{{0.9975810105353828, 0.2773318119932283}, {0.9998941069106955,
        0.2854443604565414}, {1., 0.28593197867829356`}}]}}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.00009364269117428736, 1.}}], 
      ArrowBox[{{0.33402801071274435`, 0.33303253276675954`}, {
       0.33408661711334847`, 0.33341898339326187`}}]}}}},
  AspectRatio->1,
  Frame->True,
  Method->{"TransparentPolygonMesh" -> True},
  PlotRange->{{-0.021756261443547698`, 
   1.0217562614435476`}, {-0.021756261443547698`, 1.0217562614435476`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.4654001657823763`*^9, 3.465400243399126*^9}, {
  3.465400278798273*^9, 3.465400294134988*^9}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save a CelleratorML file", "Subsection",
 CellChangeTimes->{{3.465481716580373*^9, 3.4654817265300407`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "CelleratorML.m"}]], "Input",
 CellChangeTimes->{{3.465481872767378*^9, 3.4654818749605007`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["\<\"Cellzilla2D (2.1.\[Alpha].18 5 Sept 2009) loaded Sun 25 Oct \
2009 10:51:15 using xlr8r 0.74 (13 May 2009) and xSSA 1.1.\[Alpha].5 \
(23-Jul-2009)\"\>",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.465481875423856*^9}],

Cell[BoxData[
 StyleBox["\<\"CelleratorML 1.0.5 (19 June 2009) loaded 25 October 2009 at \
10:51 GMT-06:60 using Mathematica Version 7.0 for Linux x86 (64-bit) \
(February 18, 2009) Release 1\"\>",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.4654818754257298`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SaveModel", "[", 
  RowBox[{
  "\"\<Lotka-MassAction-Oscillations.xml\>\"", ",", " ", "net", ",", "  ", 
   RowBox[{"\"\<InitialConditions\>\"", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"X", "\[Rule]", " ", "1.1"}], ",", " ", 
      RowBox[{"Y", "\[Rule]", " ", ".9"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"\"\<Parameters\>\"", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k1", "\[Rule]", " ", "1"}], ",", " ", 
      RowBox[{"k2", "\[Rule]", " ", "1"}], ",", " ", 
      RowBox[{"k3", "\[Rule]", " ", "1"}]}], "}"}]}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"\"\<Model\>\"", "\[Rule]", " ", "\"\<Lotka-Oscillations\>\""}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.465481802330019*^9, 3.465481852695951*^9}, 
   3.465481890118232*^9, {3.465482359518511*^9, 3.4654823621479883`*^9}}],

Cell[BoxData["\<\"Lotka-MassAction-Oscillations.xml\"\>"], "Output",
 CellChangeTimes->{{3.4654818547720013`*^9, 3.4654819031031227`*^9}, 
   3.4654823624892807`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"model", ",", " ", "parms", ",", " ", "iv", ",", " ", "opts"}], 
    "}"}], "=", 
   RowBox[{
   "GetModel", "[", "\"\<Lotka-MassAction-Oscillations.xml\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"run", "[", 
   RowBox[{"model", ",", " ", 
    RowBox[{"initialConditions", "\[Rule]", " ", "iv"}], ",", " ", 
    RowBox[{"rates", "\[Rule]", " ", "parms"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"runPlot", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.465481904286428*^9, 3.465481945610227*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Model: \"\>", "\[InvisibleSpace]", "\<\"Model4\"\>"}],
  SequenceForm["Model: ", "Model4"],
  Editable->False]], "Print",
 CellChangeTimes->{3.465481946013722*^9, 3.465482367926765*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CelleratorML Version: \"\>", 
   "\[InvisibleSpace]", "\<\"1.0\"\>"}],
  SequenceForm["CelleratorML Version: ", "1.0"],
  Editable->False]], "Print",
 CellChangeTimes->{3.465481946013722*^9, 3.465482367929533*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"3", "\[InvisibleSpace]", "\<\" reactions\"\>"}],
  SequenceForm[3, " reactions"],
  Editable->False]], "Print",
 CellChangeTimes->{3.465481946013722*^9, 3.4654823679337387`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"3", "\[InvisibleSpace]", "\<\" parameters\"\>"}],
  SequenceForm[3, " parameters"],
  Editable->False]], "Print",
 CellChangeTimes->{3.465481946013722*^9, 3.465482367935154*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"2", "\[InvisibleSpace]", "\<\" initial values\"\>"}],
  SequenceForm[2, " initial values"],
  Editable->False]], "Print",
 CellChangeTimes->{3.465481946013722*^9, 3.4654823679365797`*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{
    {Hue[0.5], InsetBox["\<\"X\"\>", Scaled[{1.1, 0.6666666666666667}]]}, 
    {Hue[1.], 
     InsetBox["\<\"Y\"\>", Scaled[{1.1, 0.33333333333333337`}]]}}, {{}, {}, 
    {Hue[0.5], LineBox[CompressedData["
1:eJwUnHc81V8YxxFSpGyVvbL3Xs9jjyLRQCIZKRISmSVaGiRJKlQqJEkloxTK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      "]]}}, {{}, {}, 
    {Hue[1.], LineBox[CompressedData["
1:eJwUm3c81d8fxxGyUlmRvWf2XuftWtc1KwkpMiJUIpRSmkZS4StJpBRJshMl
qYxCkiQjowj3Xu692fN3fn95nMfn8znjfc79PF9PLmnfE3sCWJiYmLo2MzH9
/6fMzbVHORLvzPk6gzTa2yjoJYey5LGgXPR4dxhT928Kene6JF8p6AVqq+Wr
K16hoCbNk4HsQW/Ry/OCj5t2UVFLchdxLvALGu7+t0PzHhXRrvD8PV30FbkX
2WwcqKGi2PcvlBcefENLi51mhj1UlAHzJf9u/EBll7yayfzTqNX48itK4BBq
1pdVTc+YRs9M+c/rvRhGqa6pNlk104je7597qmgEdf7zFRDvn0bnd3KMMh78
RiVLQRxnpGfQnTtOgTM3/qJvBruScspn0Kfb/ScnAmdQp/y5p2onaCghM6M1
TYuGjl32LZ29SENqQchT5wUNmVcycz9Pp6HwzbfPhhfRkeqV+N4fr2ho3Vq3
nvbgH3LzbqGHs9BRnuCg0y2JWZR/tcJXVICOrMauDmlkz6KSJo60q/J0dP3K
D6YTd+aQlmmXUIItHQm/j7Gk3lhAK+hs7pN4OqpLle1O5l5EHMLcPPUZdHTI
t81fLXERaWkq9gQ/pqN8ZolrIVeW0G02S6ewd3Rk+7VJiJtlGV2IK0VvO+ho
6sGJgqILy8hYotriVj8dacG7lsmYFRTiuPXlk3901L012CNxcQV1hD3f8med
jk4P8U0pRa2i2pgutjROBhJ9URfT8m8V3RFJnXzBz0D15/25g06uIbcaWryB
OAMddtqSvXlmDdVv0elRUGAgVolqtYLQdXT2jlxHjDoDFVAPvbGZWkcqGyb9
mvoMRHqz2Wk8cAO9r3zxw8aMgbQ2fOeEaBvoehhd1NyKgZKlvDtkTZkgLfeT
6ikSA8W945ExjWOCG5GDpL/ODHTKtzbS9QMToHNT3BmuDBS0Kag1lIMZrCwd
WS+4M5BXvqD4VQdmKNVQtcs7wEAu1u/D7t9iBoGvu4tWDzKQ1XjYh6puZqi6
58Z+25uBDOMlhDuEWUCFMO95yIeB1JTaQsa9WOBzfXJ4AG5LtZ55u/6ABZZ8
vx8twPfzByvy7xhjgYTQPd7yhxiInfv7EQ3lTXAsW6d/GI+3/OxSre2xTUB4
VLF1AM9n2kGT16dsE1z9z9VcZB8DjVIHD5+e2wTfbufUZ7kwUE/K9apbRqxQ
5fckyc+egT5pGHE+jWWFm9zZf6Kscb07x73evWMFO/H3W3vNGaj8ZHrpTzY2
KA8Oz0wyYKAnfARWhh0bXL4TeD1Vg4GyKmb2c6WwQX2DOMss3o+Lc6QNYyF2
cKnZd74b79+pjMU9ez3Z4aPbZI8X3t8ggydPQnLYYWxyYMYF77/LGWanbIXN
ECAZu+fWOB1Jrb3MXtPngHN+Z35slNKRQE4ATfAsBxSKetudfkhHHIjfSv0t
Bxi6rLjHp9HRTNxx8iFbTiiYC1+8cIqO6lnljRv2cwEXtbXkrDYdHeRJ/XHp
NA+Yrn/nTH9EQ+1b9DlZD26D3zZ7vCXXp1GXPV9mx7ltEJ63GNc5OI16E6cV
7mZvg3/628SG3kyjP2wFVuoD22AjiNVQ9cI0Wl3bEed+YDvMdTori2yeRiym
s7yyZ7fD09LFVacpKuKI6bxPzdoOhMAAd54OKuKfT6i71LcdoifEIjXvUJHK
9NJ8sQcf0DiGi//TpCJNtZ6r0Wf4INck6swlYSrSDy4XINzlg8zXR82FmamI
MB6s/aOXDzqv/9J07KYgopztu7xFPtjmdvK/f/UU5OQr6xIqzA+vo7l5dxdR
kMev/mPM7vxgW3Iv0+wyBR0Sq1n9HM0PEnZJvV1hFOTvmX494w4/rFuWXVb1
pqCwHoenqj/4ocA5Q1LbnIKiBJQN5+f5oYFWRxxTp6Bze9iaG4QEYDyUdP6I
FAUldLz5s89NAM5H3zEcZKOgFJ6sCKkoAbCtFiL+WCKjdFIUC/k/AShJ/lFa
OE1GWQl7bldVCUCLkFz23j9klNukLhX3XQByT63o9PWRUT4r9wvSnACsPb5+
zryLjIoIf80EBQWhpkFA5dInMiqNe982pCsIqqNTE0/ek1F1fe6BIldBqFL0
DSh5Q0avV89OnTolCKUlHfZZNWTUaOx+BqULgrPlRWJoJRm1nNbl4KoUBJPE
zDH5MjLqqN52p/ubIJQ/5nJsKSGj7lmKfO4/Qaiz9sx0fU5GfdqtlUf5hcBD
iGvkczEZDYc9ttTVEYLbH7JBA18fK7nYtb5HCI6upXdewM9PUQ4ebg0Xgtm6
L1n1pWREUzGmpaUKAdsrTmNKBRnNBwldOFQuBHcHnohy4vmtPmFsUe4Sgvuv
F4oF8fxZxjqy/9GFYG3a4QAfXh+H7DPV+u07oIBzIW2jlYx4D8fXJmjtAGlB
4beDX8lIINfPbu/uHTD2N7ynGNdv5yDqFT+5A+6dMYgIxfWVEhULnLi1A3Sj
61TFZshIwWNxrrx0B+TecM2oWyYj1TvdV2I7d0D7UXc70mYK0vxeyk+k7YDP
P7L6mgUoSJ//xkO+bcLwn8faJR1ZCiLctG4ocBYG/alAjy8ECoojVT7tOi4M
i44ft+fvpaB6Ntm0tRvC8DaPl9U9gIKMzzEd2dsmDKYszR37r1PQaYMTzufJ
wvBaZiAnN5eCqhmDhk+5RED6b86t+koK0jlax71BFAHLP3aa0SMUFC6nMqcc
JAJ7Dzckci9RUOlQ5i/XeBE4FTllFrqditTcosqKPoqAoadu/mUrKpKz1Nrv
RtgJ51guRWZWUJHvei5cPLwTKs4G7ZH4SkUPXvGqFMftBGauB7KOM1QkpklZ
ZX67E8LnH36+uWsaCYoXPHxuIgqEUTfF9dJpxL4gNs2qJwYRKWlLku0zyKr8
+g8NVzEQSEx/wsSYQZeOLTd4RoiB9LF/3fHcmL+/f6SVlolB2xXShxZNGlro
TDXyUheH0VdHd108S0P6ycyy8Y7i0JygpyGaQkOnbMN4ykPFoddpSePhAxqi
vXEc2vxMHDYXifv5fKShiSKOqxWKEiAhtzC/xkNHCkeij/+ykYBnydrIR4KO
/KXH93MekYBi8r+/FzXoaPjOexXvfAkIrIl9SnGhI4m92gJJ7yXA2b80TeUw
HXnx5q1VjkpA0L/f+dtP0tHPK+c7uaQlwdTQqPnjTcx/oL7SA0mY86ZYJuTQ
kdvKgUc+3pIwvYtJeKiYjrpOGkVV35eEPy8bzuq30NG2XYXeI68lQcK+NmbX
dzpymhCy4xmQhJ7cKfUnI3QUoLG8RWuLFLA9ehHBs0RHDv3xj4UlpKDGvvbn
D1YG0o0XNGPSkIIzeUZtK1sZSEznUfdfJAVDQtN2p3Zing9phn5xkYKfpnf2
mckxECWpftPLw1JgZSy0umcXA33Td7iXEy4FNMPctTI9Bqod/al97bIUsCw9
qtiP+f4wJfDTsXQpGEFnz1lgvicZzx3e91gK+MvzG0Ix30+OX1oyrZaCnZVs
+T8w391Tt92Wa5YCPwvnmTjMdzDPUeLplYK67Z1hgZinSlOqDf8mpKDpvjpT
EubttoxX+/uXpCC2xFttAvN90cJ2ppFLGnjen1O9hHk9RO2+ViQqDdvXXxm5
Y5433fWVSFWThkUpr3vBuF1iTas6YyYN/627mdfi+zPosY6HnaRBQECpjIj5
fv4+9xjRWxpceBMTdngx0BG7u+c0w6TBm17hreTBQI5zCgLCF6WhvJjjSCzm
u25e5bON29Kw/06ml8huXE9HguXfh9LAXhTOtYH5zrr0pa+jQhqo+zJMtGwY
iJx/MLz6gzTIhqvqVyAG6nIhc+Z8l4bPjS9fJxjieq6ezrs6Lg1fi7ffqdLE
9SxkNzq2IA17zqTeMlPC9XRN73TlkAFic0OXnCQDeRS/2JBVkYGLJ28EyHLj
+rmb3eE2kQHvr9t/WjLh+rF+Vv9nLwMfnJpEembpaPHA+MHGYzLAIZkV6T9A
Rxnc4q99ymTgQuO3w7U4X55/WbSX2CgDH9WcbVZw/gzwMyRrfJMBk4SexF6c
T3Xr9u7cmJWBwenZu+eD6OhbcNLp+4ayUOYs0SmoQEe1QsLbrtrJQsvidHIP
zr8PGx8XhHrKwuxgi5/PJjoK3/mux+ScLNxp7xEdG6KhbZ8WdPveykL0ptSd
dndoyFE5gC5kKwd+CtmBtE00tHw9sm7QTQ6mD92UbB+bQYXTV6/mH5GDH80r
Ir/fzyDWyici2tfkoH949/eCuBlUaz5h4fhRDpho5/7ark2joLxFboHvcmAd
85rTCOcLQVbOnr4/crD9Z6vlNZwvwlqVg4NY5eFVur+lPc4XCq4hqZct5eHY
PnFTIY5p1F191ou0Vx62KbPbnidT0UWRZIXtfvIgwP/tbcgXKhr4VVybc0ke
vBq3Dk1kUlHa0enRV+/kYdMz6ysj2lQEbevFcV/l4W4uhUDZSUXT6lujbUfk
4efIsy33N1ERaVaD+zuTAuz6PULY6KEgpgsndWhIAd4fGwmWu0ZBJSMX16qd
FaDR3+BdfQQFHbBKbY71VgDOxkw5EV/8PuesOMB9QQGqsgoLhS1wvgh9L9+V
ogAn849yvteioO1fvs1k5ihA2Mcr6waYJ6Hps5cV6hUg1FD34HUOCtq5wOpE
bVeAd3KfNY+vklGzh6Bw5aACtFy/WS5HJ6NTr+VHY6gK0LSwwFc2TkYykvrF
FmsKsFRgFCQ4SEadF22iOLYowjXDO5f2dpPR+T9u8EVMETp72hWOtZGRmm0g
V4aaIqDSLBH/j2T082l0t5epIvDE1UoavyWjazwJObIOitDynG+C9oqMdE9k
Bk0dUATHlq4fiVVkNPq1ULssRBHKB15YsZeT0S3dV6vRZxVh6+KhK4EvyMj8
TmuT+XVFcNHIoJTgfEBe+nmL7Z4iGM5rNw3i/JDpNeXZVqQIWp1XWeZw2+bt
slxarSKEqW2NnMP3z0pzz3h8UgS1GGf6EO4v74roK6k+Rbin1EyqwuM5/VW9
/HdSEYZErrtGVeP8YGfqWLKkCBfOP30mW4fzUrHDjkhOJRA3WEh600BG+7ce
HDERUYKCw06yVs1kxBp+7BmLshJsEUt8/LKDjMq7YyNbDZXA/MpFgvAPMiq8
6u87aqcELNV5uw1HyChH3955xVMJpBUFSo5TcJ77q2UqEIr7d6jKrF0ko6RM
YeVdsUrgPXDcRZQd5wG7DUGbFCVwuqkicAvnh6jlMRbvXCVQr1qRFJajID+v
ioFb75SguNzV1suGgjy3ZLU+7VKCxPz2MAEPCnKpj6tu/K0EubIlRb2hFGQq
5XRrlk0ZTrnoTZ+7Q0HaX3Vjt+xQBlLulPb+EgpSuiQarKCkDFuePQbtJgoS
+DNh6U5Shqad5oUDixTE9d8XzZMHlOEga1NNPj8VMdlUiyeFKoNjE+HzQQ0q
ohRcXqhLUQZiNmfpjaNU9DFE4pnkN2V4PHc+hThBRa/F2DIN/yhDgWrs/CLn
NCpvJ1/ZPacMBr+ltYLUplGOxqtDl3eoQNL7bEn/iGkU9W8v398DKpBRs+Xy
V44ZFJpvvLERqoJ952DNRY0Z5LtPmiJ8XgUs3B4V5rvNIKeX0x9JD1TgcaQc
m9CTGaR4NvFMyR8VOEvTd1CSo6FelrfDkcdUYaRyoFC3mYY6Kh63p5xXhQt/
7n0V76ehD/7JtQU3VeGk1B6nb9M0VNbkkf6zTBV8gbb5qiAdJSXN2prNq8Lh
5n+zmt50FGfSr+u2WQ3MTq0XF4XRURTlnfQJYTW4WqXrVXWRjnydbq48MFaD
lq+Sd32xX7lvRE68slcD0w9pbQtlmO+lXt+7vNRgS3aB7ibs+yZ8Ki9YL6jB
bFXwT/9BOupg9mxtv6kGZ3mt+COm6MiHnvg744EahJZ4u43P0xFj+NWad5ka
fPlQ+vYVCwNd6ZzcodyoBntuBe2c3MJAQg0i2owuNdBs9TcPE2agpy/sHOp+
q8E3/sub7GUYqCPlaZwj2y64EF9ZQNFhIJ/zP7OEhHbBve68zucmDMQ4xlk1
pLAL/vuYYVxNwP0fNPpSaLALrjtlGGyyY6AdjkcnTxJ3wTW5z39TnRioyPTu
JhOPXZBlJMrvv5eBTNVaxVmDd8HnZtK1yP14PNElg/aYXRCWF83b5InH41be
k3Edj++iN+KKec9Ydg/1zt4Fkosiu2Qwv69MJVxTer4LrIwWrNQx34X6ah7Q
3+yC0cqcs2dw+2nrRG1txy645FiMWHHb9JXw98tDu+BL7LuRL5j3HYXEGQfa
LrDVT5H8hXnvk3maU4hZHeLyg15q4vEZ8YWyQ9vVoUZQLrjVDY8X3WtWKKMO
grxxkUV78HiBHO4nddRhwOZrc48jAxW6GYYbW6nDJkVPr91EBjKxCUretA/3
J3hQXRzXp0Mv80lbgDrwv5TxNsP185FvafgvSh2qRC1fV+H6XmFVmlPMVIeG
FhZKPa6/0Oz+rfRCdbC0lHu9XwT3/zteufaVOkzvfbHDA+e39sa/Bx361cFh
mOBaiPOeT/mO04IUPN/nP59uUPH+59mm/lpVh7G9J9O6cD4UuljQFCahAW8P
uQ5uNNNRYdiPYSMNDWCOkHvqX4vPl8/mFRbQgE/cIgMeOH/6oECN/w5rgGNM
nzg3zqtP1xQyX+VrwPZfvOPSOO+aUt3KL1VpQFSqRuRDhM/jwLU2+yYNkKJe
lxlSx+PXjTP9+qsBjG3sLx/iPC1h9k33oqAmQMb3tQmctwNXUu8/dteEbYrB
ZguYfOlOlPdnfDSBWeCZ4F8ZGmrIs55yDNKEpwF8WSPbaUiYuKg/H60JlCOB
pziHZ1BL+sFOmzua0DVcduGj5wya/Vs9vzMXX78Q/ojXeAZJmWwTn3miCTZL
yet5IjPo9Ejj0TvVmnAkdcC+/uc0UlZX2jTxXROCJ/zSgw9NI7eLF5VfD2pC
lniKwEOYRpe6+5xvjWlCyZrFjJPsNOqLuZFtOKcJZvzxEWJTVJTUzNBLFNCC
L3FhZ1jPU1H1Tgevg2JasFnJNTTQn4pGjz2+pCWnBWF6bxZ97anIWMD9y08d
Lbh4dCFcW5SKyD5vglT2akFWfMWfO40UJFwpdHPdUws8k6kVsvh9a7U5rKrL
VwuYV2Ov+GVRUPZzGZaz4VpAlpQ/xR1JQS1M55ScY7Qgtn5n+Bk/Cprd+91J
9pIW1DbsXH6yh4IcluPvfb6tBX6BIsskHeyDjiPvcu9qAYSw3mvCfMh/YDwR
kacFA6Scde4dFNT5L42X+FQLnpsc2ivORUGrNlRdsTItkOnVf7W6RkZKWTYH
aDX4eu1Ol2IGGblScy9+aNCCt7GrBuoTZBSHk0Fmixb4CjokX/lFRs/T9nSE
dmpB+ZYwlbLv2O/Hn81CrxZURZQ3VrWTEbsxm6jgsBZUjLmzpjeRkfaNQxaT
f7VglvlpjiPm6aHhl4FvZrSgsq0P/tRi/ulsT7m9oAUTT+bPeWAeV18LrgzY
0ALVQeW7JZjXoz/f9xlt1oZYz+QvfzDPeXeJM/Nu1YZhTn3PNcx747goxVEh
bdjbYx6xhPPAkW9fHKsltMFD0mdPH26nKiifSlLQBm1SwNgDfH/9mUtZh9S1
IUBXp98R9zfV1t+gra8Nla72IyNlZCQkpfeX3VwbRqU1Hh/EeYUQkbKl3xpf
5/PpfofzzImmvzovHLWBzcVAZCvOOw1QHKLmpg3PlcQe9+A8tK0u7NHTQ9qw
hV03rxTXw0dPr18hUBuood9Z7/eQUemLJb78E9qwc9St+d4wGTGp1JOkT2vD
gSne4WIyGe3Ov3QpJ04bmPkcNTsXyIiRyc3IvK0Nstd42+34KYjA36kslKUN
JNejH+/LUFDajfTDaQ+1wWDmZN6GNgXpXhL/eqNCGw4zl26ecKOgK6sjHNyv
tUFG2iE/OJiCvkc9gYQPeD1uU5H/zuN8EaJReum7NrQHqnpteUZBTWP//m4M
asOEz1eTu/j87vCpkYwd1wbpbTuEpfopqMbV4mb0gjbcrYu4vmUrFS2Z7T0e
KqID1YKPwsgXcf6t2fFkUloH7BrPKXY+oKIs7YHBIyo6MPuv+n58A/68KAY4
HjbRgRyDgxf3sUyjc9ui1dwO6sCIz9yxzJRp1JZk4v8tQAc2+zZ8sKmYRuJs
TNkux3XAuCacLaF3GtUvJXDbX9ABpue+0ffkZhDT76wplKcDweIhD3+9m0GX
q+oLlcd0oNhhhSB9mYa6NS4PP6Hq4Lz/Kd8L+4hcka2w3LwONGZ95T7/DPM/
pzNeYrMuKCl/bdv3jYbYE0aP8CvrwnTM0UeJUtjfWQpybmnpwrVfdzYUdOio
4FxIzxZjXbC2C4w/YU1HxJOz1hz2uqB8PFZ3DPtTkie7/FqoLgSM8N3OLaIj
c02e+clTutBt7anYXUNHdDa+5p5zunDQ8ufyzSacD8rEj5Ym68Lm6x3vkobp
iDte1vh+ui5wnEo/1kCho3ovZe6kbF2oPH9IPGSRjuQ59J77FevCj6ObArfx
MlDvoPF5l0pdqDLmurAJ8z65ApzNXutCSPCNXi9pBkKJNlIqH3Sh4jP/YxEV
zL9DDnShNl3QQ6lqBtoM9ER3T+Ombl1oiVqvLjfC/snlnkbr14UnX4zfJwID
8Qwf9B/8rQvmzvG3arHvNlT56X0i60L8afUESwcGOnX9KPvLf7pwpiOGXxb7
suLhEz8ereiCzt2CN/uxT/fpRxbe2qQH3/pOfBvG/p/Cc/ZMLLcejPGzjb/B
/m8xGkcK5teDUdbn16ZxHph9eU10v6gefBC95x6O80DhjWSKpaweTMZfemaH
eX/AL/WNpqoefFJX1YjEbV6jzBRxHT24LeWXPofvb+TN8eYy0YM/P5PSPuM8
EPnnkeYCQQ/8DMSPLeI8oFT7lPkPSQ92uN7uicV5YODmi67OPXrAYyqaeBDn
lZsBVY/eeOoBX6Eh3MV5hmBSd6rIVw+cvK4J6Tgz0Py2d9Z3gvVAoaP60S4S
zj/jTUJXwvXgkm9L/HUrBjr4uu1vWIwebG3i9XM2Z6BtqV01By/pwU/7u1vP
GTDQh8DeRFKSHpw2kRkU0GSgaLNfngapepA8qaYsrsRAKvx/VOWy9KCqyHR3
piQD3a6faV97qgcHbpddnuNhIKv0uZypMj3YtfrcfQjnv8WjKyd+vNLD/N9u
bo/PxyHBzXxlrbgezHohr3A+UAuVcPOf1AOjLAo58AUdDVvIKe6m64Hg9mqe
n3l0lLZDZdFsSQ/6NNR4ZtLoaLlRL2sHpz5c/TT1VzSajlpEHH99UtKH79tK
/ZeN6Miv+ewRrSB83bVisqOKhvxNFZzmT+iDAZVym/MxDR0p69Sri8b3h+3j
0E6noaB78mzW8fqwosXG7BVOQ8dPfHnk/kQf8rP7Xp9Xp6GYHbIjF/7oQ2Op
6z/YM4POJbe3WFH0ganoiM6A1gyKZT5dyjmrD9aL+X3vts+gOHLbhbRNBmA0
tJdxqWsaXXsbJVEgYwCsv3uvRrlPowRdafZQFQO4m2hutm48jRKffqZqahtA
cul8+rL4NEpOk3pTa2EAYzIXdPzHqCg18NOBDh8DeLH1aFNEDBWlD5yyTAsy
gM+W9Haxw1T0325JVfcwAyAkHg33IlJRpsmp5ZELBvDnbI9kiTB+v5VKjD6J
x/0R8k40M1PRPfnW1pCbBrAyFdlzlUxBOVsl7s7lGEDVucb/1hso6MGVlrja
JwbQeIu+820xBeUthQddKDEALmMHNa27mN+/mw046w1A2NKbU/8UBT1xD5fs
+GgAc6p7SB2+FFTQLrY5rd0AbqxdNZLFeaDo5ckesUED4A2ruroF54FiNbH6
kT8GYG/0mqkQ54HneU2Pn1AM4P2bEhFOnAdKhE7eCJk1gCPW7+e1cR4ovS4a
qblqAOqqmvWK69hnmZq85jYZgtgn1YxJnAcqIsOsarkN4XY94WEMzgOVUzvV
LvAbwkpn+ZcBnAeqvT/yW4kawuUw1p/bMd9quk+scMgaQu1gR5Qo9uNXdjt/
t6sYgobH08MrOA/U1n/4lKptCGX7VPdU4DzwWudE+X5jQxhY7idbYf9+UyiS
JUYwhKm1w/FlOA/Ui3+4OGJnCMHmvaHLOA80pB4/+mS3IUzc8/gjVUpG7zaL
7A7xMIT5OSZ9hRIyGn+kTvp52BCqx3xZ1zH/ecDK0jbYENIuFq3/wm3tAQ/T
qnBDeNlPkvqE84D76RN6smcNwbTl2OEGnAfOC1xVv33ZEJCoWW0jHi+/NEtx
47oh9BWOynTh+XxyKJU6lm4IqsSECzN4vjMTH0X6sw1BITZAUbSRjASu9vPZ
PTYE9rSLhvtacT6RpnO/fG4IXQ5tnfe/4jzwhp1NvtoQbhzT453rI6NrHmLr
qfWGkHq9m/fAGBkVz2ktMDUbQsmQU9UXGhl13balHf9iCA5vmdT34Lwm/il8
lDRsCCGhDR/OieA8cCShv2bCELKGlJZllCkoiCWnW4FuCKvU7erfjCio0ri1
iYXFCFQmez6TDlFQX8+vt2FcRrC34fTjLeEUxBQxW/OLzwj8wveId12jIPtn
ks9qZY1gJGsi062CgsJs9fKV1IxgjalkeNtnCsr4TbqfoWuE89/c+4bfFDQq
GnUz3NoI/sS+jKDvoKIzyW0RKoFGUMRxMEXiOhXlKI2GZp4wgv0XTY9yFVHR
hw8LAeynjSA+pd74QysVbVuTcR9NMILh6FhaAvc0Kjh2xjSryAi8qoKLLt6Z
Rt+dFNi4po3A4FpfeGDrDFqeMlmPnjcCvsbNyI6OfSB+98LYuhEsNa3OlPLQ
UOjbc5PvthqDlXzaThY9Gtqk+a39jJYx3FlPEfhylYa0tsdlTJ4yBm8Bwui8
NB3VcvxQaj5nDJmeHC46mO8EJvW6/CvGoBO58UvBio5cZ/qHvNONQTo5R18s
gI4GxrXDzbKNwflAaA9fJB0F/EpkFc03hiMZHxWLrtBRVLuBck+FMTgeURV4
jP1/40NKXUWdMebFbY31UjpKeD3mePu9MQwKKqLf9XR091lauMM3Y5is+CJs
/pOOZB5Nsar0G4PhE6WgojE6KsqyuLP5tzFs//Bj9y06Hb1OnKlrZBjDcdpo
2qvNDGR90cbpwbIxhCRom85txz56+v5wLIsJmE1m77snykBuYbPhB7hMQPNh
A8tTOQYaCrRnM+IzgVszW2+L7mKgIO+Hd4R2msCjLWuONF0GorktKc9Km8Bf
yst4OVMGOuPk8vqrsgmsXr1Lq8K+y2JT4PRCywQK2H6wPMI+fN1sfTjZyAT0
olxdprAvC+jtiwi2MAHGyFxwEvbpbLViNqIdvu6qOHkR+7a83KZM+d0mkLzZ
jfHFg4FKRD1VNnmYgIPpqMcpzGd9/rLXwz4mEK0su3Yc8/stF4dzfZAJ8LGH
vXqL+U5k8R65F2YCETW000cw/78uVUWcOW0CVoSD3X647UnnYd8fZwK8G7kj
Nfj+0Qm/TN0EE7jZ4PDqCO4vZLhWhe+WCSS4L0Qcx+PN/tj+ZuaOCTjHe1l+
xfM59yXIuT3XBL68nuS+jefL1vx2pKjABFwcW9de4PWk1AudSnhhAsWcrnaa
Tgy0o/oY+5GXJvCucVRCwI6BHjz/kGn51gTkjd99P2iJ88ZjUVXpZhNY/7bf
Z5sZA5Vlh79Z7zCBWZN739X1Gcg4vdV5oMcExp9EO7xWx/nlutToq18mQNix
2F+nwEDdMR3skdMmkHravUdCEOeLcPm7e+ZNoJL0/k0iNwONHz2nqrluAh7C
S7aRzAy04K7iQt5iCnVuD1MGyXS00+Da3cO7TEHSR5E5sI6OHqkPqiI9fH05
7QWxBOcDBd16MTNTYOHacbbtAR2ZCY6O/nAwhZ7sJ1Zt+Dz7/DNTcwo1Bc1U
aX8VOzrawsfU2X3KFF6+Ko+2M8SfH83GiAOxpuA9aMskr0hHAsdt6oJSTAEl
nlRQYsX5YcKJdLnUFIRDOFhX62hI85d3UM2sKSimkTJTFGlocFWaB62ZgrH/
X14WQRpKEv3z4iObGdwxbfvvKgsN/XEPWugSMoMtua4COXUzKPNb2DWqoRm8
Zpvn+6iK83/rxXyZWDMQ95co+yMxjZ7/tSQ+vWoGF0Oucf63QUWe7OwUjRQz
6PlPN35wmIoqLZN0zHLN4EvUI+T4mIoO+zr8eF9gBt4S5+MuJFAR70Xes6RS
M0h8bMPhE0pFQfWpjfvf4f6FiCmgT0WCg65HfrWawXHZAXaSGBU1rghxBXSZ
wcdYcXPBTVQkZnRvd/hvM3irL3p50zfs3xWPhpPZzGGFEF9UcY6CYrsCrvDz
moOgpfIw4SgFqdAVlbKEzOEczc+wEvvaj61Tn6UkzUHMY5yb2xr7m3rxiQJF
cxhN8q4g6VKQluNxfnVNc2i114mPwnz/FaL5stLQHDyr4stvC1KQ4dPK9Xd2
5vDUXNA0b5mMxpqjHhL3mMPlk7sl701jHx43tPniaQ5LPIQTN3+TEWJbmdzn
Zw5Bfm2NcT/JiCL75sZAiDlkx5S7newko7uEC1p+p8wh6+hpL78WMrI5bPF9
8hy+3/Yhm8c7Mpq9sOlM2FVz6I2PvOyKeZiX81Fs4Qa+nsnTvx/zMttL7ce+
DHNYDPNvO4V5mrkz7XZljjm8kU6US8O8TetdsucvMIdQr5NBlZjHKRk+7OEv
zGHe6qj4//090bW5ofOlORw4y1bMhq9f4VM/q9FgDg8+qGw2xLy/0Jmul9Ji
Dnp28pzhOA/EpKzMUDrN4ZqWRXJlBRlFOvgW2f80B7Ynn4KZasgojKvVv2jE
HEiR72Ld3pBRSIuGJOeUOYRvTbd7+Z6MjlzL+BnIMAd/0t8emc9kdNhqLa1p
2Rzc+8Tk734jIy8Wfyf5TQguRWTo7Bwko/0NnziucCMQ+VTF/OQvGe05r/V+
lB+BxO7Gq6b/yMjRNDPWQgxBlqyt1OAGGRGX1w0eyCEIcEh8e20LBVnWBDDW
1RCYl9o5G4pRkHlUW/FBPQR/dOzqaKoUZKSrE/jaDIHAa+JMiSn2e8ZdaVEb
BBqbtlWedKIg1eOBGb1uCDIX9muu4ryooNbhYuCNwGH0PsfbRAqSmdLlzghE
8PS5JEdsLgUJH2GJ23sagfbXhgPD7RTEeuj+0Y67CNzVixIG9ahoQ5RVbtdD
BL6dg/Sde6ho+Wfwr+tFCDjSvrTqnqAi2j7DvXZ1CJi9HZ3Gn1HRgOM30w8D
CNyGmaMy1KdRXw4rx+BWAFMp3xPxOM9XpBj3d+0B+C/uwA6dcRryvcfLVusG
cN3svNSORRriKxxVz/ME+FDo2trESUdh75IunfAFcPJ0/HNSDb+fZvuUecIB
GLMW7B7H6aif6cXef5EA+yjL4iux2Le3XI7tO4PbGuUOpjfoaEJB9WvhRYA+
14fO8di/8z3Onra+DbB41uR01RAd7T3i/FDtP4AY90C5Jvx+ZImQbeO/CxA9
xe3ksoDfd8mfJUcfAERNPrvdiH1r691cu9Z8AIud2pGPhBio/nFERGkh7u+b
Se4M9jOxt6LN50sBBP6Zr9djn/v8eYYWUAnQ6zY9Z2rIQDG973c61gC0PDf8
IIoYSHnsjpXuawBJ18nHHtbY3+khx0UbAKotErfNYZ+MX0eZLB/weDmPz1Cw
b+pzCzRONgOkr+4INHdloLEdE+TOzwA23hNsU9hX0+VeC9Z8ASi4DGPT2Gct
tW6h3G8AI98T/3P4/+/XzfyPXvsBoKQmXsyCeZhHMkw71g+gLydgvh3z0mU/
zxvXIQA/Nr+J07i94Tc8bvIboMngupPx//++Hla5TfYvwKeS5wJu+PmDsQnG
XGSAn/OZ6u24f54kL3/6NIDzM2fV/39fry5DM6WXAaBsfuPZN+z7wY9Ya97O
A/hIb3E5so+BREp7R54sA6hdHR723M1ALa+LuVPWAeSyOWorHLAPt8bpRbJY
wFB/skeELQMp9Lh6e7FbwKv5CLNsCwb6PqqUaMllAX9yFhmaJgx0ZWa1XIXX
AqR+p8Xo4vyis9o5sJ3PAmwWRTmK1DD/OR6zLwlaQI5h8pd0nH9AxtGzWdwC
fD/P6v/gY6AZdekrJdIWIMQ3IaTPyUA5JnPP/5O3gABF1yDhDTpadb3P7L/L
Ap643LwaNUlHzw6fVLXXsoCeexV7lwfpyPO49T5tPQvoDHCN3N5FRzXx1EIm
MwuQJMQjrld0dKrWzOW+gwVkV5XL5VyioyrPZpafLhbwQlFzYyGcjuaXXaoE
9lnAvskzW1Z86eiMif/O5IMWoJKVvpefQEfnXyf9iTluAaQLB38or9FQfP2P
0+63LICDxrznVQgNtRw6rJqebgEpF4LJxh40xLUxNfgl0wKebdI4XGdDQ8lo
nWCbZwHx/1HefJamoVsNclv0yy3gXVVW7+6yGZTVeDKPv9sClPPQ9aW706jf
d2Wvcy9eT7H7m6HT00hs01X26wMW0BGspmmF/TrHMjOEZcwCIMU3OU94Gj36
UK9Hn8P1DuMw3f+Aiv74EyfUli3giqhe1s/LVKTA1pUVtG4Blvmq7RxBVFRo
PbYxxE6AnUsfe+K0qai4iftTxw4CEN1aXnp2UhD1yH/nuMQI0L5nt0zTKwpS
3yypYSNFgMWVNA6WfAoqs9VOf6NEgCan8l0rMRTE+Ftns6RGgMbTV6rfBuL3
Y4L1kq4WARLn9wf77aOg6hb3Q8VGBOj4Ov1jH/bjhaDRbRNmBLhWEaT+TBbz
kjP0vSyBAKVxDxMpAhR05ulcpLcNAc5Hn6gW20xBtXYXlO6RCCDd8/CiOebp
yiRHf48TAQJusNS4Yp6aJqXe4NtLgLsNJ1h9MU/Pq4iB034C1JpdqwrCPH37
6TEj8QABQkVcuUIwT8uFO0/GehPgWIdaAxnzNP/IMi3MjwARgaGn7bE/3qmU
C/MPJMC9Yxuz11+TURKL88z+EAIcdDJ7WvKSjM65nDluf4IA2tYfGf/n24mc
R1TzCAKcuqiv8QDzz5fSHqodTYBYbc3XJzEfXY0XyfJncX8LafMqmJ+2CTIh
IhcIYK9/cKUN89W4x2GK5zKuTxZ7rju+riYXfZQpngDbr26v6MDPS4bnTfxL
IgDTvg0OzTIy4mv4HPg3hQAJwbvDYyvJiJV3frwvlQCE49frX2K+LhyQOtKR
gff36YETQ5ivU09JY++yCJARXls4i/k6sHDKvyoH7492ROLCJzL6Yp37u/Ah
AT657Nac6CKjxrRW3+wnBFDTk3rd1E9GlSP/Rm4W4ftj1khp2I8LNCQOXy4h
wHUnq2eO2I+zYonDUeUECOkYVJhbwXlA5P6vg7UEaE3dfZRDiILCA5sP7q4n
wGeDzuJwnJf8q+gDVo0EqBP4w9qMzwNpt02/6icCfOUunFPC58U0N8xTsoMA
k9vvTmnj86RBzfrJ14X3c+ObjxQ+bwKJMz+WfuL1v+PxynlIQew/RPZTBwmg
yBrSq1JDQUtyVj3DIwRQP/Np4HYHzmcNmd3NkwT46SSTMrpGQU8XLb7+t0QA
V6JUp9YRKsq2CXVJXCPAzN0Pn7UvUVFKesaXc8yWYP/t5fWZHCo6pUlu9+O0
hBfPmKkJfVRkHpT+SUvEEvxmvmx94DGNtKrr7eTFLcEqMeLtWMw0kmOdbBGW
toS8sYPlL7OnEecDs+YNJUuweRi6c2RkGnX/GH/fbmgJN1eu9wWdnEFHbY3e
HHW3hAEt52f5TjQ0rSTysczLEk5EfuPT8KOhcK6ltiUfS7j9OKCpLJqGzrXX
DCQetYQ3q71/Lz3A75O9hqtPY/Dzo3+PX6bRkKCeMCvjvCXUdrTuY8L5P0to
kdv4siXUiWsmGO3A/vHzpein6/j50xtvG03pqNrbwGQq2xL0zuuAz2U6MrHY
Yamdh9fvt8JJS6OjBpkFUsxjS6iUdJ5hzqej1rFqT64SvP6dK6dSG+nIqTnD
d0+5JbD9si5l/UpHXYVRwVnVljDFX7489Av7eoh+jMpbS7hCoCbVLdLRYUeh
S+Hvcb3cX7SUsWJ/Up9PrG22BG0edvfVrZhX23pus7RZQsPl9ZMZOzEf6FV3
SZ2WUF1y0f4c5sepb//lpXZbggBzs08R9ufFysinfb2W8HmGTV0c+1xsxr4y
mUFLYFaKNP6KfY/ltN6r4BFLGN/sOvzeCvPdQ/Bd+Zgl1IRXGPzDvOcxmWtZ
nrSEHWZ+3gddGOiW2PdOwrQlmI/uiWLCvBRcr+xNYljCb/6wjT7M06yh9OGu
eUvQ6PD4j4J5K/Hu1MTOFUtQ4tu1SQ/77aOHrjTfDUv4OswuUIl5rXRFd7Fo
kxVM+G4tOop5/jxAgOnfZiswnhLMdMNtbdvZzSY8VpAtY4/O4ftfKnVvvbzN
CjKHnrEMYL6bclXu+CxgBeGSB2yi8XjvyGmS/CJWEHW9etwZz8emPULxgLgV
FGvdzArC+eRTyV6NR9JW0CVko/EB5xfnWzoGZHkreIJMwwPwertP8iMdFStI
5zVzdsb1cN/7z+asuhVMOVecuorrNaj7zem9thXcX9no48b19BWqcOM2sIIU
jksx47jefxdSD+01sQIXLVcnEXkGCv0ZfuQesoIHT3mqCkUZKCpbO0qVaAWP
p9+k0tgZaCWW73yEgxXsYQ6sL1+hozhvxtU6Fysw5KAt/5mho0SZ8v/sPayA
p79S7UUPHWUXalWFBFuBqaVUb0QO9teffi25x63A3/BM2J2bdDTLldH/LdwK
Bll7dQ7E0ZH9sWVm07N4PsQB458+dLSs9d6JJ9kKNqiPGHYSdORR5zpR/NwK
PpiMh729SUNXKNdWhsusQPny0ffhsTRUKv6KV7Aar78+8Lgo5jlHnLhebL0V
rB/jW/PG/K6xGr/o+MUKPG2TesKWZ5BQR7ToNM0Kgv6y9rUMTSPCxlN1mTm8
3lqR4pU30+i45oCF25IVTMZw37qPP/9NqRBUz2wN1EITQbsD0yhyP2dVCp81
RD48HUP+RUUPEkxaGoWsgS7T7W/zjoraXh3rn99pDVsPEh0hn4rkxLqYvWWt
wbeM2UwB+3D3cJaThq41WJT5Uq1YqYiJr/2wn6E1jKsMycpSKEjNcuPUHVNr
UBgMPNrUTUGXH/vd27Cyhi0ht3JDCimopOe/Eh07a3D1/64XmUZBfZtb3gU6
WsOV5w4Gey9QkHaw2sSXfdZwHOq+ZnlQ0KF7h1Y2eVqDu8q9CS4iBSW13eI1
PGQNL2rT270MMN/XGqVDfa2h/MaR6jRFChpVn9N9cMQa6vZfelMuTEG8PorE
7mBrnK/u3n/NRUHGtz0OcJywhjzzqNWKNTK6/e/NxbBoaxiWy2uPHCej4123
DnudtQbjkKNvKQNk5FDmZ0G8gNdzO57NpJuMlG/pS+tetga9/qh9vm1kxH6C
k1kq3hrUg8v9//99uD+OA8Pc163h+6GqCcJbMnqn9qJhIcUaBvcopW+8IqMc
7ksPfqdaA5d8ydC9KszzKde4LxnWcM+vbYsI9mOPVkWfuixrsC1ZPXQa+7F+
4TIqyLGGD/k1/HWYzwLx7ZJpD63B8/7T0FHMb3rAg43zT6xBRvX1nRnc7rCK
GAousgZGdPTh3/j+Ylmbt24l1nBylv18Pe4vkUUkl1BuDZbbM/Iu4vGOjJDP
q1fj/UYucbuwr1s11B/aWWsN86s+HY21ZCSde9ucvd4avJfnlAkNZLQe6y/B
eGcNd17uePWsCfPcy2B98KM19MUsn91oJ6NXJly/WlutwSepK9ysh4wydg6+
qWq3hgC17vsBQ2R0aunF/byv1qBYoLMWPUlGu3svxd74bg09O2fjTs2SkfrL
fQfP/MTzUVhO8mSiIJ4MJbOAQWuwnlAzUsa+3LS3Y9V0DM+/8t7iOWUKytfO
G1CatIYjziLWTEYUdHH7qdcCVHyeswYfBNlhnn8ROUeZtQaXvdS+kVAKEimh
HOhdtIZCYcW6aXze5pPfmnxYtYabSzfFf+LzWEYKWLnHagOmLW8Om9djn24q
jbEXsAH56jH+dTEqYn182dNA2AZ0uag1z/WpaOSym7GsmA3ckJi1kt2NeW6x
urQsawNsDVZPnBKoaPsb2zNFOjbgXP22QWKDiqbv7fTIMLCBuiQOi9MS06gt
hmp4ycQGglaE9Y+bT6NrhmmLHpY2cKRDwUUobhqtVvyK5tyLnw8kJKRxzqDx
osiooHDc/4au/NYdNOQmvv6rMMoGvl67QAlQpaGPN6/ZTsbYwJp7KHsLoqH8
U3eEgy/bgMyEi2NaEPZv81e1Iek20FN++uf5VzTUVWohW5xpAzOlv1pD2mnI
QvbTdUq2DegHdTeojNCQFEe/17HHNjDUM8/EzEFHv76urh+vtgFJ7cAtaA/m
r9XVwBe1NvAx+uEYxY+O3lRv6Zypx+s7vW1dKxK/T+9J5IU124D5nxd/j2TQ
EQ9vAWfZZxtoE5jys3tCR2fjNMLpX/B1v7eehVXYpwLAMrzXBoi8CfrvsU99
+tHyrHzABj7YH74dMUxHRqTdAv+GbcBv+8JIApWOCl//PKczZgP9R+5Mry3R
kbCG71jEpA0sGPSyd7Bh3uZNOVZSbeDW+J242W0MNM8fUT1LtwHqxN83oZgX
3xcvx0cu43qfSNtvqc5AViE8tKp1GziTeGwyC/OncjDdfZ7FFth4eU31zRlI
1kX8nf5mW4jte9fPh/09tfGxcjS3LZQ7NrSo22Pe66mnvtxqC4+uerAmYJ6f
LKheXuC3hfQzctVimOfDIsjPUNgWBPJiGGTMT5fk5s+nxWyhQlNSaQ7ztWHd
WfeVlC2URG9qMsA81zjZm70kZwuaZQHhFZjPOb992IyVbWFHbkJD0P///u02
eSxmly1MqDBd/v/348+3nOyp1bIF40dHky/j+6nGy+YrerbA0yu1MIV57vX8
UoGJMZ6vqXjVLTxemyT3tnPmtiB90mM4Cs/HNDXt9GuCLXQHQFou5vkzVrGR
VRtbGGO4mG7B69kZnW9nZm8LXLlia42Y50mTauWxzrbQR/uw5QPm+fKBqp31
e22hLrG7gB/X62iH2eX1/bbA4bzhVYXrSaxwcr3gYwvnzl2/uoH5XSP/4/Vb
f1vI+JtHKBVjIMVMb3mmo7bgupV1/j32c/bYsPm4k7YQVUq+rbhGR1Ezi4fe
ReL1y21Wv0ino7HDF5uZY2xB75xd4O4xOvpgk5p56ZItDBWKMYV8xteP1LXH
XLOFXb0OQ0X1dMQe/4clIskWsnN9Qq6W0RGxWf+YX6otiFC+9Irh89lm229h
9dAW9g3eeL7vAB19I8qR2Rpt4fFJxLv2k4Zmgxyl1j/awssCL69trTTsA1H7
5lttYZmr5uzmGvx5bG15O/4V1z9N52H5fzTUZ3csvXnEFhr6z1iGu9DQKKna
LJGZCAa/5iVFUmbQppCh8ItsRHC4f1//SugMkrvOUXiGkwhX7rD81bKfQUc+
e/IFbyfC29rtAcfx53/KfmOcJE0ESbHjFQJJ04g7VEnMUp4I12c92s1DppFa
8u7dJspEqAy6a93ngPNA26M6VS0i/Dr48lLM9mnEcCDe4rEgAmfXkfFJ7Ov8
x05+ZLUm4vV9dFe5RkW6N7KWV4lEuK1nfJQF8z6qneJPdSGCmHK+caIRFd2h
CmaNueL5RvB9QtJUVLMFfRl0J4KM58OC+5xUtOx426jDhwixqUWehwYoSPR4
7fEmfyKkPF5fbW7C7+OU34/qg4gQsefx2HgZBZ3v0ON9EUYEww3+1t1JFJQ7
fciy4BQRLhz6Ty4/moIaeBNO554mgmwzj3VNAAUxO/eN3owjQlJs9KqmFQW1
1O+TPXWFCI8aUNJfXQq6pf7Vzz2BCMvZVeO+ChTknuOQb5pMhDv7eJwe4zwg
xdvyR+oWEegCmdRSbgqaiLWUZ0snQgzbc0b8BhmVUusDJu8QoXB3bpIa5tHp
g8ZP2u8RIXTo5K8HmFfQXjVelkuEm5Mf+8YxzzjMtBQzHhGhKuIbYvpBRp3F
xYExBUTQlv/cNt1BRpliSoWHnhHB8/EgVDaTkU/yownCCyJEHt91YM87MlJa
lVBWrCACc8Or+k91ZEQLyTrK/ZIIo+ezP0pg36/pFyyaqSXC+7l99c7Y9+Ps
b099qyeC84kjC4ew7xPreFRrGvF4+k5vHbGvb1NNCMluIoISXPIVx/zvzdpU
HPeJCDpSF/524HzwgOsCxb+DCP6Te4T98PWgmGU1uy7c3/KLN334ec2pyGO7
eogQX0Z8oI99f9GD/nx7HxEeHvuSEI19v6E1dHpukAh2y6tmOdj3E4wm1PtG
iCBfl2byDPu+y1O/E/VjRDivHJyfg31fWGToxcNJIlhFpWScxr4/nOBJu0Yl
QkAXr6YR9v3Cxe+aIXQidB1fShnuI6OwoN0nnefw/hIdvx7/Q0aGvW1lOkt4
Px89//57moyYiETGjjUiKGyd+Pf/38e0vHyvvcpkB34VLyMusOP9V0QRw6x2
wFr7IzufH+/3Zv3ZQh47mDAT4MrSxPsdVaZ7Y5sdiK8PlAQBBZWOq0WeFLCD
g3t9NwvvpiBokp03ErODW9LWL7dHUhCHfq6+hJQdfG6LiHNPoKDOxzujWeTs
IO8k88jpbAryubp98ZOqHZRFry+YNVNQnNXG0gETO6BmSPdcVaAiYmWMMSA7
KOi7a+EIVLRNbj5GztIOrue7ivR44vy9ibpCIdnBjNCBZJFUKmpo7FuL9bQD
rpcvEv5wTCMmi2rmB2fs4NHfdaWrfDPI0+rvp95YO7gfwZXcaziDKm2F07df
soMvRvfy73rPoCCnGIXLSXawpLEp2qBkBn09YG5/5J4d8Ka+YXFUpKGHUU3p
am/sIBO2FTq30NDqmYWDAe/sQO/2rm8L/fj9FaukmPPRDpId56yOzdAQ15Wk
V1s77GCj//znh4J0FHHb6RfjF67foaEfxw7RUUf6hQLV33ZgEZlbUnWCjpQy
S8P8/+LxUiK/3sZ+NJDDt6lnBtffT59BfkBHVsU9iq+YSLB0jk8sup+Ocl5s
ptNZSeA88f5jyQQdLZYb1qpwksDIuvkcaY6O9lQfvey3hYR5ZRRtzcxAxa+y
HLK3k3C99clZPJgPbz4LfhckQdrsc0mbHQzk07D6a8tOEgx9nlG2lMb+3Hzo
5AUZEpyYkDSW12GgsE83jWsUSLBvn/DFTSbYV9sbNtFVSND35FCiAoGB5L7S
25Q1SLB37JJ3MhHztFsmw1eHBLdTjfR0nBio98de73sGJPDVNDAV2Yv9uf+K
UrcJCWqEVd+Y7meg5F9VdB4gwa/DBEa2JwONj4zXWlvh+WszPzHC/IWxHVfO
E0nQ2N6Xz4f5nDVBdHzpQAL7kG91ipjfs+QzQjQXEoT6kZX+/313p5miIaV9
JBg78FmSA7cLGf2Fhz1IcFVWbPY7zgcs8zzhWQdJIJ54bem3F+b7kpnJt8Mk
sB09eFcHj/9y9TgrzxESmEqF8ja7MRAf04N2q2ASPC2eZM/bg/1509eM2OMk
ID6T1P7gyEBN7Cw+1eEkiDDuRTp4/VJcOsozUSS4OzRvQLdgoJgt/gzFsyQA
gmU3M65f97b/6nwu4PrY/xoNwvVN2LHg2BVPgm6d7Bw7GQZKb2n53XidBKLN
hyvDRRgo90zWmYqbJHitfSVYCOex6n6zx+l3SDDs5PhjAPt5Y/JWk6v3SCBR
1K2FTwbqMBvpjMwlQdK3sI91mO9juVdW3QpIsI3elNLdTkc0F7dU22ckWCe1
IYt3dLTKrKRk+IIE7h4EPbtKOhLw/7xX5CUJuNK5+0zv0hFBie9ZfxMJNrhO
//7//3M4/fwNbZ9IEGz18dGcM/b1pKqe1x34fHm6Np8BOgqjuLPk9JDgzYid
f5cUHeWW5nr4jJNgtWZ5D2EIf34Md3GMsdkDz6RY+JQb9vep9fvfOe1BJOmZ
ZoU1DfHf69Rp2mIPi0dI+y7o0pDKWoR3gaA9iLUdvajJR0Me72qrj8rbA2F/
FVt19gzyD0928FS2h9dJHlM2Z2dQmOyhUdIuezhmOHBQyHMGJVxl5lXTswfp
X4tvkoRnULUdMWDayh62vvSmn7g7jRqX/9fRmcdD9b1xHKVUVEpkSZJUkqWU
SjkPRTJmzD5jK5VdSUhaRBRSliJfJGVJQqIsbSRJpSzZipQ1ZPYJLcjv+P05
r3PvWZ7znPP+fK57D+WJb1YEsFDttLt1mo/q8znxjTYEWH19E9fEkY8G5OKe
F9EJcOOHXEOTBh8tbW5b6u9CAII5efjnAx5SD79777AHvr/KoWvZdR7SMTqF
6EcI8KymJKXuNA+ZJ6l5bwkggK92vsPUXh7ytT9c/SucANHTD8dEP7DfvjXS
szOKAG6KW9qsm7mooP/49PkrBLgvbxvi/4yLho6E7pS9ToBTm2tM9sRz0YXi
uQ6UFAK4PqijjJ7hIs3x2FNJNwngLPNJ6oIH9v8hN8s0cgig4JNZZ4t5P/lK
q801jwC3sm3Srm3molSZgp95hQToUAiKqp55nk/cvET4kAA7kcnjPgUuarv6
1GBLOQFo+vMmxjAf/NrNbE8/I4Dhex+l6T+Yl6rvjr54QQD+798tEpgvhQfI
V2bXEIBeHDc+1Yf9f/anvH1vCeAeGrvkz2cOGhne/y72AwG+yOx0HW3E/Ns4
ONTSRIANZ8+sFmO+a/sdnaPcRoCPCwzCRrFfflU2qrW/gwCNFddKp7Cfdp44
szvrKwGOJKGKRdhv/0OzDg33EoCrlIl0sR9PuxAdunGQANJGsZ107Nd3vJO/
5TdCAK+uTxsuz/BcLqWinE+AHIf+j02Y54FUja5JMc6XPw3b1848H/jv7l+z
XwTQ+t1gH4d5XvxFTzlyggBZzQkr5mOekzTKjD9ME0BSusErGfOc67KLKT/b
BqQX6G0wecJB0fdqApgyNhAUtsL0ZyXWJ3xCwg1ZGzh8467Ey9ccVLuppbhn
sQ2MPHsbkI39vstJ+6Y1y2zgi1ln6sz77VLPe/leyjYw+/IW/4IeDrol4SlX
tMIGXlVZ/GvicNBOC+GGsVU28LqnR27Bbw7qvHTSeoe2DUzbRRXaSXOR4tKI
yBo9G1i5gLbEAM9nCUsuZ95mG4hNWxVTiuebmpZYQzK2ASpfZg7Bgoti1mRJ
diAbOMQSW6V7c5GOl46G+h4bYB4j/2aGYn1YWGx62MoGCP8+IMUkLpq9reoM
j2wD45pK2uk1XJR5dm/qJoYN3PmVYe38FfP/ZcPjk3Y2EO+y65bqLy46Y/11
TPKQDXRpvfc9spGHxI5/jyn624CZzrMMUTYPxWecj3U4aQPhF7Vqxmp4SG9Q
5v7tMzZwabeV5tvvPOR1TGlE54INrPkRL/V0PR/1njdyQddt4FTXUkPeEz7S
VlwY65tiA4me5883feMjr7yh8oybNnAsJ6DJeLYAjTanLpidg/snOTjsTRYg
GS3JR2/LbEAnfJNgB0+A9GrrJamfbUDofZc8lSRE/vZ3N4R34fbKb9/tzhOi
x/xQRkmPDdAbk5szKrG/VzK6p/jDBnyHHi6+912I6B6p5C9/bOCqIOr4hIEI
pUz6n5b9ZwMvc5a9V9iN/X48MXuXFBFWiJN2t9FFyP2JxO9b84lg72n5Vv+k
CJ2e737LRZUI+q1N8QllIvQiHd5dX0kEt+W7luu+FqHZm1V+1q4mQt6IbeO2
FhGKcai3XK9LhKDNAxXJ2L83C3J87Q2IYDyLd6IX+3fFC6Gpl42IsOv+cOcl
7N9vF2zm83YSIdDSsnlIRYy+g9zylVhJaV+uXXddS4x02gbNyBZEYG0u3Hxt
oxgd86zyPr+PCMnCrY++bMH+fSrl+kMiEVbqugb67BKjP1f9X/RTcLnxnQVW
2K+aahN/KDCJECWbH+GG/WzYU+2llvZEeOPxdeqNrRi9IUnsOrmfCCr6Umle
2A/L9ne45R4igsjZzoE4499PPorvcCPC0CV4cAz76esLYp7O9yZCgnmK7EfM
+85bbgMmx4hgektb6jjm/UojWHjUnwi+oXPFtpjnLm+Vt6WfJEJEHPOOz8z3
bY4/DzaeIQLVrut7Pb6eL/xwWSKUCPlLsm/MvA+3+WJOqeEFItzQsQqiYt4H
KYd2H4oiQsGLzSFn7MTo+X27eYlXiDDfdm4JhyFGkuabN7+OJ8Kdo2dM7lDE
yLJd1mk8EcefM0eQZ4P9u9dgxNoUIqg6JA1MW4pR478XReybuL8bl2+6C2Kk
kJDSeSmDCHddli3K3i5G89uWfvS7Q4QfcpPe4ZvESEIp9o3DPSK4fy2d16Yj
RrzUsJKNxUQ41ew3+gXzfqBrMk+xlAifPEzWJGPed6qfzJh+jPv7ti+wdQ7W
G5nesR+riFCcxbzaNfN+48D3C09riBDQULmyaFCEHmo7n8l6SwSF3v+Cl2K9
eCuP7nGiCcd3zfxdqdUiFPRwl7lyDxH+u3hj6coYEfIZLd8mNUAEyfxq4dA5
EXLZukmfM0SEQa1Hiod9RYjyVFutQkAEE5H03DCqCOlULxp3nibCuU+Ntd+W
itDXj733ctVJ0B/oNHcgVohalzrevqpJgn9Tphu/BQtRHaM96bQ2Cb5LlUw2
HBGiso66cBs9EgxlBG3Kthai+N5HTsJdJHj1zVUtYo4QmYsuym9zwuXJzW5u
eD1v2ywhs+ogCZw9Ta9GD/CR3onT/+a5kuCdS6eUzGs+Uv3jw/lyhARLZ53U
WRPJR6MS7NchZ0kwnxQ5O2gxH42YNz/zCCWB1QJ+8Z+fPNRzweYh5QIJ8/rq
1OQnHqqXMbu1+goJHjswBlIyeChnsc6pNzdIUOY4IZNtMrM/2f2efZsE/j+X
Zd/D/r382aWT5tkkCH0RIu8jw0Nv3X6cqCggwW6rJfcsPnMReafy2N8iErxR
91928CUXdcjvC9hWSoJM1Yu2NvlcNPI81+9RBQmkX3/YnXke8/XaZ5HwJQms
9QMiFHy4aMJd5rheLQlWtvrEuTpwkexSj2P3GkjwaPesmOJtXJQ4/B9/sJkE
zzhTpo/WcZFa5ZujWp9IsM/o68fbyly00XPtkVvdJKiI8Plm/Y+DykxZnK5+
EmyOlP8rK+YgU4VIL5VhEhBUJTfWDmI+/Sj7weLi+Ev7dQd1Yd69GPS4LiTB
eZlZ9LUtHNSeqDjcPEqCgxyj+hbsRw94Wbov/kMCs8ComFDsV4dR4CBxigTJ
UTfr9LGf9V2W43pZ0hZmb0l36sd+/PdI28BbaVs4rnf8Vxr24+erpF3mzLeF
/dMtVjN+fH7Slv7dC22BsumC1HrM32verofOL7GF+sS8hpn30VXMrvdWKtrC
taKXwh78O0vxtfOkii0svfXnSNPM39+5o93bV9rCWbspywbM/5KXWgdOrraF
X59Phn3B+mDnf/RvJWtt4Rhr/eo/WD+8PnLBSbzBFrQuJEuue47Ha17SpW9g
C5lK6Yc8qvF4lQYcjhrZQh3aePTpOw7az1v6JW+bLYTpbLdSx/57sHq3/fBO
W3ggXaqS+IWDfJL9O9aY2UIzbWqeGo7nr6NZ7MMWuP/eMk2lIg4K3d3y6fY+
W1BI1Ih2xvMhozyL9Y1oC+ukJa1VZbH/5m9qV6XawtVfLqu+q3DR8ppDDDum
LbRkzdWs0OGi2ynXWpPsbeGf4lFipgkXrT9WTWvdbwvvGTs7rxG5aIeKJtXW
3RYiGpQ5VwK4qFpA+XjF2xZiF89pv3qJiwivz5PrjtmCucewKPkWFzn69pIs
gmxB9fBqdmYDFw1YyDeEnbWFjwdcRWlDXHRU1YxYFWoLIz73z16W5KFztbcJ
JpdsIVz0xddoGw/NSWuqC4qxhW+QunqQzkNxxyWsy67agoHhf4an/LA/V3O2
Mky1hcdWGm4binjopd9Ki7X5thB/Tbd68RY++jsmiFd7YAvzPjdSqhh8ZHSq
qkv+kS3WLxv3zj7JR7khBwMmn9rC5TJzi43P+Cj+SlbWxzpbeFLUeG/NPgFy
zlkrdXbEFu4Y7IPx7UKUuv438TjfFkypvVM/bfD+U/A2xU1sC2W5o/2iA0Jk
9cjTkPLXFlJv2Kz8dFGIlvcwDJZKkyErltWa3SRE09z/DgwrkCFzwcGmZU4i
lKYXKt2vSAbNwE1jtKMitM3XI//rcjK0xP0zMwoWIb+f2341q5HhNlVp7usb
IrRoy6qb9epkWJEge9UrT4QKAuftfqtBhmXlGh/THovQ4J+O2AotMhjTOZ0J
mOfhJtVGj7XJYKZ57CupR4Q0gvM6H64jwxfztaHhXBGylzijnatLBovT4U37
ZonRL7PDHzL1yKAUdyalRQ77w3CC300DMtQ/3WT9Bvv3hjlqldeMyCDh3rqu
Z70YeVvNdonZSobv1Z6104ZiJBPNnRe1DV/vWFEfjHl0533rg7AdZNinaZHH
wrwyl6tgBO8kw5R5b9ZlzLNu0p2Jk6ZkuPfowq7lmHdn42My/IAMp09o/p0g
i5Fy84m9R83JkDCm5LQF87Js6X6e+x4yRLUetHqF+U5jWCYcsiSD8je5gDuY
78Ikve1OVmS4PBFf+gXzPeazYjfLmgxais59rpjXOirTF6g2ZOipTWnZjXn+
xmFIh0jC9Rv7jcx8r+Zys7FpL5kMsV9HNk/h6yW7ywPNqWTY1t/7phPzPV3j
ttouOhnG/bZULsL1L4w2fLuRSYbjqbt187GfD/lZ7a/OJsNq15WkuyzcH0f6
ykX2ZCDS5xvPwfrEufZ73bQDGSS/XZt8h/VLk/7JQKETLg/aWzKK9Y1Zioxm
7wE8X6nbw6IsxOihVGr9x4NkcDt8a0kUEiPNIxtOVR8mQ/w4xW58mxhda3uu
9ciVDIcDrlu34/jPQqSmLHcyhE3d79TBvB+QP772ojcZLFf2OJpi3tPPSLWc
OEqGVyssnWdj3r8eSDjndowMiZPyZTaY9znlZW17/cnwkQ5f/TDvFVdZnd92
ggwnyw3t2Jj3kdEduutPkuFu+t8zjZ0i5OE0GT7/DBlCf9weCcO815llvqk+
jAw1Xmee+2Hepx5p+VpxgQxiNi3ILkSEFrS7XCqMwOPPRxE/Me+5uZE9cdFk
OPt6riSNJkKFpPpY6jUyVDqCcNsyEVJ/vH/H7kScb4seFmyWFqG4VcLvm5PI
sOtT/o7ZY0LkO7pk17JUnF8XuVXGrUK0KZXN+ZRBhoByIcvhKub/9/69TsV4
vsWNzbPmC5G27YmfxEdkcH+SJhsgFqD/Hs+5ZVpKBt3fgyfmfBSgoMvrx1c+
IUOgncCgPFaAdhgey+6rIsNynzW/xmQFqOLsXwmPJjJsfXZzO0eZj8YfDArD
msmw7l/kC4UJHjLob+652UqGRZKT51u6eCh7X35Vy2e8HtU8Vmhn8tC3s/8V
8TvJUN56OqnmIg8pFYXfnvcVz3ffwSQ5Lx6KVnQMRb14v5Cr+PbQiIdq9ln5
2vfj9e1ts2e5Kg9NnTVyPvGdDEPja3p3SGF/3y8L+T9wfjZI573Dfp5ZVDGt
KCZDzs0KcnAw3u/77wkMR8lwtVT9JfLioneKSd0242Q44UtO/8biop3BPi/C
/uJ4KbZEVG7hosAi+wc3J8kw592Q9BxtLnrQb3nr8T8ybG42Lt2qhP2/9coQ
vhQFJEu3B+6f5CDH4AXH5klToPe+S6e9kIOuF/3arzWXApfvZ2kSvnNQQ38/
Cc2jgL1BQach5peMUpOp/QIKbHgpvUke883c+rneCTkKHHxtYcnB/DsbnKse
v4gCDpmSW6oxH8uKEhfmy1PgpFajajLmp6A/9N/rpRQIWasx7YN5v07pKL9n
GQXI4jdhVpj3h6ztvk0oUWDSPGqzNuZ9WrBFg6IKBVI/aabPw7xvLzKsNFSj
APjY2Y5ivi8eWFFoo06BQ5rfXw/h3/uU5qe7a1DA/VK37HfM+zDr8ZgwTQq0
7XGexcO8fx7cF3xTiwLlgnNREjPn3RU1HH2sTYHla2hnNHB/9AeeOrWso4D1
8b6nRNxfD6W7RL4OBYJ124ei8HgyrRN2zdtIgYY41WXNeLxdwSEbtfQpoG4+
b/d6HI9lxd4rkCG+f2TseCyOF2mAJWe/mQLG+tsyJTHvo5T2TAVsoUDBn7rG
MMz7amsDXpwxBQzc3vnLY95PBKt9zdtOgdUx6GzBAi4yKpapf21CAbmtSz5S
Me99Bkaf9+zC8VynbT8L8z5XqbdgAlHg6wbn6ec7uKjXuj5N0ZwCLoWH487Z
cBG9+M5ZG0sKFH87/mGxPxfFDlw94m6F63/xIaIrkoveKJ1zDLOmAPFGYnHO
TawPzjF3Pibhct31arofuGgVYe7kahYFava1pibgfDZq292sYkeB7yreCdK2
PGR5IDRX3oEC50Kuk3fg/Pfy/0Of3k+BPLfYZ5/xeim5wbnf6UaB/45Oe+1X
4yNLbuOBq4EUsKh4lrF5gwCxA2W3RgXh9nYV1arZCpCXxD7ZkNMUUJtDsD/g
L0BxCtWPj5yjgE5Y+f33zwXo884SeasICrh+Yfmprhcir5jkV/+uUyCt0Xm+
wgshOqvUljL2HwXEz1Kz/D8KUWyGvC83hQKL/1vwMK9fiB6VRqt13sT5ey26
NHKuCE1+PXui9A4F5N8/cLazEaGFHk8IBXdxPh6Lk/voKEKrxGOrsu5RQGpy
tFp0RIQs5xxriL9PAfo5etDyK3g/0zu49kgpBTIv2Vp5YD+e+fjm1KFyCkyl
jLQkNotQiXlni90TCmhK036bdYvQZyYtdG8FBVR2em+X/SVCIz1xTNMXOL61
0+6rpMRoyuuD7paXFNgx2TrvrizmRYhFh+ZrCjgX3zEYWylGRvPCHii/ocDb
47vDytdhv5lQeXHxOwpsP8B68tVAjNgrJhzmvqdAOnf/elfMF++7xpv+fcD9
2+RkS8D8OWcYIDPWQIFlO/MOx2I+xT8r+sZposDKWvsWXYIYZVrwSvqaKfBx
9YUFazC/SxrXX+5opYASOyz2BOZf/OqXd/62U+DPtw0xLpjf3ifZVaodFKig
p/y8gvlt+V7QufMLBfqfC/RnvjfXXBk55vSVAqIC1+ZIzOMpP/XFId0UyN6v
RbbHvP5cW6pzu5cCgZd8z858b1aiQrR42U8B5dR2nfv4+jifgQN93ykwP/3Z
fn3Mb6/qM6dnDVMg+UrMOH+mPcWl17VGcH8O9i/k4/6s8sp7YMGlQGETo0YP
643JCrM6Nz6OzyZt30d4PJ/lOwYihRQQjo+sD8HjfeTqO50rpsDajoaN13E8
Yp/MVakbxflQtO/xb1PcntwtI844BZJ+kq3vG+P2Dm61lf2D1597zp8yfdxe
ab3nxgkcH+lRvvJaXL/jZPqxaQq4fetPmlyK6y9KeBIvSYWbLpdiLs7D9c/e
0Fo8iwqG254vO/1PhCwK7OaNzqUCZ4R3/cnMebISotXL5lPBOG6B1CLM50la
lOlWWSpIbRYVDnzAfn2izD9oMRWEwYNe2sX4eoLCt8nlVLihuvnh7QB8fXr+
7xWqVFjpxGtLcBGhT2LzpWgFFYZejFsY0UUoNvW41flVVDjNU5+VuEmEJn40
PJTWoYL2/h4vH64QtUddilxoQoV7pSEGrnZC9LBLI1N/FxX6ilYav7MUohiD
x8/JiArTzLmDBkZCtOfzoOjabio8ebbgzYpFQlS8do+jkg0Vtjn+mdN5WYCu
1P4z0HCiwsmrjYRZgXwExwcNVxygwl0uLd+Dhf23asMmlYNU2PDktuXu7Xzk
ePymkYIrFfrdL7GO/uOhjWo7t8kcpcIKv/19KnE81Fe7erv0MSqQ0t/mPgrg
oaTjC3ZIHadCp2X6niF7HvpX22kyGUCFyU/FD/TW81DD8VNIeJYKCg1LnuXV
c1GY2kHgnaNCx5jnsYuPuWjrGyuzkVAqXFVsIi/P5qJ0teW7By5QwfZ2Wr0/
5i/1zfTu3ggqTHV3nDL35qI5fkN7vkVR4bB9RESbHRcde1Nm+fkKFVRbV/2m
beciLb/0vW2xVPAYZvD34P35s1qEVXM8FewT16hIq3HRlTdH9zVeo8L9Qu+G
pIVcBH4M6w+JVBhIbXealOSiUbVdhHdJVAh7rqC6bZyDct9o2dQmU2HipRLL
hoN57SdLfJVKhfyMGD2TXsy/FaPEqjScD+rj5+d85qCaN19IFek4f86c1Stq
5KAgv1e2T29TYeQXQX7HW+x/V+STyzOpwI6/MjfnJQf1vLlGKcmmgpYboXXs
GQcl+p2mFudQoWCvM0cH89BqxSFaYS4V3l55VmyJeTn5Zh89P48K1BjiFWvM
52I/Q0ZuARVWZczpMcZ8dluhzLxTiMsz9BcuxvxVeSvByiyiwuNlhWtbZ96f
8xtm3XpIhRDR6VkXZ/i8oomdVkKFCnHNydUz7+O9LbdLKaNC9Ken9kXFHDTi
d8s+6TGeT6fLYbqlHJS+ItIh4SkVMtyIlclPOIj61scx/jkVtnC2nByr5KA5
/kynmEoqxFMfNZi/5qCnK0z3R1dR4Zb84EDoB+y/3645EFlNBZub/I4HrRyk
6S/nfKGGChe8ePWNX7G+WDHmfL6WCg+WH/7SM8RB0W+7Dp57i+efTbjbJ+Yg
8YqCw0EfcH5/8j5eivmc8zbB5UQDzofDCYMXlLnI3v+Mq18TFY4UKCwwX4f9
9Vtr9yOtVHj39nDpeSusz/w3eXi2z+TPxfmS9lyko67i6faZChYyD/U9jnBR
gv8PL+cuKvgcJdAHE7hIxfL0cdo3KlTm+aXE5HJR5vIFQZY9VHC6Ivq0oJKL
HlboXtQdwPN5feB3KIeLmub63vrNoUJhVJ//OOYzu1Mih8PD+bDj4qVJzOee
gqsF3wRUsE48z6iI4CEB5dGTmp9UcJmz18exiocWpo23xE9Q4cfipxMXTPgo
ySeyM3wKxyPQXL3FgY9WmC3vDZymwjxXiUVFZ/lId3A733EWDUIflYr+vuAj
gkGwzPoFNAhsWt03TRCgqJpZu16q0GCe3+BPHey/F/+XuLtEjQZji4xduwlC
9J/nGuu76jQwNVxim7hfiHIW7mXFaNLg77X0qB/hQvSaHX3cTocGGawgn5x6
IbLZoBpko0uDD7OzVr7qxv59Kv8c0qPBlgxXh0ciIRrIrL+8ZhMNnh3f4/tL
QYSkeItzRNtpoCGZn+jDFqHoFxkFAyY06I0J+xnpIULy1zY9+rSLBrGb6/v3
BuH91JheVWFGg8m723VykkQod9732qLdNJhfcZe7/Y4IGXSdqM+yoMH7CeGl
A49ECJ3/r/PSPhp4u7rfIDaIUC1tXe9ZAg1W9mY+lP0iQiTtJ0PHiDSYs4Sh
ThgSof3vO0cZFBoEDJZc3or3/8Gb3hNWNBqk6cRKdcmI0VHfScmdDBqsJVfc
FC3BfnqZ+iJNOxqsJ+cQndeIUX3xPHvkQAND7hf/g3pipE4ay3Z0osET04+p
+VvFyGekR3DqAA3MvHR8TDC/XkR82PHfQRqMfzoduBDzbfHqxxdLDtOAdtC6
WxPzz/lFVtNHVxp0Dv/4FIj5WOwQpypwp8Gi3s44GcxPqd+n3WS9aHDzmkRa
O+YrNdGteP0RGpRPdqXNnOeeZUCdtPShQZRk3H5tzOfRD7v2uvjSYEf4lvsz
58Hv8Vx/7bwfDQaJP9xdMN+vSy/7mh5Ag6XlQpIT/j2YIbHueSANFNLWlibg
67eacv06gmiwqbZDIIPri+z8VDF+mgZZ+9Lplbi9z4GvZBSCaRDUqJFcOnPe
7dIHNMMQGqzYMUwUYX1y6kFqOuk8DVZ13F4XgMdTR4j44R1Og+WT452Ax6sy
fNzo0kUaLJFQWGeP4+F9wSkkJ5IGfgSFkFc4Xs819tW9ukSDhHaph6GY97IV
Rst6L9OAadaecB3z3slOw/lfDA2oV+p/SWPeF44tyFeNpwG3edvPthViZKvX
D8xEHJ86o613Me9v1zVc9k/C8dWL/FSM51vo9rQ9PpkG3778rdT7KULXbl09
8j6NBi1t/zoSMO/7TYLLh9Nx/gV0R0fUi5DRZw+pORk0+HHqOkWiSoTaFkMy
3KGBBensy/QsEVoexn9Vep8G/hzjZE03EUp3IajerqSB4l1F0oavQnRvvXRd
QA8Nwv4dfU47LkDNamYTR/toQGoPXrGOLECTi4J13QdoIGm/s2q3vgCRxkdj
7YZxfBfdU/LkYz5XD9BMhTRQH+m+vvA4H6mXaVw0FtNgj5XloyoqH+2951hm
MEqDW8nhskNGfJQa17p89W+cz0l2H7L/8hA41nydK0EHVnjiSs8r2B/YSiyS
lKKDc/f0it1+PJRgvhP+zqLDoqcBK8vYPDS4riSTO5cOsUO5PoFreWixmrDl
+zw6iBJTjd4v4qHti3SluxfQwT4yYd7b35inY1nuHxfRIdj4stdb7FfKhruT
6+TpYHyqOKq5nIu6v6jWvVpKB6tfTeuuZXHRpuoE3TIlOggtJZJNMd8dSxud
HijT4emcvgRDzPeLuQviclXpcJc1rjKI+f45NlyUupIO7wq6vNMx36XCXmgm
rqLD7GKziLuY7xtOTNBiVtPhifOhl2cx3+kexhcj1tBButvuqMYiLjrn4F8W
spYO3HL7Z4lS2K+RHgwFrafD8oiwri+Y7x/NOMv9NtBBb4Av+Rvz/a/RWmvv
jXSoOqfrwMF811p3+IyLPh0eakV8L8d8J6neKnAypEOd+5VDB5o46OTCL1+Z
m+mQfoER34/5fltSaRF5C76//JeuJfardaNU2GdMh4ySS+NR2M/+HIo9br6d
DmmpedfvY76rfanLNDGhA1vq+OFSzHfLhjmtRrvo4NuYm5OB+X7spbm0HqLD
he8rcvwx35NLzm1da0YH3XVpubqY39V3n7pr7KZDyJyLP+sx3zmp48nKFnT4
NE6KmPneTSF2U92SvXQYT+Cq1OP7Tc/7TCzYR4cXN9Q9dTHf3QPydKUJeP4/
3Fk38/5bvPug0z8bOrztM5cvfIz5ba8Z94tEh56Am58+Vsy8/7+/SkjG9Vv4
d/S94iA5s1TRDyodpJI/qvTWYf1g1K7ZT6dDntT0jQ/YjzuvXULvYuJ4rzB3
uoP9eLQK6WIbG+fXud793t856JFcdFmDPR1sF4XeUhdi/TAqqfxyPx0SaKQ+
axku+l2UHDvgjMtNL+vwFLmIc1R/tsxhOigwT7tkamPeDjkKSO50eHlweoHZ
Psz77J8ufp50ONg6QVvryEWlB6M7r3vTQaPIs1DZl4tSv5S/7jpGh1vzF+9Y
fgPnbzLJRMIP5++9+SYrH3JRCON70eoAOkSNf8tbW8dFLo1L0ryC6HDf+gdZ
d4qL9F4d9fsdSgf5q3ztSz48pBE6e1g1nA6XzG0DVsbw0NJdN5zQRTq0PPZ8
GlfAQ7/L3lpFXKJDp/69fwM8HqrOW71S4RodVPOk7K6d4iPmtY73+ll4fW7f
IbHqvgBZ2fqa0e7Q4aLR3qNebQJkIju3PPAujv/1s55jUwKkEWGUWZFPh3Cf
otj6tUI0ciouiFBCh9TMiuqWU0LUtVWb71NGh7L5D40gVogafz4/fO0xHTZ8
GL56PVOISo6OkDqe06G9lhnwtU6Izh20WOP+mg4jr5aNySmLkK96V2r0GzrI
NA07CDaI0OEvfosL39Fh+41V54JNRciKcXtitB7vB0t3OoYdEqEdS4yPL2+i
w8I2U8aIvwhtbKwfNGmmw7d5MYLeCyK0ZN/Ex7B2vD4V3vS5YH7PnnNtb85n
OqyMu5XfVyJCv6rXVbzrpEOQriO77ZUIde1k5i7upoPhYs1myR4RavzDXWHU
SwdHJ4MRfZ4IVZeFJ7D66fB4zZrRZ39E6K5B8bn0ITpsUVV/27kY83eZ6E/5
DzosUb8bZ6SK/fpfgxMfOXi8JsoZPVpi9Pebr3CER4eTa5aXftkoRlWvirxn
C3F+ddyP1MT8jsgVDq4Q02GHnutg8S4xsokxOGQ8SgfPdd6ukXvEaImf71fy
OB374UeKGdaYh8wittdvnF/FegunbGe+rxa2hP/F6+GgflAK5qGLhoHtzUk6
uNrKsk9gXupI+9aV/aPDj/B/GjPvpwt/PLBokmDAqZdGe39gv17WIKj6IcUA
B521+0Mxj88+0t85S5oBF9RjWhiY1+bJx8rV5jLAk9F9fOZ8eJngB5u2zmNA
DH9k1sz5MQ0HBfdtFzBA0HT4FB3zO9FSf72nHAOyBUPxuo5iZL/hWHbYIgbk
Lc8m77MTI43FD1amyTMg+dvHygKsNwZH+amlSxkQmUydb0cRo4IOPcXGZQx4
bDemTLERI79Kn6vDSgzwKLo7N9lSjLZlFcpKqTDAO4/KMwAx+hfJj1RVY4Dd
bK+FK7eLUc0RvVlb1PH4ehQt3QzFKJric46kwQCF/j/x89eLEXlr4R93Tfy7
qISzSEOMFFX5Aee1GNAwYXH6tKIYdU1vFKZqM6Dyq3sLSVaMPN7dH6zXYcDZ
3ozYveMipFfIOziky4AyKS33EyMiNHpt41cJfQYEZfTt1vgmQqGO91s2b2YA
TeZ3gmSNCCULCqpSTBhQ8cb+18VorAdbuSaPdjFAO9ngp94ZEdJ6olv+ATGg
Os84I8RbhIrCCu5P72bA4dOHlfUIIvR2WUGqqw0DdLas32M3F/v5v5xlISQG
8HaTjnSMCRG9e8PVZDID2i7l83UHhKgnNz/yPZ0BYY36fw9VCdFvk/wAQycG
7GV2WN44KUTrD+WRpo4yoP5t9JuJOgF6e3NHkfgYA4rdiHP87wmQW0ed/PBx
HI9B9uaVUQKUTea0Np9gQKd4C9vAEu8HSNchN5gBNzruxfW85qMXp58/vxmC
r2+u0SrI4aP9ZTbqCecZsKVaZkdXJB/d2Hi0N/giA2offbE4R+AjRbVCd1oM
A/J/qj5hfuahUpbpO6s4BqgtErz9+JyH6AkNOqZXcb68zMr+lMFDV+cLeOuu
M8D4dKfO9aM8ZGAZYqv+HwPIX+hcOh37/fOLipemMGCTaFbJAxMekv2jH/Av
jQH8rVeYFrI8lG9U1fYzHcdvtX9e5BgXWfuSjX/cZoBjxFSmfzcXRQ75/m3J
ZkC/xkdglGLetxeH3itggHSo/P7/PLkoQ968L72QAQG/ri85x8b+ndi8O7GI
AXNrAkEb+7vgGvGckBIGbHdKK3m9novUJMI9AsoYwPD79/OlKhc9NVla5/kY
52+72ZVL2P//frg5hv4c9+d4V2441gP/8V/x91Xi8WWmpz3FemCrDp2Mqhiw
6t7D5NdYD7S6DhQbVTOAs/yXRw7WA/4ZAUt1anD+qwW17cd6YMnX2SdW1jLg
/DezHCHWA0XLr7crvGXA8mjnLCesB2zpa7bNr2OAj9r88LtYD/DjSlOm3zPA
1ulzYSPWAzHvLfD+yoBtqfwzn7Ae0J3b7jjSiNevhi+qwnqgztytsvsjA+RN
Q0mXMc89z42vbGthwIdw/tR2zHuZpxHn69oY0LT8lfuMHsgZU+x/8YkBix1t
HC1xuYXh3T2lHQzoMtiVewffP3DEOCfvC87P01bLubj+8Nw3c29/xf1RW3VK
BesBzQGW5/VuBnz8cDvJEOuBlyuH66J7GRBYsHfCEOsBZ4cg3dB+BmxQLa5X
xXpgOkkm9sR3HG+5eF3BOw5Kb04WeA0xgHnyv60FHzlo58L1FOcfDIglnp5P
6+SgL/uePGRwGEAPn/2mv5+DzG2z2Sd4DKDO4moQBByUR4/7lyhggMWb/Iia
CRxf+9PZJSIGXHrwQcZ2HhedPuBq3fqTAcFpn8p/KHFRnwtZ+HOMgfnIyJ75
XtLayyRp6W8GqLx26yBsw37+hHwfdZIBwodOsj1YH4Sdnoz0+8cAYoyWfznW
ByMhQxuvSTBhW/mxrMSLXPQkuuLUx9lM8HQI/sfE+oB921OeLMcEdweNpDQl
Hqq6Qy8/togJifG7svdt5qF1+cgpTp4Jzmvzcrqx//9duuxewzImLLb5u/TB
ZR767/1LIKozgblawsFQjo/ax5V9rfWZEFoovG1kKECmk7MVvQyZ8E1UX6PG
FqAcSeGzS5uZUKtVfMcrRIACZWvnvjNmQrLs9X3zGgVomabfrb3AhGKXh/3B
24To7FonC3dzJgwJ7p79ZoP9uK4VJ2IPE3RrTxPQQcx/Y3XjWismzBojKHy/
hPcrYl3DHgoT5j8WrPvdIUTPqaUBLjQm9K72+xXPEyIt9m2VCww8Pin9GoEE
3l8PBbq9smNCyVfH3F5tEUoI0vxndogJt38eufHOR4T+BstlH3Rhglw12fV1
iAgdCv+977wbrr/3+j1ivAhtim24XuXFhD1r5l4bfiBCqQlPTHqOMCE7/8Yj
fqUISaVk9077MGG8NbjHHfuv5qzTG5E/E54GkL1uDGM9IVH2ZMcJJnjHADVo
VIRojiKLrSeZUHS0tPzNtAglPtZtNjzFBKnKX5kX54tRq4LH/o1nmHB1YI9G
oYIYLTueNbIumAnb1+x4sUtdjJj13wK1QnD/AxzyDbGf/HSREacazgTSg/s7
TbD/XN4Xr6p0kQmLOmY5ELA/ZZt+uLskkgkh0mUnS7EeSEmda7TwEhOaXt+R
D8J6oHPcvGreZSY80Ku6dxXrARXaORvpGCbU08VVElgPODx48lkijgnfzW9I
1LDEKG3BmMtkPBPOhduLOmfOa3U3EP26xoTXyx09LLAeUKvxDv6ZiMulv+6Y
NXM+jcbdeYIkJuy+rGuqgPmffrbv+kgyE07/Sb02c77Nt88rNAdTmfDu/S1d
Q/xbfYtdYW8aE+QNU9YgfP+Bq4k7vqYzQY/9PSkL13+b11j7+TYTNkvm3TiA
9UjPvgW01kwmnK2jPQvAekUjx7K7MZsJP7uGV33H/T8oFeb9Pgfnl3q9zMzz
/Mz9Fb9qc5lQGOhyrwf7+76nv8Or85igumV4ty/WB6uVjBZXFjAhek10ogvW
By7+x9KeFDJBevP5F1VYH3zfMFhS9BDHYzIbKnTESDtqlVlBCRPGbB1+HtYU
I7cBx/q7ZUxo0ObnhyiL0XBay/f0p0zozriZsmaOGK37s9Av9TkTqrZrXCif
ECFPhvW/65VMeNb1brReKEIjci8VY6qZ0M7YEp7SIUI6XpOZUTVM0PBOt2Th
/PKuNda/UMuESD2r93nY33PPFe49U8eEKH2TYa0cEeILbgR5NuP8258S8f0I
1hs2n2a7tjIhTy3lWJOTCB3LXXLVuZ0J8elXy06QREjofOkeq5MJuwalhiT1
Rejnx8BOiz4mcH32B2Tg9fT7EWWnppgJd7pCY7+7CJHstq0NS0eZILrsYPiD
JkQaz1WcpcdxPjJ501xzIbKq6Q8f/sOEJ8rtn2etEqKU1hPvCyVZ8KtjQ8et
ZwK0YyzF3kSeBe7trJITT/iIdOocV3cpC2oFxh7ZqXx0aOrQOfVlLGA9pWzf
dpaPoqV1MyWVWbD1w8CrmfPivyyr/PFGgwUmFP67+Y08JEzJPPNEkwWVDWEv
hx/x0Gz1SLl8LRZsZF2qIafwkK422TB2HQu8Q1ZkNbry0NmtfUF0AxakTGsU
jkrzUPzT2vmWm1jwYfLWkXgBF2Wb5qcZG7Eg/qrn5tYOLvpgGVClsg33/1T2
JuciLuqpY1Nld7Bg78kTJwvTuGiUtGtgyoQFjwtzxUWXuGgFa45ML2LB36E2
5jdXLtr0ZSSl2YwFPSyT2IUMLrI80LihZjcLvHzmfJraw0U+7sm2d/eyoOZX
Ws1qvP+Hcc72Ju9jwX+Vbq4HlLko6dhB/2gCCxLErJrDslxUeVLnv6O2LCij
Ll3ROMpBzRML1x+gsMDo08K9O0Y4aDDk51MyjQWT58ovB/Zw0N9Zn23MGSyY
0+1cc/ETBy2Mev5tM4sF0vMD0jwbMS9lM3zX2LEgVnd15WrM/63xF6WUHFiw
xf92S+lLDrJW8EqUcWKB8ZBy5CrM//3JJO2/+1lA/7fN0wPz309t82OOMwta
ot69uIz5H3FbyfrrIRasb5n96grmc6rW5JcGFxa8X6+VfwTzuzC352iVGwt0
O5yL/v88QPf1dLEHCwbPPZ838z1ce9G9q1leuPwmP5+Cy0eMYldfP8KC+qfF
Vo/x/dOP/UojfFigEZ0YJ1XMQV1zHl7O9MXzu+49PxTz/ylddLDSjwUXDCh/
ZJ9gfZRpsK0zgAV5HupRdys5KEB4bOF4IAusdt+ZIL/mIIrpgwH5Uzj/zPyZ
8+o5SO8K/+nGMyw4cOhrclMbBy3o3Hh1XzALaFnbXuV0c9Dw2qPuriEs+CbV
2XYZx/v1iYJd58+zoOTEyochWI9lvuIsvRnOAvNb/HPnZ3FRqPyGkccXWXDX
qEYzXp6LnA54VbVGssC3QuVCngYX7bh/L0l4iQXo5ZFLjQZctHxi+IjsFRbs
a92i/M+Mi5qT3JX3xLOgrcxw0XF3LnowkCM4cI0FhwzMbhSd4aIrmwZfn0lk
gcfYnV5hPBftbXDxe5TMAh3HsEzPSi7SUsu2akxlwfjHqj1p7VifevWrc9JY
0G00T+sVzvfn0ofea2bg+ToMrV1aPJRCy8gwzWKBRYi/+RvgocCMnpP2d1hw
QobQl+iE9fOuA1rX7rGgMMskrRqvrzsBjsGSD3F+Grp8eq7KR2HVN2grSljg
X7PipIIpHzkv/rJ+exkLOho4XcoH+UilwK7d9ykLwhd/b5W7x0ex/Uz9nmoW
vKqOIiYiAQqiUnorW1hQ/ePlq0FTIWLcji/vbGPB/W75C6vxfrOJ3xgz/okF
Q4U5R/a7CxHvEmmHXhcef5lS6sM4ITr0kpBwc4AFUokbGAu7hQgtuuz5ZJAF
Ez/jJk+IhUjNqQ61DbPgecr8G5nSItT+24ory2NB1bz62xs3iBDBwNLi7BgL
lqrf+2LuJ0ISbW2SAb9w/tmMSPPPi1DZKddK7z8s6FrUSN5yVYQ0X10wdphi
gcq5Ns3wQhH67K4wSp1mgR4pxSjkOfZbstlF1pJsaNJn/ZKqw3qD8Wr9Dmk2
GN65T4jrx37tL3XQcC4bYjbYv4kViJDbrb7M9fPYcC6Dbz0b80Ftj9+BVQvY
oJxkr8mVFqPmYUk1ZTk21EpdTDVfLEZRMVc/L17EBq7/uPRsFTEy3bTquow8
G5gfh402rhajvDOw8LcCGwgKEXIFM/9fRqOpTqDIBiPCMfbkDuxfXx+IHFrO
Bp/msAV5ZmL0wVOwu1uFDcJR7fBHe8UobGGIxCc1Njy4b6WjRMT++dHCigZ1
Nujni71bsN/ms9JP1WqwYeOg4Z9B7MezJzdurdRkg4FiNKJgv26fUSEu1WLD
ILPvvTz284stiQ/ua7Nh8tWqDeuw368d6fK+s44NE4E35BNnnh/EHVl3U4cN
dx/08WeeH2wymhxI1GWDV+mI58z7+MOfL2dc0cPjX5y7/tvM9/fBqvsvGLDB
w8526A6uj66Zr3J2Exum+kgTtbi9eW92fPI3YsOBTXcW7cZ6pdK7LsF7Kxt2
/RI2qGI9E7DYnnx4Gxtmf2GMUGlipFP6Q9ZhB66/YmfUCAnrC7tT76g72fD4
7OrN3/eJUdI/mQhrUzYkmaYFWWA9ZZOVbG4ObIgV3R+Sw3pLymrd9HZzNpw/
u9HODOuxx9zyZ4Z7cPnFz3L9+mLkc3Vv0HpLNmgM9hPHsX7T2vrJaJUVG/zm
pB48t1KM4kPG7y+2YUOQElNtQlaMLLUivGRIbHCXOuz6S0qMJt8uWytBxu1f
Pel18rcIeSzZcltAw+15R0cv6RMh9fIaxyEGG/LdouZvbRehVge6cjeLDYdz
99Xz3okQ3PG/1uCA4807tWtDkQgt3/bwwv3DbND+t03fPkiE3jjpe3r74/wx
SR4OmhCiJYc9nt08wYbIxKgsmR9CtN8jQ67pJBvkWZIl3u1CNO639KHRWTZU
naJcflWE9XfUr79TF9hwU3ik1QnrhdCHL67EJ7Hh3glNyoJkAfpQ/vtbdTLO
1+iusCY/AVKqMDQcS2XDW5uuJ9+JAlT4JqvN7hYbBHCvUVNagL52RaqvzsX5
NjGy6EMQH63rq/Jl5OF8srsj95vJRwFDf6ojC9ggoygwfrSFj2TF3u7cIjac
YNz0/znKQzvmkotKn7DhSM/NONIZHoqQvSQ1/IwNy6zv9Ofv56GP8tV0lUo2
/A48YlFnzkMeakZ/zlWzwdrP1PGAHA+VrDpKKK7B6zfaPa3nJxdJrM252V/L
huwBuGz8hYv+M1xubvWeDQdTCL5BBdjPbaUknq7H+XLc7JB3Ehfp7YweLGhk
Ay+k84fFeS6qtZyMlm9lw5ZN+9xe2nHREpstX3e343wTFo547sV8oPjoB35m
g9Keduq8rVhfOPS0dHax4YPn7IUmilwEB5W15bpxe5oVL1rmctFlN2oQ6mVD
8DLr875/MT+9L9cd72fDnmT7AAU+5vvxGrXs72ywGt16tbqPg3wCp3zah9hg
PH7JK/gz5uWZrS9lRtgg51wUvhfrgTnnjy014eL5+DnHefUbzMeIXNejfLxf
dCufX1rFQWmXe8tvCdng2xqnrfIU8zBeZX6zGM+no6XZ9lIOMkqiOc4ew/HK
FVf4YT6H3rhSuPUXG54X7Lg08/9oP9x+LeH5B9eff8FrJ+a7Us4/6o0JNjhs
fVTbiPl/KN/4Tv0UGyRy8sXhuLywyPfX9DQbLOm03fYPOOh/YuAc5Q==
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True]], "Output",
 CellChangeTimes->{3.46548194615487*^9, 3.465482368031755*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{640, 750},
WindowMargins->{{363, Automatic}, {127, Automatic}},
FrontEndVersion->"7.0 for Linux x86 (64-bit) (February 25, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "PastelColor.nb", 
  CharacterEncoding -> "iso8859-1"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 99, 1, 75, "Title"],
Cell[669, 25, 157, 3, 70, "Subtitle"],
Cell[829, 30, 267, 6, 74, "Text"],
Cell[CellGroupData[{
Cell[1121, 40, 115, 2, 42, "Input"],
Cell[1239, 44, 400, 7, 114, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1676, 56, 124, 1, 39, "Subsection"],
Cell[1803, 59, 169, 7, 116, "Text"],
Cell[CellGroupData[{
Cell[1997, 70, 610, 18, 42, "Input"],
Cell[2610, 90, 512, 17, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3159, 112, 117, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[3301, 117, 313, 7, 42, "Input"],
Cell[3617, 126, 1386, 42, 71, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5040, 173, 156, 3, 42, "Input"],
Cell[5199, 178, 547, 17, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5783, 200, 160, 3, 42, "Input"],
Cell[5946, 205, 577, 19, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6560, 229, 358, 9, 42, "Input"],
Cell[6921, 240, 304, 10, 41, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[7274, 256, 109, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[7408, 261, 1087, 27, 87, "Input"],
Cell[8498, 290, 58845, 975, 386, 49330, 817, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[67380, 1270, 127, 2, 42, "Input"],
Cell[67510, 1274, 68522, 1128, 219, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[136093, 2409, 108, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[136226, 2414, 549, 16, 42, "Input"],
Cell[136778, 2432, 403, 11, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[137218, 2448, 844, 23, 65, "Input"],
Cell[138065, 2473, 197274, 3131, 384, 137201, 2145, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[335388, 5610, 114, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[335527, 5615, 126, 2, 42, "Input"],
Cell[CellGroupData[{
Cell[335678, 5621, 277, 6, 70, "Print"],
Cell[335958, 5629, 295, 6, 70, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[336302, 5641, 879, 20, 109, "Input"],
Cell[337184, 5663, 166, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337387, 5670, 603, 16, 109, "Input"],
Cell[CellGroupData[{
Cell[338015, 5690, 234, 5, 24, "Print"],
Cell[338252, 5697, 262, 6, 24, "Print"],
Cell[338517, 5705, 222, 5, 24, "Print"],
Cell[338742, 5712, 222, 5, 24, "Print"],
Cell[338967, 5719, 232, 5, 24, "Print"]
}, Open  ]],
Cell[339214, 5727, 82796, 1361, 217, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
